@@ -1,10 +1,61 @@
 #!/bin/sh
 ROOT=../../..
 proot=$ROOT/src_plugins
-rnd_proot=$ROOT/src_3rd/librnd-local/src/librnd/plugins
+
+# Get librnd requirement from INSTALL so it doesn't need to be maintained
+# multiple locations
+librnd_min_ver()
+{
+	awk -v "which=$1" '
+		/librnd >=/ {
+			ver=$0
+			sub("^.*>=", "", ver)
+			sub("[ \t].*$", "", ver)
+			split(ver, V, "[.]")
+			if (which == "major")
+				print V[1]
+			else if (which == "minor")
+				print V[2]
+			else if (which == "patch")
+				print V[3]
+			else
+				print ver
+		}
+	' < $ROOT/INSTALL
+}
+
+
+# major version of librnd
+RNDV=`librnd_min_ver major`
+RNDVER=`librnd_min_ver`
+
+if test -f $ROOT/Makefile.conf
+then
+	LIBRND_ROOT=`make -f librnd_root.mk`
+fi
+
+if test -z "$LIBRND_ROOT"
+then
+	if test -f /usr/local/share/librnd${RNDV}/librnd_packages.sh
+	then
+		LIBRND_ROOT=/usr/local
+	else
+		LIBRND_ROOT=/usr
+	fi
+fi
+
+if test -f $LIBRND_ROOT/share/librnd${RNDV}/librnd_packages.sh
+then
+	. $LIBRND_ROOT/share/librnd${RNDV}/librnd_packages.sh
+else
+	echo "librnd installation not found - try to configure this checkout first or install librnd in /usr or /usr/local" >&2
+	exit 1
+fi
 
 ### generate description.txt (file formats) ###
 
+echo "$RNDV" > auto/ver_librnd_major
+
 . $ROOT/util/devhelpers/awk_on_formats.sh
 
 awk_on_formats  '
@@ -34,7 +85,7 @@ function out(dir, type  ,n,v,A,tmp)
 
 ### generate packages.html and auto/ ###
 
-meta_deps="core io-standard io-alien hid-gtk2-gl hid-gtk2-gdk export export-sim export-extra auto extra cloud doc import-net"
+meta_deps="core io-standard io-alien lib-gui librnd${RNDV}-hid-gtk2-gl librnd${RNDV}-hid-gtk2-gdk export export-sim export-extra auto extra cloud doc import-net"
 
 (echo '
 <html>
@@ -47,24 +98,26 @@ do
 	pkg=`basename $n`
 	sed "s/^/$pkg /" < $n
 done
-for n in $rnd_proot/*/*.pup
-do
-	pkg=`basename $n`
-	sed "s/^/!$pkg /" < $n
-done
 for n in $proot/*/*.tmpasm
 do
 	sed "s@^@$n @" < $n
 done
-for n in $rnd_proot/*/*.tmpasm
-do
-	sed "s@^@!$n @" < $n
-done
 cat extra.digest
-) | awk -v "meta_deps=$meta_deps"  '
+) | awk -v "meta_deps=$meta_deps" -v "librnd_pkgs=$librnd_pkgs" -v "librnd_plugins=$librnd_plugins" -v "RNDV=$RNDV" -v "RNDVER=$RNDVER" '
 	BEGIN {
-		gsub(" ", " pcb-rnd-", meta_deps)
-		sub("^", "pcb-rnd-", meta_deps)
+		v = split(meta_deps, A, "[ \t]")
+		meta_deps = ""
+		for(n = 1; n <= v; n++) {
+			if (A[n] == "")
+				continue
+			if ((!(A[n] ~ "^pcb-rnd")) && (!(A[n] ~ "^librnd")))
+				A[n] = "pcb-rnd-" A[n]
+			if (meta_deps == "")
+				meta_deps = A[n]
+			else
+				meta_deps = meta_deps " " A[n]
+		}
+
 		while((getline < "desc") == 1) {
 			if ($0 ~ "^@") {
 				pkg=$0
@@ -74,8 +127,38 @@ cat extra.digest
 			}
 			LONG[pkg] = LONG[pkg] $0 " "
 		}
+
+		v = split(librnd_pkgs, A, "[ \t]+")
+		for(n = 1; n <= v; n++)
+			LIBRND_PKG[A[n]] = 1
+
+		v = split(librnd_plugins, A, "[ \t\r\n]+")
+		for(n = 1; n <= v; n++)
+			if (split(A[n], B, "=") == 2)
+				PLUGIN["pcb-rnd-" B[1]] = B[2]
 	}
 
+	function fix_dep(dep)
+	{
+		if ((dep == "") || (dep ~ "^librnd"))
+			return dep
+		sub("^pcb-rnd-", "", dep)
+		if (dep in LIBRND_PKG)
+			return "librnd" RNDV "-" dep
+		return "pcb-rnd-" dep
+	}
+
+	function fix_deps(deps   ,A,n,s,v)
+	{
+		v = split(deps, A, "[ \t]+")
+		s = ""
+		for(n = 1; n <= v; n++)
+			s = s " " fix_dep(A[n])
+		sub("^ ", "", s)
+		return s;
+	}
+
+
 	{
 		if ($1 ~ "^[!]") {
 			in_librnd = 1
@@ -182,7 +265,12 @@ print in_librnd, $1 > "L1"
 	}
 
 	END {
-	
+
+#		for(plg in PLUGIN_DEP)
+#			print "PLUGIN[" plg "] = " PLUGIN[plg] > "/dev/stderr"
+#		exit(1)
+
+
 		# everything depends on core
 		for(pkg in PKG)
 			add_dep(pkg, "pcb-rnd-core")
@@ -208,15 +296,19 @@ print in_librnd, $1 > "L1"
 		PKG["pcb-rnd-doc"] = "&nbsp;"
 		IFILES["pcb-rnd-doc"] = "/usr/share/doc/*"
 
+		print "<h3> Librnd minimum version: " RNDVER "</h3>"
+		print RNDVER >  "auto/librnd_min_ver"
+
 		print "<h3> Package summary and dependencies </h3>"
+		print "<p>"
 		print "<table border=1>"
 		print "<tr><th> package <th> depends on (packages) <th> consists of (plugins)"
 
 		for(pkg in PKG) {
 			if (pkg == "pcb-rnd-core")
-				print "<tr><th>" pkg "<td>" PKG_DEP[pkg] "<td>(builtin: " PKG[pkg] ")"
+				print "<tr><th>" pkg "<td>" fix_deps(PKG_DEP[pkg]) "<td>(builtin: " PKG[pkg] ")"
 			else
-				print "<tr><th>" pkg "<td>" PKG_DEP[pkg] "<td>" PKG[pkg]
+				print "<tr><th>" pkg "<td>" fix_deps(PKG_DEP[pkg]) "<td>" PKG[pkg]
 			print strip(PKG_DEP[pkg]) >  "auto/" pkg ".deps"
 			print pkg > "auto/List"
 		}
@@ -235,10 +327,8 @@ print in_librnd, $1 > "L1"
 		}
 		print "</table>"
 		print "<p>File prefixes:<ul>"
-		print "	<li> $P: pcb-rnd plugin install dir (e.g. /usr/lib/pcb-rnd/)"
-		print "	<li> $C: pcb-rnd conf dir (e.g. /usr/share/pcb-rnd/)"
-		print "	<li> $LP: librnd plugin install dir (e.g. /usr/lib/librnd/)"
-		print "	<li> $LC: librnd conf dir (e.g. /usr/share/librnd/)"
+		print "	<li> $P: plugin install dir (e.g. /usr/lib/pcb-rnd/)"
+		print "	<li> $C: conf dir (e.g. /etc/pcb-rnd/)"
 		print "	<li> $PREFIX: installation prefix (e.g. /usr)"
 		print "</ul>"
 
