@@ -11,18 +11,20 @@
 #include "util/arg_auto_set.h"
 #include "Rev.h"
 
-#define version "2.4.0"
+#define version "3.0.3"
 
-#define LIBRND_ROOT         "../src_3rd/librnd-local/src/librnd"
-#define LIBRND_PLUGIN_ROOT  "../src_3rd/librnd-local/src/librnd/plugins"
-#include "librnd-local/src_3rd/puplug/scconfig_hooks.h"
-#include "librnd-local/src_3rd/libfungw/scconfig_hooks.h"
-#include "librnd-local/src_3rd/libporty_net/hooks_net.c"
+#define REQ_LIBRND_MAJOR 3
+#define REQ_LIBRND_MINOR 1
 
-#include "librnd-local/src/librnd/scconfig/plugin_3state.h"
-#include "librnd-local/src/librnd/scconfig/hooks_common.h"
-#include "librnd-local/src/librnd/scconfig/hooks_gui.c"
-#include "librnd-local/src/librnd/scconfig/rnd_hook_detect.h"
+#define TOSTR_(x) #x
+#define TOSTR(x) TOSTR_(x)
+
+#include <librnd/src_3rd/puplug/scconfig_hooks.h>
+#include <librnd/src_3rd/libfungw/scconfig_hooks.h>
+
+#include <librnd/scconfig/plugin_3state.h>
+#include <librnd/scconfig/hooks_common.h>
+#include <librnd/scconfig/rnd_hook_detect.h>
 
 const arg_auto_set_t disable_libs[] = { /* list of --disable-LIBs and the subtree they affect */
 	{"disable-gd",        "libs/gui/gd",                  arg_lib_nodes, "$do not use gd (many exporters need it)"},
@@ -37,14 +39,17 @@ const arg_auto_set_t disable_libs[] = { /* list of --disable-LIBs and the subtre
 #undef plugin_def
 #undef plugin_header
 #undef plugin_dep
-#define plugin_def(name, desc, default_, all_, hidlib_) plugin3_args(name, desc)
+#define plugin_def(name, desc, default_, all_) plugin3_args(name, desc)
 #define plugin_header(sect)
-#define plugin_dep(plg, on, hidlib)
+#define plugin_dep(plg, on)
 #include "plugins.h"
 
 	{NULL, NULL, NULL, NULL}
 };
 
+#define TO_STR_(payload) #payload
+#define TO_STR(payload) TO_STR_(payload)
+
 static void help1(void)
 {
 	rnd_help1("pcb-rnd");
@@ -52,6 +57,12 @@ static void help1(void)
 	printf(" --dot_pcb_rnd=path         .pcb-rnd config path under $HOME/\n");
 }
 
+#define need_value(msg) \
+	if (value == NULL) { \
+		fprintf(stderr, "syntax error; %s\n", msg); \
+		exit(1); \
+	}
+
 /* Runs when a custom command line argument is found
  returns true if no further argument processing should be done */
 int hook_custom_arg(const char *key, const char *value)
@@ -59,6 +70,7 @@ int hook_custom_arg(const char *key, const char *value)
 	rnd_hook_custom_arg(key, value, disable_libs); /* call arg_auto_print_options() instead */
 
 	if (strcmp(key, "dot_pcb_rnd") == 0) {
+		need_value("use --dot_pcb_rnd=dir");
 		put("/local/pcb/dot_pcb_rnd", value);
 		return 1;
 	}
@@ -91,16 +103,31 @@ int hook_postinit()
 	put("/local/pcb/want_byaccic", sfalse);
 	put("/local/pcb/want_static", sfalse);
 	put("/local/pcb/dot_pcb_rnd", ".pcb-rnd");
+	put("/local/pcb/librnd_prefix", TO_STR(LIBRND_PREFIX));
+
+	librnd_ver_req_min(REQ_LIBRND_MAJOR, REQ_LIBRND_MINOR);
 
-	put("/local/pcb/librnd_is_local", strue);
-	put("/local/pcb/librnd_root", "src_3rd/librnd-local/src");
 	return 0;
 }
 
 /* Runs after all arguments are read and parsed */
 int hook_postarg()
 {
-	return rnd_hook_postarg();
+	char *tmp;
+	const char *libad;
+
+	put("/local/pcb/librnd_template", tmp = str_concat("", TO_STR(LIBRND_PREFIX), "/", get("/local/libarchdir"), "/librnd3/scconfig/template", NULL));
+	free(tmp);
+
+	/* if librnd is installed at some custom path, we'll need to have a -I on CFLAGS and -L on LDFLAGS */
+	libad = get("/local/libarchdir");
+	if (((strncasecmp(TO_STR(LIBRND_PREFIX), "/usr/include", 12) != 0) && (strncasecmp(TO_STR(LIBRND_PREFIX), "/usr/local/include", 18) != 0)) || (strcmp(libad, "lib") != 0)) {
+		put("/local/pcb/librnd_extra_inc", "-I" TO_STR(LIBRND_PREFIX) "/include");
+		put("/local/pcb/librnd_extra_ldf", tmp = str_concat("", "-L" TO_STR(LIBRND_PREFIX) "/", libad, NULL));
+		free(tmp);
+	}
+
+	return rnd_hook_postarg(TO_STR(LIBRND_PREFIX), "pcb-rnd");
 }
 
 
@@ -114,12 +141,17 @@ int hook_detect_host()
 	/* figure if we need the dialogs plugin */
 static void calc_dialog_deps(void)
 {
+	const char *control;
 	int buildin, plugin;
 
-	rnd_calc_dialog_deps(); /* remove after librnd separation */
-
-	buildin = istrue(get("/target/librnd/dialogs/buildin"));
-	plugin = istrue(get("/target/librnd/dialogs/plugin"));
+#warning TODO: get this from librnd
+	control = get("/local/pcb/lib_hid_common/controls");
+	if (control == NULL) {
+		fprintf(stderr, "librnd configuration error: can't figure how lib_hid_common is configured\n(should be coming from plugin.state as /local/pcb/lib_hid_common/controls)\n");
+		exit(1);
+	}
+	buildin = strcmp(control, "buildin") == 0;
+	plugin = strcmp(control, "plugin") == 0;
 
 	if (buildin) {
 		hook_custom_arg("buildin-draw_csect", NULL);
@@ -142,16 +174,13 @@ static void calc_dialog_deps(void)
 /* Runs when things should be detected for the target system */
 int hook_detect_target()
 {
-	int want_gd, want_stroke, want_xml2, want_freetype2, want_fuse;
+	int want_gd, want_xml2, want_freetype2, want_fuse;
 
 	want_gd     = plug_is_enabled("export_png") || plug_is_enabled("import_pxm_gd");
-	want_stroke = plug_is_enabled("stroke");
-	want_xml2   = plug_is_enabled("io_eagle") || plug_is_enabled("order_pcbway");
+	want_xml2   = plug_is_enabled("io_eagle") || plug_is_enabled("order_pcbway") || plug_is_enabled("stl_export");
 	want_freetype2 = plug_is_enabled("import_ttf");
 	want_fuse = plug_is_enabled("export_vfs_fuse");
 
-	plugin_db_hidlib();
-
 	rnd_hook_detect_cc();
 	if (rnd_hook_detect_sys() != 0)
 		return 1;
@@ -164,14 +193,6 @@ int hook_detect_target()
 		}
 	}
 
-	if (want_stroke) {
-		require("libs/gui/libstroke/presents", 0, 0);
-		if (!istrue(get("libs/gui/libstroke/presents"))) {
-			report_repeat("WARNING: Since there's no libstroke found, disabling the stroke plugin...\n");
-			hook_custom_arg("disable-stroke", NULL);
-		}
-	}
-
 	if (want_freetype2) {
 		require("libs/sul/freetype2/presents", 0, 0);
 		if (!istrue(get("libs/sul/freetype2/presents"))) {
@@ -180,13 +201,11 @@ int hook_detect_target()
 		}
 	}
 
-	rnd_hook_detect_hid(plug_is_enabled("puller"));
-
 	if (want_xml2) {
 		require("libs/sul/libxml2/presents", 0, 0);
 		if (!istrue(get("libs/sul/libxml2/presents"))) {
 			report("libxml2 is not available, disabling io_eagle...\n");
-			report_repeat("WARNING: Since there's no libxml2 found, disabling the Eagle IO and pcbway order plugins...\n");
+			report_repeat("WARNING: Since there's no libxml2 found, disabling the Eagle IO, amf 3d models and pcbway order plugins...\n");
 			hook_custom_arg("disable-io_eagle", NULL);
 			hook_custom_arg("disable-order_pcbway", NULL);
 		}
@@ -255,17 +274,9 @@ int hook_detect_target()
 		put("/local/pcb/want_parsgen_byaccic", sfalse);
 	}
 
-	libporty_net_detect_target();
-
 	/* plugin dependencies */
 	plugin_deps(1);
 
-	rnd_hook_detect_coord_bits(); /* remove this after the librnd split */
-
-	/* restore the original CFLAGS, without the effects of --debug, so Makefiles can decide when to use what cflag (c99 needs different ones) */
-	/* this should be removed after the librnd split */
-	put("/target/cc/cflags", get("/local/cc_flags_save"));
-
 	return 0;
 }
 
@@ -312,42 +323,10 @@ int hook_generate()
 	put("/local/version",  version);
 	put("/local/version_major",  version_major);
 	put("/local/apiver", apiver);
+	put("/local/librnd_ver_req_major", TOSTR(REQ_LIBRND_MAJOR));
+	put("/local/librnd_ver_req_minor", TOSTR(REQ_LIBRND_MINOR));
 
 	printf("\n");
-	if (istrue(get("/local/pcb/librnd_is_local"))) {
-		FILE *f;
-		put("/local/pup/sccbox", "../../../../scconfig/sccbox");
-
-		printf("Generating local librnd build files:\n");
-		printf("Generating librnd-local Makefile.conf (%d)\n", generr |= tmpasm("../src_3rd/librnd-local", "Makefile.conf.in", "Makefile.conf"));
-		printf("Generating librnd-local src/Makefile (%d)\n", generr |= tmpasm("../src_3rd/librnd-local/src", "Makefile.in", "Makefile"));
-
-		printf("Generating src_3rd/libporty_net/os_includes.h (%d)\n", generr |= generate("../src_3rd/librnd-local/src_3rd/libporty_net/os_includes.h.in", "../src_3rd/librnd-local/src_3rd/libporty_net/os_includes.h"));
-		printf("Generating src_3rd/libporty_net/pnet_config.h (%d)\n", generr |= generate("../src_3rd/librnd-local/src_3rd/libporty_net/pnet_config.h.in", "../src_3rd/librnd-local/src_3rd/libporty_net/pnet_config.h"));
-		printf("Generating src_3rd/libporty_net/phost_types.h (%d)\n", generr |= generate("../src_3rd/librnd-local/src_3rd/libporty_net/phost_types.h.in", "../src_3rd/librnd-local/src_3rd/libporty_net/phost_types.h"));
-
-		printf("Generating librnd config.h (%d)\n", generr |= tmpasm("../src_3rd/librnd-local", "config.h.in", "config.h"));
-
-		generr |= pup_hook_generate("../src_3rd/librnd-local/src_3rd/puplug");
-		if (!istrue(get("libs/script/fungw/presents")))
-			generr |= fungw_hook_generate("../src_3rd/librnd-local/src_3rd/libfungw");
-
-		f = fopen("../src_3rd/librnd-local/scconfig/revtest", "w");
-		fprintf(f, "#!/bin/sh\nexit 0\n\n");
-		fclose(f);
-		system("chmod 755 ../src_3rd/librnd-local/scconfig/revtest");
-
-		system("cd ../src_3rd/librnd-local/scconfig && make cquote && make sccbox");
-
-		printf("\n");
-
-		/* reset shared variables used in librnd, reused in pcb-rnd */
-		put("/local/pcb/buildin_pups", "");
-		put("/local/pcb/buildin_hidlib_pups", "");
-		put("/local/pcb/buildin_hidlib_pups_fullpath", "");
-		put("/local/pcb/SRCS", "");
-		put("/local/dep/SRCS", "");
-	}
 
 	put("/local/pup/sccbox", "../../scconfig/sccbox");
 
@@ -356,8 +335,6 @@ int hook_generate()
 
 	printf("Generating src/Makefile (%d)\n", generr |= tmpasm("../src", "Makefile.in", "Makefile"));
 
-	generr |= rnd_hook_generate();
-
 	printf("Generating util/gsch2pcb-rnd/Makefile (%d)\n", generr |= tmpasm("../util", "gsch2pcb-rnd/Makefile.in", "gsch2pcb-rnd/Makefile"));
 	printf("Generating util/bxl2txt/Makefile (%d)\n", generr |= tmpasm("../util", "bxl2txt/Makefile.in", "bxl2txt/Makefile"));
 
@@ -375,15 +352,16 @@ int hook_generate()
 	print_sum_setting("/local/pcb/want_parsgen",   "Regenerating languages with bison & flex");
 	print_sum_setting("/local/pcb/debug",          "Compilation for debugging");
 	print_sum_setting_or("/local/pcb/symbols",     "Include debug symbols", istrue(get("/local/pcb/debug")));
-	print_sum_cfg_val("/local/pcb/coord_bits",     "Coordinate type bits");
+	print_sum_cfg_val("/local/prefix",             "installation prefix (--prefix)");
+	print_sum_cfg_val("/local/confdir",            "configuration directory (--confdir)");
 	print_sum_cfg_val("/local/pcb/dot_pcb_rnd",    ".pcb_rnd config dir under $HOME");
 
 #undef plugin_def
 #undef plugin_header
 #undef plugin_dep
-#define plugin_def(name, desc, default_, all_, hidlib_) plugin3_stat(name, desc)
+#define plugin_def(name, desc, default_, all_) plugin3_stat(name, desc)
 #define plugin_header(sect) printf(sect);
-#define plugin_dep(plg, on, hidlib)
+#define plugin_dep(plg, on)
 #include "plugins.h"
 
 	if (repeat != NULL) {
