@@ -45,7 +45,7 @@ int find_gl(const char *name, int logdepth, int fatal, const char *call, const c
 	const char *node = "libs/gui/gl";
 	char **id, *incdirs[] = {"GL", "OpenGL", NULL};
 	char **cf, *cflgs[] = {"", "-I/usr/include/libdrm", NULL};
-	const char **lf, *ldflgs[] = {"-lGL", "-lopengl32", NULL};
+	const char **lf, *ldflgs[] = {"-lGL", "-lopengl32", "-framework OpenGL", NULL};
 	char *cflags = NULL;
 	char *ldflags = NULL;
 	(void) call;  /* not used */
@@ -93,6 +93,42 @@ int find_gl(const char *name, int logdepth, int fatal, const char *call, const c
 	return 0;
 }
 
+int find_gl_vao(const char *name, int logdepth, int fatal, const char *call, const char *arg)
+{
+	const char *test_c =
+		NL "#include <stdio.h>"
+		NL "int main()"
+		NL "{"
+		NL "	glBindVertexArray(0);"
+		NL "	return 0;"
+		NL "}"
+		NL;
+	const char *node = "libs/gui/gl/vao";
+	const char *cflags, *ldflags, *incs;
+	(void) call;  /* not used */
+	(void) arg;  /* not used */
+
+	if (require("cc/cc", logdepth, fatal))
+		return try_fail(logdepth, node);
+
+	if (require("libs/gui/gl/*", logdepth, fatal))
+		return try_fail(logdepth, node);
+
+	cflags = get("libs/gui/gl/cflags");
+	ldflags = get("libs/gui/gl/ldflags");
+	incs = get("libs/gui/gl/includes");
+
+	report("Checking for gl vao... ");
+	logprintf(logdepth, "find_gl_vao...\n");
+	logdepth++;
+
+	if (try_icl_norun(logdepth, node, test_c, incs, cflags, ldflags) != 0)
+		return 0;
+
+	return try_fail(logdepth, node);
+}
+
+
 int find_glu(const char *name, int logdepth, int fatal, const char *call, const char *arg)
 {
 	char test_c[256];
@@ -168,9 +204,8 @@ int find_glut(const char *name, int logdepth, int fatal, const char *call, const
 		NL "#include <stdio.h>"
 		NL "int main()"
 		NL "{"
-		NL "	int t1 = glutGet(GLUT_ELAPSED_TIME);"
-		NL "	int t2 = glutGet(GLUT_ELAPSED_TIME);"
-		NL "	if(t2 >= 0 && t1 <= t2)"
+		NL "	glutGet(GLUT_ELAPSED_TIME);"
+		NL "	if (glutGet!=NULL)"
 		NL "		puts(\"OK\");"
 		NL "	return 0;"
 		NL "}"
