@@ -27,6 +27,7 @@
 int find_socket_socket(const char *name, int logdepth, int fatal)
 {
 	char *test_c =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	int s;"
 		NL "	SOCK_INIT;"
@@ -103,6 +104,7 @@ int find_socket_socket(const char *name, int logdepth, int fatal)
 int find_socket_wsasocket(const char *name, int logdepth, int fatal)
 {
 	char *test_c =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	int s;"
 		NL "	SOCK_INIT;"
@@ -217,6 +219,7 @@ int find_socket_types(const char *name, int logdepth, int fatal)
 		{NULL, NULL}
 	};
 	char *test_c_socket =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	SOCK_INIT;"
 		NL "	if (socket(%s, %s, 0) >= 0) {"
@@ -253,6 +256,7 @@ int find_socket_types(const char *name, int logdepth, int fatal)
 int find_socket_ioctlsocket(const char *name, int logdepth, int fatal)
 {
 	char test_c_temp[] =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	int s;"
 		NL "	%s nonblocking;"
@@ -278,6 +282,7 @@ int find_socket_ioctlsocket(const char *name, int logdepth, int fatal)
 
 	sprintf(test_c, test_c_temp, "int", "");
 	if (try_socket(logdepth, "libs/socket/ioctl", "", test_c, NULL, NULL, 0)) {
+		found1:;
 		put("libs/socket/ioctl/ioctl", "ioctl");
 		put("libs/socket/ioctl/presents", strue);
 		put("libs/socket/ioctl/argtype", "int");
@@ -286,6 +291,14 @@ int find_socket_ioctlsocket(const char *name, int logdepth, int fatal)
 		return 0;
 	}
 
+	/* OSX */
+	if (try_socket(logdepth, "libs/socket/ioctl", "#include <sys/ioctl.h>", test_c, NULL, NULL, 0))
+		goto found1;
+
+	/* Solaris / OpenIndiana */
+	if (try_socket(logdepth, "libs/socket/ioctl", "#include <sys/socket.h>\\n#include <sys/ioctl.h>", test_c, NULL, "-lsocket", 0))
+		goto found1;
+
 	sprintf(test_c, test_c_temp, "u_long", "socket");
 	ldf = get("libs/socket/socket/ldflags");
 	if (try_socket(logdepth, "libs/socket/ioctl", "", test_c, NULL, ldf, 0)) {
@@ -306,6 +319,7 @@ int find_socket_fionbio(const char *name, int logdepth, int fatal)
 {
 	const char *ldf;
 	char test_cf[] =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	int s;"
 		NL "	%s nonblocking = 1;"
@@ -353,6 +367,17 @@ int find_socket_fionbio(const char *name, int logdepth, int fatal)
 		return 0;
 	}
 
+	/* Solaris / OpenIndiana; manual inclusion of filio.h is required because
+	   ioctl.h also includes filio.h; BSD_COMP won't be #defined because
+	   most code will first #include ioctl from libs/socket/ioctl not from
+	   fionbio. */
+	sprintf(test_c, test_cf, get("libs/socket/ioctl/argtype"), get("libs/socket/ioctl/ioctl"));
+	if (try_socket(logdepth, "libs/socket/ioctl/fionbio", "#include <sys/socket.h>\\n#include <sys/filio.h>", test_c, NULL, "-lsocket", 0)) {
+		put("libs/socket/ioctl/fionbio/presents", strue);
+		report("found (Solaris style)\n");
+		return 0;
+	}
+
 	put("libs/socket/ioctl/fionbio/presents", sfalse);
 	report("not found\n");
 	return 1;
@@ -361,6 +386,7 @@ int find_socket_fionbio(const char *name, int logdepth, int fatal)
 int find_socket_closesocket(const char *name, int logdepth, int fatal)
 {
 	char test_c[] =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	int s;"
 		NL "	SOCK_INIT;"
@@ -395,6 +421,7 @@ int find_socket_closesocket(const char *name, int logdepth, int fatal)
 int find_socket_SHUT(const char *name, int logdepth, int fatal)
 {
 	char test_c[] =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	int i;"
 		NL "	i = SHUT_WR + SHUT_RD + SHUT_RDWR;"
@@ -427,6 +454,7 @@ int find_socket_SHUT(const char *name, int logdepth, int fatal)
 int find_socket_SD(const char *name, int logdepth, int fatal)
 {
 	char test_c[] =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	int i;"
 		NL "	i = SD_RECEIVE + SD_SEND + SD_BOTH;"
@@ -458,6 +486,7 @@ int find_socket_shutdown(const char *name, int logdepth, int fatal)
 {
 	const char *ldf;
 	char test_c[] =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	int s;"
 		NL "	SOCK_INIT;"
@@ -552,7 +581,7 @@ static char *test_lac =
 	NL "int main() {"
 	NL "	struct sockaddr_in sa;"
 	NL "	char buff[64];"
-	NL "	int ls, cs, as;"
+	NL "	int ls, cs, as, b, n;"
 	NL ""
 	NL "	SOCK_INIT;"
 	NL "	ls = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);"
@@ -562,7 +591,14 @@ static char *test_lac =
 	NL "	sa.sin_family      = AF_INET;"
 	NL "	sa.sin_addr.s_addr =  %s;"
 	NL "	sa.sin_port = %d;"
-	NL "	bind(ls, (struct sockaddr *)&sa, sizeof(sa));"
+	NL "	for(n = 0; n < 32; n++) {"
+	NL "		b = bind(ls, (struct sockaddr *)&sa, sizeof(sa));"
+	NL "		if (b == 0)"
+	NL "			break;"
+	NL "	sa.sin_port += %d; /* if failed to bind prot, try another */"
+	NL "	}"
+	NL "		if (b != 0) /* failed to bind any port in many tries */"
+	NL "			return 1;"
 	NL "	fprintf(stderr, \"l=%%d ls=%%d\\n\", listen(ls, 2), ls);"
 	NL "	fprintf(stderr, \"c=%%d cs=%%d\\n\", connect(cs, (struct sockaddr *)&sa, sizeof(sa)), cs);"
 	NL "	as = accept(ls, NULL, NULL);"
@@ -585,7 +621,8 @@ static const char *localhost(void)
 int find_socket_lac(const char *name, int logdepth, int fatal)
 {
 	const char *ldf;
-	char test_c[1024];
+	char test_c[2048];
+	int test_lac_port_inc;
 
 	char *inc_linux =
 		NL;
@@ -613,8 +650,15 @@ int find_socket_lac(const char *name, int logdepth, int fatal)
 
 	srand(time(NULL));
 	test_lac_port ^= (rand() % 10000);
+	if (test_lac_port > 65500)
+		test_lac_port -= 65500;
+	if (test_lac_port < 1024)
+		test_lac_port += 1024;
 
-	sprintf(test_c, test_lac, inc_dns, localhost(), test_lac_port++, "");
+
+	test_lac_port_inc = (rand() % 32);
+
+	sprintf(test_c, test_lac, inc_dns, localhost(), test_lac_port++, test_lac_port_inc, "");
 	free(inc_dns);
 
 	ldf = get("libs/socket/socket/ldflags");
@@ -630,7 +674,8 @@ int find_socket_lac(const char *name, int logdepth, int fatal)
 int find_socket_recvsend(const char *name, int logdepth, int fatal)
 {
 	const char *ldf;
-	char test_c[1024];
+	int test_lac_port_inc;
+	char test_c[2048];
 
 	char *test_local =
 		NL "*buff = '\\0';"
@@ -665,7 +710,9 @@ int find_socket_recvsend(const char *name, int logdepth, int fatal)
 	logprintf(logdepth, "find_socket_recvsend: trying to find recv() and send()...\n");
 	logdepth++;
 
-	sprintf(test_c, test_lac, inc_dns, localhost(), test_lac_port++, test_local);
+	test_lac_port_inc = (rand() % 32);
+
+	sprintf(test_c, test_lac, inc_dns, localhost(), test_lac_port++, test_lac_port_inc, test_local);
 	free(inc_dns);
 
 	ldf = get("libs/socket/socket/ldflags");
@@ -680,7 +727,8 @@ int find_socket_recvsend(const char *name, int logdepth, int fatal)
 
 int find_socket_readwrite(const char *name, int logdepth, int fatal)
 {
-	char test_c[1024];
+	char test_c[2048];
+	int test_lac_port_inc;
 
 	char *test_local =
 		NL "*buff = '\\0';"
@@ -712,7 +760,9 @@ int find_socket_readwrite(const char *name, int logdepth, int fatal)
 	logprintf(logdepth, "find_socket_recvsend: trying to find read() and write()...\n");
 	logdepth++;
 
-	sprintf(test_c, test_lac, inc_dns, localhost(), test_lac_port++, test_local);
+	test_lac_port_inc = (rand() % 32);
+
+	sprintf(test_c, test_lac, inc_dns, localhost(), test_lac_port++, test_lac_port_inc, test_local);
 	free(inc_dns);
 
 	/* Look at some standard places */
@@ -726,6 +776,7 @@ int find_socket_readwrite(const char *name, int logdepth, int fatal)
 int find_socket_ntoh(const char *name, int logdepth, int fatal)
 {
 	char test_c[] =
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	short int sh;"
 		NL "	long int ln;"
