@@ -183,6 +183,7 @@ static void pcb_buffer_clear_(pcb_board_t *pcb, pcb_buffer_t *Buffer, rnd_bool b
 			pcb_data_bind_board_layers(pcb, Buffer->Data, 0);
 	}
 	Buffer->from_outside = 0;
+	Buffer->from_bottom_side = 0;
 	free(Buffer->source_path); Buffer->source_path = NULL;
 	Buffer->X = Buffer->Y = 0;
 }
@@ -224,6 +225,7 @@ static void pcb_buffer_toss_selected(pcb_opfunc_t *fnc, pcb_board_t *pcb, pcb_bu
 		Buffer->Y = pcb_crosshair.Y;
 	}
 	Buffer->from_outside = 0;
+	Buffer->from_bottom_side = (PCB_LYT_VISIBLE_SIDE() == PCB_LYT_BOTTOM);
 	free(Buffer->source_path); Buffer->source_path = NULL;
 	rnd_hid_notify_crosshair_change(hidlib, rnd_true);
 }
@@ -296,7 +298,7 @@ fgw_error_t pcb_act_LoadPixmap(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (fn == NULL) {
 		static char *default_file = NULL;
 		char *nfn;
-		nfn = rnd_gui->fileselect(rnd_gui, "Load pixmap into buffer gfx...",
+		nfn = rnd_hid_fileselect(rnd_gui, "Load pixmap into buffer gfx...",
 			"Choose a file to load the pixmap\nfor the gfx object to be created\nin the buffer.\n",
 			default_file, ".*", NULL, "gfx", RND_HID_FSD_READ | RND_HID_FSD_MAY_NOT_EXIST, NULL);
 		if (default_file != NULL) {
@@ -352,6 +354,7 @@ rnd_bool pcb_buffer_load_layout(pcb_board_t *pcb, pcb_buffer_t *Buffer, const ch
 		pcb_board_free(newPCB);
 		free(newPCB);
 		Buffer->from_outside = 0; /* always place matching top-to-top, don't swap sides only because the user is viewing the board from the bottom */
+		Buffer->from_bottom_side = 0;
 		free(Buffer->source_path); Buffer->source_path = rnd_strdup(Filename);
 		PCB = orig;
 		pcb_layergrp_inhibit_dec();
@@ -366,6 +369,7 @@ rnd_bool pcb_buffer_load_layout(pcb_board_t *pcb, pcb_buffer_t *Buffer, const ch
 	PCB = orig;
 	pcb_layergrp_inhibit_dec();
 	Buffer->from_outside = 0;
+	Buffer->from_bottom_side = 0;
 	free(Buffer->source_path); Buffer->source_path = NULL;
 	return rnd_false;
 }
@@ -468,7 +472,7 @@ void pcb_buffer_rotate(pcb_buffer_t *Buffer, rnd_angle_t angle)
 	PCB_ENDALL_LOOP;
 	PCB_TEXT_ALL_LOOP(Buffer->Data);
 	{
-		pcb_text_rotate(text, Buffer->X, Buffer->Y, cosa, sina, angle);
+		pcb_text_rotate(text, Buffer->X, Buffer->Y, cosa, sina, (PCB_FLAG_TEST(PCB_FLAG_ONSOLDER, text) ? -angle : angle));
 	}
 	PCB_ENDALL_LOOP;
 	PCB_POLY_ALL_LOOP(Buffer->Data);
@@ -959,6 +963,7 @@ rnd_bool pcb_buffer_load_footprint(pcb_buffer_t *Buffer, const char *Name, const
 		Buffer->X = 0;
 		Buffer->Y = 0;
 		Buffer->from_outside = 1;
+		Buffer->from_bottom_side = 0;
 		free(Buffer->source_path); Buffer->source_path = rnd_strdup(Name);
 
 		if (pcb_subclist_length(&Buffer->Data->subc)) {
@@ -1080,7 +1085,7 @@ static fgw_error_t pcb_act_PasteBuffer(fgw_arg_t *res, int argc, fgw_arg_t *argv
 		case F_SaveAll:
 			free_name = rnd_false;
 			if (argc <= 2) {
-				name = rnd_gui->fileselect(rnd_gui, "Save Paste Buffer As ...",
+				name = rnd_hid_fileselect(rnd_gui, "Save Paste Buffer As ...",
 					"Choose a file to save the contents of the\npaste buffer to.\n",
 					default_file, ".lht", NULL, "buffer", 0, NULL);
 
@@ -1114,7 +1119,7 @@ static fgw_error_t pcb_act_PasteBuffer(fgw_arg_t *res, int argc, fgw_arg_t *argv
 		case F_LoadAll:
 			free_name = rnd_false;
 			if (argc <= 2) {
-				name = rnd_gui->fileselect(rnd_gui, "Load Paste Buffer ...",
+				name = rnd_hid_fileselect(rnd_gui, "Load Paste Buffer ...",
 					"Choose a file to load the contents of the\npaste buffer from.\n",
 					default_file, ".lht", NULL, "buffer", RND_HID_FSD_READ | RND_HID_FSD_MAY_NOT_EXIST, NULL);
 
