@@ -59,7 +59,7 @@ void pcb_conf_legacy(const char *dst_path, const char *legacy_path)
 }
 
 
-static void conf_core_postproc(void)
+void pcb_conf_core_postproc(void)
 {
 	htpp_entry_t *e;
 
@@ -119,8 +119,7 @@ void conf_core_init(void)
 #define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
 	rnd_conf_reg_field(conf_core, field,isarray,type_name,cpath,cname,desc,flags);
 #include "conf_core_fields.h"
-	rnd_conf_core_postproc = conf_core_postproc;
-	conf_core_postproc();
+	pcb_conf_core_postproc();
 
 	cbs.val_change_post = conf_legacy_chg;
 	rnd_conf_hid_reg(conf_core_cookie, &cbs);
