@@ -32,7 +32,7 @@
 #define	PCB_DATA_H
 
 #include "globalconst.h"
-#include "global_typedefs.h"
+#include <librnd/core/global_typedefs.h>
 #include "layer.h"
 #include "crosshair.h"
 #include "buffer.h"
@@ -40,7 +40,7 @@
 #include "obj_rat_list.h"
 #include "obj_subc_list.h"
 #include "obj_pstk_list.h"
-#include "rtree2_compat.h"
+#include <librnd/poly/rtree2_compat.h>
 #include "vtpadstack.h"
 #include <genht/htip.h>
 
@@ -55,7 +55,7 @@ struct pcb_data_s {
 	padstacklist_t padstack;
 	pcb_subclist_t subc;
 /**/
-	pcb_rtree_t *padstack_tree, *subc_tree, *rat_tree;
+	rnd_rtree_t *padstack_tree, *subc_tree, *rat_tree;
 	pcb_layer_t Layer[PCB_MAX_LAYER]; /* layer TODO: make this dynamic */
 	pcb_plug_io_t *loader;
 	ratlist_t Rat;
@@ -77,7 +77,7 @@ extern pcb_buffer_t pcb_buffers[PCB_MAX_BUFFER];
 extern int pcb_added_lines;
 extern int pcb_layer_stack[PCB_MAX_LAYER];
 
-extern pcb_bool pcb_bumped;
+extern rnd_bool pcb_bumped;
 
 /****** callback based loops *****/
 
@@ -96,6 +96,7 @@ typedef void (*pcb_line_cb_t)(void *ctx, pcb_board_t *pcb, pcb_layer_t *layer, p
 typedef void (*pcb_arc_cb_t)(void *ctx, pcb_board_t *pcb, pcb_layer_t *layer, pcb_arc_t *arc);
 typedef void (*pcb_text_cb_t)(void *ctx, pcb_board_t *pcb, pcb_layer_t *layer, pcb_text_t *text);
 typedef void (*pcb_poly_cb_t)(void *ctx, pcb_board_t *pcb, pcb_layer_t *layer, pcb_poly_t *poly);
+typedef void (*pcb_gfx_cb_t)(void *ctx, pcb_board_t *pcb, pcb_layer_t *layer, pcb_gfx_t *gfx);
 
 /* subc callbacks */
 typedef int (*pcb_subc_cb_t)(void *ctx, pcb_board_t *pcb, pcb_subc_t *subc, int enter);
@@ -104,14 +105,14 @@ typedef int (*pcb_subc_cb_t)(void *ctx, pcb_board_t *pcb, pcb_subc_t *subc, int
 typedef void (*pcb_pstk_cb_t)(void *ctx, pcb_board_t *pcb, pcb_pstk_t *ps);
 
 /* Loop over all layer objects on each layer. Layer is the outer loop. */
-void pcb_loop_layers(pcb_board_t *pcb, void *ctx, pcb_layer_cb_t lacb, pcb_line_cb_t lcb, pcb_arc_cb_t acb, pcb_text_cb_t tcb, pcb_poly_cb_t pocb);
+void pcb_loop_layers(pcb_board_t *pcb, void *ctx, pcb_layer_cb_t lacb, pcb_line_cb_t lcb, pcb_arc_cb_t acb, pcb_text_cb_t tcb, pcb_poly_cb_t pocb, pcb_gfx_cb_t gcb);
 
 /* Loop over all subcircuits. */
 void pcb_loop_subc(pcb_board_t *pcb, void *ctx, pcb_subc_cb_t scb);
 
 /* Loop over all design objects. (So all the above three in one call.) */
 void pcb_loop_all(pcb_board_t *pcb, void *ctx,
-	pcb_layer_cb_t lacb, pcb_line_cb_t lcb, pcb_arc_cb_t acb, pcb_text_cb_t tcb, pcb_poly_cb_t pocb,
+	pcb_layer_cb_t lacb, pcb_line_cb_t lcb, pcb_arc_cb_t acb, pcb_text_cb_t tcb, pcb_poly_cb_t pocb, pcb_gfx_cb_t gcb,
 	pcb_subc_cb_t scb,
 	pcb_pstk_cb_t pscb
 );
@@ -128,12 +129,12 @@ void pcb_data_uninit(pcb_data_t *data);
 /* Calls pcb_data_uninit() and free data */
 void pcb_data_free(pcb_data_t *data);
 
-pcb_bool pcb_data_is_empty(pcb_data_t *);
+rnd_bool pcb_data_is_empty(pcb_data_t *);
 
 /* gets minimum and maximum coordinates
  * returns NULL if layout is empty */
-pcb_box_t *pcb_data_bbox(pcb_box_t *out, pcb_data_t *Data, pcb_bool ignore_floaters);
-pcb_box_t *pcb_data_bbox_naked(pcb_box_t *out, pcb_data_t *Data, pcb_bool ignore_floaters);
+rnd_box_t *pcb_data_bbox(rnd_box_t *out, pcb_data_t *Data, rnd_bool ignore_floaters);
+rnd_box_t *pcb_data_bbox_naked(rnd_box_t *out, pcb_data_t *Data, rnd_bool ignore_floaters);
 
 /* Make sure all layers of data has their .parent field pointing to the data */
 void pcb_data_set_layer_parents(pcb_data_t *data);
@@ -152,7 +153,7 @@ void pcb_data_binding_update(pcb_board_t *pcb, pcb_data_t *data);
 void pcb_data_unbind_layers(pcb_data_t *data);
 
 /* Make sure there are no negative coords in data, knowing the bbox of the data */
-int pcb_data_normalize_(pcb_data_t *data, pcb_box_t *data_bbox);
+int pcb_data_normalize_(pcb_data_t *data, rnd_box_t *data_bbox);
 
 /* Make sure there are no negative coords in data (calculates the bbox of the data) */
 int pcb_data_normalize(pcb_data_t *data);
@@ -166,13 +167,24 @@ pcb_board_t *pcb_data_get_top(pcb_data_t *data);
 void pcb_data_set_parent_globals(pcb_data_t *data, pcb_data_t *new_parent);
 
 typedef enum pcb_data_mirror_text_e {
+	/* main operation - choose one: */
 	PCB_TXM_NONE = 0, /* do not mirror text */
-	PCB_TXM_SIDE = 1, /* mirror text, changing side */
-	PCB_TXM_COORD    /* mirror text base coords only */
-} pcb_data_mirror_text_t;
-void pcb_data_mirror(pcb_data_t *data, pcb_coord_t y_offs, pcb_data_mirror_text_t mtxt, pcb_bool pstk_smirror);
+	PCB_TXM_SIDE,     /* mirror text, changing side */
+	PCB_TXM_COORD,    /* mirror text base coords only */
 
-void pcb_data_move(pcb_data_t *data, pcb_coord_t dx, pcb_coord_t dy, int undoable);
+	/* modifier bits, can be OR'd: */
+	PCB_TXM_ROT = 32,  /* mirror text rotation angle */
+
+	/* msic */
+	PCB_TXM_MASK_OP = PCB_TXM_ROT-1
+} pcb_data_mirror_text_t;
+
+
+
+
+void pcb_data_mirror(pcb_data_t *data, rnd_coord_t y_offs, pcb_data_mirror_text_t mtxt, rnd_bool pstk_smirror, rnd_bool undoable);
+
+void pcb_data_move(pcb_data_t *data, rnd_coord_t dx, rnd_coord_t dy, int undoable);
 
 /* Multiply x and y coords by sx and sy and thickness by sth (where applicable).
    If recurse is non-zero, also modify subcircuits */
@@ -183,10 +195,10 @@ void pcb_data_clip_polys(pcb_data_t *data);
 
 
 /* rsearch on all trees matching types of data */
-pcb_r_dir_t pcb_data_r_search(pcb_data_t *data, pcb_objtype_t types, const pcb_box_t *starting_region,
-						 pcb_r_dir_t (*region_in_search) (const pcb_box_t *region, void *cl),
-						 pcb_r_dir_t (*rectangle_in_region) (const pcb_box_t *box, void *cl),
-						 void *closure, int *num_found, pcb_bool vis_only);
+rnd_r_dir_t pcb_data_r_search(pcb_data_t *data, pcb_objtype_t types, const rnd_box_t *starting_region,
+						 rnd_r_dir_t (*region_in_search) (const rnd_box_t *region, void *cl),
+						 rnd_r_dir_t (*rectangle_in_region) (const rnd_box_t *box, void *cl),
+						 void *closure, int *num_found, rnd_bool vis_only);
 
 /* Either pcb->data or the subcircuit's data if PCB is a subc (footprint edit mode) */
 #define PCB_REAL_DATA(pcb) \
@@ -201,15 +213,15 @@ void pcb_data_clip_inhibit_inc(pcb_data_t *data);
 /* decrease the inhibit counter - if it's zero, reclip all dirty polygons;
    enable_progbar controls whether a progress bar is drawn for reclips
    that take longer than a few seconds. */
-void pcb_data_clip_inhibit_dec(pcb_data_t *data, pcb_bool enable_progbar);
+void pcb_data_clip_inhibit_dec(pcb_data_t *data, rnd_bool enable_progbar);
 
 /* attempt to reclip all dirty polygons; normally called by
    pcb_data_clip_inhibit_dec(). */
-void pcb_data_clip_dirty(pcb_data_t *data, pcb_bool enable_progbar);
+void pcb_data_clip_dirty(pcb_data_t *data, rnd_bool enable_progbar);
 
 /* Force reclip all polygons; useful after a move-everything kind
    of operation (e.g. autocrop()) */
-void pcb_data_clip_all(pcb_data_t *data, pcb_bool enable_progbar);
+void pcb_data_clip_all(pcb_data_t *data, rnd_bool enable_progbar);
 
 
 /* Recursively change flags of data; how is one of pcb_change_flag_t */
