@@ -136,7 +136,7 @@ RND_INLINE void pcb_find_mark_set_pstk(pcb_find_t *ctx, pcb_any_obj_t *obj, pcb_
 				break;
 			case PCB_OBJ_PSTK:
 				if (arrived_from != obj)
-					rnd_message(RND_MSG_ERROR, "BUG: disjoint padstack overlap with disjoint padstack - not handled correctly\nPlease report htis bug with your board file!\n");
+					rnd_message(RND_MSG_ERROR, "BUG: disjoint padstack overlap with disjoint padstack - not handled correctly\nPlease report this bug with your board file!\n");
 				goto fallback1;
 			default:
 				assert(!"pcb_find_mark_set: invalid arrived_from object type");
@@ -196,7 +196,7 @@ RND_INLINE int pcb_find_mark_get_pstk(pcb_find_t *ctx, pcb_any_obj_t *obj, pcb_a
 				return !!(mm->layers[lid / 8] & (1 << (lid % 8)));
 			case PCB_OBJ_PSTK:
 				if (arrived_from != obj)
-					rnd_message(RND_MSG_ERROR, "BUG: disjoint padstack overlap with disjoint padstack - not handled correctly\nPlease report htis bug with your board file!\n");
+					rnd_message(RND_MSG_ERROR, "BUG: disjoint padstack overlap with disjoint padstack - not handled correctly\nPlease report this bug with your board file!\n");
 				return 1;
 			default:
 				assert(!"pcb_find_mark_get: invalid arrived_from object type");
@@ -467,7 +467,16 @@ static unsigned long pcb_find_exec(pcb_find_t *ctx)
 		{ /* search unmkared connections: iterative approach */
 			rnd_rtree_it_t it;
 			rnd_box_t *n;
-			rnd_rtree_box_t *sb = (rnd_rtree_box_t *)&curr->bbox_naked;
+			rnd_rtree_box_t *sb, tmpsb;
+
+			if (ctx->bloat > 0) { /* for a bloated search bloat up the search box so it won't miss anything */
+				tmpsb = *((rnd_rtree_box_t *)&curr->bbox_naked);
+				tmpsb.x1 -= ctx->bloat; tmpsb.y1 -= ctx->bloat;
+				tmpsb.x2 += ctx->bloat; tmpsb.y2 += ctx->bloat;
+				sb = &tmpsb;
+			}
+			else
+				sb = (rnd_rtree_box_t *)&curr->bbox_naked;
 
 			if (PCB->Data->padstack_tree != NULL)
 				for(n = rnd_rtree_first(&it, PCB->Data->padstack_tree, sb); n != NULL; n = rnd_rtree_next(&it))
