@@ -50,6 +50,15 @@
 
 #define Bloat ctx->bloat
 
+/* For clearance vs. object because clearance doesn't really touch the object
+   so a few nanometers of overlap is required */
+#define THERMAL_EXTRA_BLOAT 2
+
+/* When object has clearance to a given polygon, shrink it a few nanometers to
+   avoid false positives in drc-kind lookups, e.g. when requirement is 10mil
+   clearance and clearance is exactly 10mil */
+#define CLEARANCE_EXTRA_BLOAT -4
+
 /* This is required for fullpoly: whether an object bbox intersects a poly
    bbox can't be determined by a single contour check because there might be
    multiple contours. Returns 1 if obj bbox intersects any island's bbox */
@@ -692,18 +701,18 @@ rnd_bool pcb_isc_arc_polyarea(const pcb_find_t *ctx, pcb_arc_t *Arc, rnd_polyare
  * - check the two end points of the line. If none of them matches
  * - check all segments of the polygon against the line.
  */
-rnd_bool pcb_isc_line_poly(const pcb_find_t *ctx, pcb_line_t *Line, pcb_poly_t *Polygon)
+static rnd_bool pcb_isc_line_poly_blt(const pcb_find_t *ctx, pcb_line_t *Line, pcb_poly_t *Polygon, rnd_coord_t bloat)
 {
 	rnd_box_t *Box = (rnd_box_t *) Line;
 	rnd_polyarea_t *lp;
 
 	/* lines with clearance never touch polygons */
-	if ((Bloat == 0) && !ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLY, Polygon) && PCB_OBJ_HAS_CLEARANCE(Line))
+	if ((bloat == 0) && !ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLY, Polygon) && PCB_OBJ_HAS_CLEARANCE(Line))
 		return rnd_false;
 	if (!Polygon->Clipped)
 		return rnd_false;
 	if (PCB_FLAG_TEST(PCB_FLAG_SQUARE, Line) && (Line->Point1.X == Line->Point2.X || Line->Point1.Y == Line->Point2.Y)) {
-		rnd_coord_t wid = (Line->Thickness + Bloat + 1) / 2;
+		rnd_coord_t wid = (Line->Thickness + bloat + 1) / 2;
 		rnd_coord_t x1, x2, y1, y2;
 
 		x1 = MIN(Line->Point1.X, Line->Point2.X) - wid;
@@ -713,13 +722,85 @@ rnd_bool pcb_isc_line_poly(const pcb_find_t *ctx, pcb_line_t *Line, pcb_poly_t *
 		return pcb_poly_is_rect_in_p(x1, y1, x2, y2, Polygon);
 	}
 	if (box_isc_poly_any_island_bbox(ctx, Box, Polygon, !PCB_FLAG_TEST(PCB_FLAG_FULLPOLY, Polygon))) {
-		if (!(lp = pcb_poly_from_pcb_line(Line, Line->Thickness + Bloat)))
+		if (!(lp = pcb_poly_from_pcb_line(Line, Line->Thickness + bloat)))
 			return rnd_false;							/* error */
 		return box_isc_poly_any_island_free(lp, Polygon, !PCB_FLAG_TEST(PCB_FLAG_FULLPOLY, Polygon));
 	}
 	return rnd_false;
 }
 
+rnd_bool pcb_isc_line_poly(const pcb_find_t *ctx, pcb_line_t *Line, pcb_poly_t *Polygon)
+{
+	return pcb_isc_line_poly_blt(ctx, Line, Polygon, Bloat);
+}
+
+
+/* Bloated pline-pline intersection test: trace c1 using thick lines to see if
+   it ever touches c2 */
+rnd_bool pcb_isc_poly_poly_bloated(const pcb_find_t *ctx, rnd_pline_t *c1, rnd_pline_t *c2, pcb_poly_t *P2, rnd_coord_t extra_bloat)
+{
+	rnd_pline_t *c;
+	rnd_coord_t bloat = Bloat + extra_bloat;
+
+	/* this won't work with negative bloat: we can't draw a line with negative thickness */
+	if (bloat <= 0) bloat = 4;
+
+	if (!((c1->xmin - bloat <= c2->xmax) && (c2->xmin <= c1->xmax + bloat) && (c1->ymin - bloat <= c2->ymax) && (c2->ymin <= c1->ymax + bloat)))
+		return rnd_false;
+
+	for (c = c1; c; c = c->next) {
+		pcb_line_t line = {0};
+		rnd_vnode_t *v = c->head;
+		if (c->xmin - bloat <= c2->xmax && c->xmax + bloat >= c2->xmin &&
+				c->ymin - bloat <= c2->ymax && c->ymax + bloat >= c2->ymin) {
+
+			line.Point1.X = v->point[0];
+			line.Point1.Y = v->point[1];
+			line.Thickness = bloat;
+			line.Clearance = 0;
+			line.Flags = pcb_no_flags();
+			for (v = v->next; v != c->head; v = v->next) {
+				line.Point2.X = v->point[0];
+				line.Point2.Y = v->point[1];
+				pcb_line_bbox(&line);
+TODO("This is very expensive: we could use something cheaper here that checks the two offseted thin line edges and one of the end cap circles");
+				if (pcb_isc_line_poly_blt(ctx, &line, P2, bloat))
+					return rnd_true;
+				line.Point1.X = line.Point2.X;
+				line.Point1.Y = line.Point2.Y;
+			}
+		}
+	}
+
+	return rnd_false;
+}
+
+static rnd_coord_t get_extra_bloat(pcb_any_obj_t *ps, pcb_poly_t *poly)
+{
+	rnd_layer_id_t poly_lid = pcb_layer2id(poly->parent.layer->parent.data, poly->parent.layer);
+	unsigned char *thr;
+
+	if (!PCB_FLAG_TEST(PCB_FLAG_CLEARPOLY, poly))
+		return 0; /* poly is not clearing: no thermal or clearance possible, use true sizes */
+
+ /*if  obj is not clearing: no thermal or clearance possible, use true sizes */
+	if (ps->type == PCB_OBJ_POLY) {
+		if (!PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, ps))
+			return 0;
+	}
+	else {
+		if (!PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, ps))
+			return 0;
+	}
+
+	thr = pcb_obj_common_get_thermal(ps, poly_lid, 0);
+	if ((thr != NULL) && (*thr & PCB_THERMAL_ON) && ((*thr & 0x07) != 0))
+		return THERMAL_EXTRA_BLOAT;
+
+	return CLEARANCE_EXTRA_BLOAT;
+}
+
+
 /* ---------------------------------------------------------------------------
  * checks if a polygon has a connection to a second one
  *
@@ -790,32 +871,11 @@ rnd_bool pcb_isc_poly_poly(const pcb_find_t *ctx, pcb_poly_t *P1, pcb_poly_t *P2
 		for(pa1 = pcb_poly_island_first(P1, &it1); pa1 != NULL; pa1 = pcb_poly_island_next(&it1)) {
 			rnd_pline_t *c1 = pcb_poly_contour(&it1);
 			for(pa2 = pcb_poly_island_first(P2, &it2); pa2 != NULL; pa2 = pcb_poly_island_next(&it2)) {
-				rnd_pline_t *c, *c2 = pcb_poly_contour(&it2);
+				rnd_pline_t *c2 = pcb_poly_contour(&it2);
+				rnd_coord_t extra_bloat = get_extra_bloat((pcb_any_obj_t *)P1, P2);
+				if (pcb_isc_poly_poly_bloated(ctx, c1, c2, P2, extra_bloat))
+					return rnd_true;
 
-				if (!((c1->xmin - Bloat <= c2->xmax) && (c2->xmin <= c1->xmax + Bloat) &&
-					  (c1->ymin - Bloat <= c2->ymax) && (c2->ymin <= c1->ymax + Bloat))) continue;
-				for (c = c1; c; c = c->next) {
-					pcb_line_t line;
-					rnd_vnode_t *v = c->head;
-					if (c->xmin - Bloat <= c2->xmax && c->xmax + Bloat >= c2->xmin &&
-							c->ymin - Bloat <= c2->ymax && c->ymax + Bloat >= c2->ymin) {
-
-						line.Point1.X = v->point[0];
-						line.Point1.Y = v->point[1];
-						line.Thickness = 2 * Bloat;
-						line.Clearance = 0;
-						line.Flags = pcb_no_flags();
-						for (v = v->next; v != c->head; v = v->next) {
-							line.Point2.X = v->point[0];
-							line.Point2.Y = v->point[1];
-							pcb_line_bbox(&line);
-							if (pcb_isc_line_poly(ctx, &line, P2))
-								return rnd_true;
-							line.Point1.X = line.Point2.X;
-							line.Point1.Y = line.Point2.Y;
-						}
-					}
-				}
 				if (!PCB_FLAG_TEST(PCB_FLAG_FULLPOLY, P2))
 					break;
 			}
@@ -839,11 +899,11 @@ RND_INLINE rnd_bool_t pcb_isc_line_polyline(const pcb_find_t *ctx, rnd_pline_t *
 
 	/* single-point line - check only one circle*/
 	if ((x1 == x2) && (y1 == y2))
-		return pcb_pline_overlaps_circ(pl, x1, y1, thick/2);
+		return rnd_pline_overlaps_circ(pl, x1, y1, thick/2);
 
 	/* long line - check ends */
-	if (pcb_pline_overlaps_circ(pl, x1, y1, thick/2)) return rnd_true;
-	if (pcb_pline_overlaps_circ(pl, x2, y2, thick/2)) return rnd_true;
+	if (rnd_pline_overlaps_circ(pl, x1, y1, thick/2)) return rnd_true;
+	if (rnd_pline_overlaps_circ(pl, x2, y2, thick/2)) return rnd_true;
 
 	dx = x2 - x1;
 	dy = y2 - y1;
@@ -855,8 +915,8 @@ RND_INLINE rnd_bool_t pcb_isc_line_polyline(const pcb_find_t *ctx, rnd_pline_t *
 	vy = (double)dy / -l * ((double)Bloat/2.0);
 
 	/* long line - consider edge intersection */
-	if (pcb_pline_isect_line(pl, x1 + ox + vx, y1 + oy + vy, x2 + ox - vx, y2 + oy - vy, NULL, NULL)) return rnd_true;
-	if (pcb_pline_isect_line(pl, x1 - ox + vx, y1 - oy + vy, x2 - ox - vx, y2 - oy - vy, NULL, NULL)) return rnd_true;
+	if (rnd_pline_isect_line(pl, x1 + ox + vx, y1 + oy + vy, x2 + ox - vx, y2 + oy - vy, NULL, NULL)) return rnd_true;
+	if (rnd_pline_isect_line(pl, x1 - ox + vx, y1 - oy + vy, x2 - ox - vx, y2 - oy - vy, NULL, NULL)) return rnd_true;
 
 	/* A corner case is when the polyline is fully within the line. By now we
 	   are sure there's no contour intersection, so if any of the polyline points
@@ -869,7 +929,7 @@ RND_INLINE rnd_bool_t pcb_isc_line_polyline(const pcb_find_t *ctx, rnd_pline_t *
 		q[2][0] = x1 - ox; q[2][1] = y1 - oy;
 		q[3][0] = x2 - ox; q[3][1] = y2 - oy;
 
-		return pcb_is_point_in_convex_quad(pl->head->point, q);
+		return rnd_is_point_in_convex_quad(pl->head->point, q);
 	}
 }
 
@@ -919,7 +979,11 @@ rnd_bool_t pcb_isc_pstk_line_shp(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_line
 			if (!proto->hplated)
 				return 0;
 
-			slshape = pcb_pstk_shape_mech_or_hole_at(PCB, ps, line->parent.layer, &sltmp);
+			if (line->parent.layer != NULL)
+				slshape = pcb_pstk_shape_mech_or_hole_at(PCB, ps, line->parent.layer, &sltmp);
+			else
+				slshape = pcb_pstk_shape_mech_or_hole_(ps, proto, &sltmp); /* this happens when called from a line shaped padstack - there's no known layer ID, assume anylayer */
+			
 			if (slshape == NULL)
 				return rnd_false;
 			return pcb_isc_pstk_line_shp(ctx, ps, line, slshape);
@@ -1059,6 +1123,7 @@ RND_INLINE rnd_polyarea_t *pcb_pstk_shp_poly2area(pcb_pstk_t *ps, pcb_pstk_shape
 	return shp;
 }
 
+
 RND_INLINE rnd_bool_t pcb_isc_pstk_poly_shp(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_poly_t *poly, pcb_pstk_shape_t *shape)
 {
 	if (shape == NULL) goto noshape;
@@ -1067,9 +1132,18 @@ RND_INLINE rnd_bool_t pcb_isc_pstk_poly_shp(const pcb_find_t *ctx, pcb_pstk_t *p
 		case PCB_PSSH_POLY:
 		{
 			/* convert the shape poly to a new poly so that it can be intersected */
-			rnd_bool res;
+			rnd_bool res = rnd_false;
+			pcb_poly_it_t it2;
+			rnd_polyarea_t *pa2;
 			rnd_polyarea_t *shp = pcb_pstk_shp_poly2area(ps, shape);
-			res = rnd_polyarea_touching(shp, poly->Clipped);
+			rnd_pline_t *c1 = shp->contours;
+			rnd_coord_t extra_bloat = get_extra_bloat((pcb_any_obj_t *)ps, poly);
+
+			for(pa2 = pcb_poly_island_first(poly, &it2); pa2 != NULL; pa2 = pcb_poly_island_next(&it2)) {
+				rnd_pline_t *c2 = pcb_poly_contour(&it2);
+				if (pcb_isc_poly_poly_bloated(ctx, c1, c2, poly, extra_bloat))
+					res = rnd_true;
+			}
 			rnd_polyarea_free(&shp);
 			return res;
 		}
@@ -1152,10 +1226,24 @@ RND_INLINE rnd_bool_t pcb_isc_pstk_poly(const pcb_find_t *ctx, pcb_pstk_t *ps, p
 {
 	pcb_pstk_shape_t *shape;
 	pcb_pstk_proto_t *proto;
+	rnd_coord_t clr;
 
 	if (anylayer)
 		PCB_ISC_PSTK_ANYLAYER(ps, pcb_isc_pstk_poly_shp(ctx, ps, poly, &tshp->shape[n]));
 
+	if (PCB_FLAG_TEST(PCB_FLAG_CLEARPOLY, poly) && PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, ps)) {
+		/* optimization: if there's a clearance between the padstack and the poly, no
+		   need to calculate anything */
+		clr = pcb_obj_clearance_at(PCB, (pcb_any_obj_t *)ps, poly->parent.layer);
+		if ((clr > 0) && (ctx->bloat == 0)) {
+			unsigned char *thr = pcb_pstk_get_thermal(ps, pcb_layer2id(PCB->Data, poly->parent.layer), 0);
+
+			/* but only if there's no thermal that'd connect it through the clearance */
+			if ((thr == NULL) || (!(*thr & PCB_THERMAL_ON) || ((*thr & 0x07) == PCB_THERMAL_NOSHAPE)))
+				return rnd_false;
+		}
+	}
+
 	shape = pcb_pstk_shape_at(PCB, ps, poly->parent.layer);
 	if (pcb_isc_pstk_poly_shp(ctx, ps, poly, shape))
 		return rnd_true;
