@@ -76,7 +76,7 @@ static const char pcb_acts_Display[] =
 	"Display(SubcID, template)\n"
 	"Display(Grid|Redraw|Pinout|PinOrPadName)\n"
 	"Display(CycleClip|ToggleAllDirections|ToggleStartDirection)\n"
-	"Display(ToggleGrid|ToggleRubberBandMode|ToggleUniqueNames)\n"
+	"Display(RealignGrid|ToggleRubberBandMode|ToggleUniqueNames)\n"
 	"Display(ToggleName|ToggleClearLine|ToggleFullPoly|ToggleSnapPin)\n"
 	"Display(ToggleSnapOffGridLine|ToggleHighlightOnPoint|ToggleCheckPlanes)\n"
 	"Display(ToggleThindraw|ToggleThindrawPoly|ToggleOrthoMove|ToggleLocalRef)\n"
@@ -237,6 +237,7 @@ static fgw_error_t pcb_act_Display(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 					pcb_find_t fctx;
 					memset(&fctx, 0, sizeof(fctx));
 					fctx.flag_set = PCB_FLAG_FOUND;
+					fctx.consider_rats = 1;
 					fctx.flag_chg_undoable = 1;
 					pcb_find_from_xy(&fctx, PCB->Data, pcb_crosshair.X, pcb_crosshair.Y);
 					pcb_find_free(&fctx);
@@ -268,7 +269,8 @@ static fgw_error_t pcb_act_Display(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			break;
 
 			/* shift grid alignment */
-		case F_ToggleGrid:
+		case F_RealignGrid:
+		case F_ToggleGrid: /* for compatibility */
 			{
 				rnd_coord_t old_grid = rnd_conf.editor.grid, x, y;
 
@@ -277,7 +279,7 @@ static fgw_error_t pcb_act_Display(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				   means the user can go anywhere, but snapping will apply; if the
 				   crosshair is snapped, we are aligning to an object(point), else
 				   we are aligning to whatever fine point the user clicked */
-				rnd_hid_get_coords("Click to set the grid origin", &x, &y, 1);
+				rnd_hid_get_coords("Click to set the grid origin", &x, &y, 0);
 				if (pcb_crosshair_move_absolute(PCB_ACT_BOARD, pcb_crosshair.X, pcb_crosshair.Y))
 					rnd_hid_notify_crosshair_change(RND_ACT_HIDLIB, rnd_true); /* first notify was in MoveCrosshairAbs */
 				rnd_hidlib_set_grid(RND_ACT_HIDLIB, old_grid, rnd_true, pcb_crosshair.X, pcb_crosshair.Y);
@@ -345,6 +347,7 @@ static fgw_error_t pcb_act_Display(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 	else if (str_dir) {
 		switch(id) {
+		case F_RealignGrid:
 		case F_ToggleGrid:
 			if (argc > 3) {
 				if (fgw_arg_conv(&rnd_fgw, &argv[3], FGW_KEYWORD) != 0) {
@@ -563,7 +566,7 @@ static fgw_error_t pcb_act_RouteStyle(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	switch(*cmd) {
 		case '\0':
 			do_select:;
-			pcb_use_route_style(rts);
+			pcb_use_route_style_idx(PCB, number - 1);
 			break;
 		case 'd': /* del */
 			res->type = FGW_INT;
@@ -663,7 +666,7 @@ static const char pcb_acth_SetSame[] = "Sets current layer and sizes to match in
 static void set_same_(rnd_coord_t Thick, rnd_coord_t textt, int texts, pcb_font_id_t fid, rnd_coord_t Clearance, rnd_cardinal_t via_proto, char *Name)
 {
 	int known;
-	known = pcb_route_style_lookup_strict(&PCB->RouteStyle, Thick, textt, texts, fid, Clearance, via_proto, Name);
+	known = pcb_route_style_lookup_strict(&PCB->RouteStyle, PCB->route_style_last, Thick, textt, texts, fid, Clearance, via_proto, Name);
 	if (known < 0) {
 		/* unknown style, set properties */
 		if (Thick != -1)     { rnd_conf_set_design("design/line_thickness", "%$mS", Thick); }
@@ -675,7 +678,7 @@ static void set_same_(rnd_coord_t Thick, rnd_coord_t textt, int texts, pcb_font_
 		PCB->pen_attr = NULL;
 	}
 	else
-		pcb_use_route_style_idx(&PCB->RouteStyle, known);
+		pcb_use_route_style_idx(PCB, known);
 }
 
 static fgw_error_t pcb_act_SetSame(fgw_arg_t *res, int argc, fgw_arg_t *argv)
