@@ -142,6 +142,7 @@ struct pcb_layer_s {              /* holds information about one layer */
 			int no_drc;                    /* whether to ignore the layer when checking the design rules */
 			const char *cookie;            /* for UI layers: registration cookie; NULL for unused UI layers */
 			rnd_xform_t xform;             /* layer specified rendering transformation */
+			rnd_xform_t gui_xform;         /* GUI-render only layer specified rendering transformation */
 		} real;
 		struct { /* A subcircuit layer binding; list data are local but everything else is coming from board layers */
 			pcb_layer_t *real;             /* NULL if unbound */
@@ -151,9 +152,6 @@ struct pcb_layer_s {              /* holds information about one layer */
 			/* for comb, use the ->comb from the common part */
 			int stack_offs;                /* offset in the stack for PCB_LYT_INNER: positive is counted from primary side, negative from the opposite side */
 			char *purpose;                 /* what the target doc/mech layer is used for */
-
-			unsigned user_specified:1;     /* 1 if the user forced the binding */
-			rnd_layer_id_t user_lid;
 		} bound;
 	} meta;
 
@@ -164,9 +162,10 @@ struct pcb_layer_s {              /* holds information about one layer */
 rnd_layer_id_t pcb_layer_id(const pcb_data_t *Data, const pcb_layer_t *Layer);
 
 
-/* the offsets of the two additional special layers (e.g. silk) for 'component'
-   and 'solder'. The offset of PCB_MAX_LAYER is not added here. Also can be
-   used to address side of the board without referencing to groups or layers. */
+/* Sddress side of the board without referencing to groups or layers.
+   (Historical use: in io_pcb the index offsets of the two additional
+   special layers (e.g. silk) for 'component' and 'solder'.
+   The offset of PCB_MAX_LAYER is not added here.) */
 typedef enum {
 	PCB_SOLDER_SIDE    = 0,
 	PCB_COMPONENT_SIDE = 1
