@@ -41,6 +41,8 @@ static const char *EXPERIMENTAL = NULL;
 #include "brave.h"
 #include "data.h"
 #include <librnd/core/error.h>
+#include <librnd/core/compat_fs.h>
+#include <librnd/core/safe_fs.h>
 #include "plug_io.h"
 #include "buffer.h"
 #include "crosshair.h"
@@ -76,25 +78,65 @@ static const char *EXPERIMENTAL = NULL;
 #include <librnd/core/compat_misc.h>
 #include "tool_logic.h"
 #include "pixmap_pcb.h"
-
-TODO("librnd: remove this once librnd is not extern anymore")
-#include <genregex/regex_se.h>
-#include <puplug/util.h>
-#include <genvector/vtl0.h>
+#include "draw.h"
 
 #define pup_buildins pcb_rnd_buildins
 #include "buildin.c"
 #undef pup_buildins
 
-const char *rnd_menu_file_paths[4];
-const char *rnd_menu_name_fmt = "pcb-menu-%s.lht";
+static const char *menu_file_paths[4];
+static const char *menu_name_fmt = "menu-%s.lht";
 
 #define CONF_USER_DIR "~/" DOT_PCB_RND
-const char *rnd_conf_userdir_path, *rnd_pcphl_conf_user_path;
-const char *rnd_conf_sysdir_path, *rnd_conf_sys_path;
-const char *rnd_app_package = PCB_PACKAGE;
-const char *rnd_app_version = PCB_VERSION;
-const char *rnd_app_url = "http://repo.hu/projects/pcb-rnd";
+
+/* for security reasons ignore these nodes when coming from a board or project file */
+static rnd_conf_ignore_t conf_board_ignores[] = {
+	{"rc/action_string", 16, 0},
+	{"rc/library_shell", 16, 0},
+	{"rc/file_command", 15, 0},
+	{"rc/font_command", 15, 0},
+	{"rc/save_command", 15, 0},
+	{"rc/rat_command", 14, 0},
+	{NULL, 0, 0}
+};
+
+static rnd_conf_ignore_t conf_ignores[] = {
+	/* old config paths - safe to ignore */
+	{"editor/show_mask", 16, 0},
+	{"editor/show_paste", 17, 0},
+	{"editor/increments", 17, 0},
+	{"design/max_width", 16, 0},
+	{"design/max_height", 17, 0},
+	{"design/groups", 13, 1},
+	{"design/default_layer_name", 25, 1},
+
+	{NULL, 0, 0}
+};
+
+
+/* try to use new (3.x.x) config file name with a fallback to pre-3.0.0 in
+   case the old exists but the new doesn't */
+static char *conf_fn_compat(const char *dir, const char *old_name, const char *new_name)
+{
+	char *old_path, *new_path;
+
+	/* new exists: use it */
+	new_path = rnd_concat(dir, new_name, NULL);
+	if (rnd_file_readable(NULL, new_path))
+		return new_path;
+
+	/* new doesn't exist, old does; use the old and warn the user */
+	old_path = rnd_concat(dir, old_name, NULL);
+	if (rnd_file_readable(NULL, old_path)) {
+		rnd_message(RND_MSG_ERROR, "Using old (pre-3.0.0) config file name for compatibility\nPlease quit and rename %s to %s\n", old_path, new_path);
+		free(new_path);
+		return old_path;
+	}
+
+	/* neither files exist; stick with the new path in case we need to create it */
+	free(old_path);
+	return new_path;
+}
 
 /* Figure out the canonical name of the executed program
    and fix up the defaults for various paths; returns exec prefix that
@@ -189,10 +231,11 @@ static char *main_path_init(char *argv0)
 	sprintf(exec_prefix, "%s%s%s", bindir, RND_DIR_SEPARATOR_S, BINDIR_TO_EXECPREFIX);
 
 	/* export the most important paths and data for child processes (e.g. parametric footprints) */
-	tmp = rnd_concat(PCBSHAREDIR, "/pcblib", NULL);
+	tmp = rnd_concat(PCBSHAREDIR, "/footprint", NULL);
 	se |= rnd_setenv("PCB_RND_VERSION",     PCB_VERSION,           1);
 	se |= rnd_setenv("PCB_RND_REVISION",    PCB_REVISION,          1);
-	se |= rnd_setenv("PCB_RND_PCBLIB",      tmp,                   1);
+	se |= rnd_setenv("PCB_RND_PCBLIB",      tmp,                   1); /* for backward compatibility - do not use */
+	se |= rnd_setenv("PCB_RND_FOOTPRINT",   tmp,                   1);
 	se |= rnd_setenv("PCB_RND_SHARE",       PCBSHAREDIR,           1);
 	se |= rnd_setenv("PCB_RND_LIB",         PCBLIBDIR,             1);
 	se |= rnd_setenv("PCB_RND_EXEC_PREFIX", exec_prefix,           1);
@@ -201,15 +244,17 @@ static char *main_path_init(char *argv0)
 	if (se != 0)
 		fprintf(stderr, "WARNING: setenv() failed - external commands such as parametric footprints may not have a proper environment\n");
 
-	rnd_menu_file_paths[0] = "./";
-	rnd_menu_file_paths[1] = "~/.pcb-rnd/";
-	rnd_menu_file_paths[2] = rnd_concat(PCBCONFDIR, "/", NULL);
-	rnd_menu_file_paths[3] = NULL;
+	menu_file_paths[0] = "./";
+	menu_file_paths[1] = "~/.pcb-rnd/";
+	menu_file_paths[2] = rnd_concat(PCBCONFDIR, "/", NULL);
+	menu_file_paths[3] = NULL;
 
-	rnd_conf_userdir_path = CONF_USER_DIR;
-	rnd_pcphl_conf_user_path = rnd_concat(CONF_USER_DIR, "/pcb-conf.lht", NULL);
-	rnd_conf_sysdir_path = PCBCONFDIR;
-	rnd_conf_sys_path = rnd_concat(PCBCONFDIR, "/pcb-conf.lht", NULL);
+	rnd_pcbhl_conf_postproc(); /* get ~ (home dir) set */
+
+	rnd_app.conf_userdir_path = CONF_USER_DIR;
+	rnd_app.conf_user_path = conf_fn_compat(CONF_USER_DIR, "/pcb-conf.lht", "/conf_core.lht");
+	rnd_app.conf_sysdir_path = PCBCONFDIR;
+	rnd_app.conf_sys_path = conf_fn_compat(PCBCONFDIR, "/pcb-conf.lht", "/conf_core.lht");
 
 	free(bindir);
 	return exec_prefix;
@@ -218,9 +263,9 @@ static char *main_path_init(char *argv0)
 static void main_path_uninit(void)
 {
 	/* const for all other parts of the code, but we had to concat (alloc) it above */
-	free((char *)rnd_menu_file_paths[2]);
-	free((char *)rnd_pcphl_conf_user_path);
-	free((char *)rnd_conf_sys_path);
+	free((char *)menu_file_paths[2]);
+	free((char *)rnd_app.conf_user_path);
+	free((char *)rnd_app.conf_sys_path);
 }
 
 
@@ -302,6 +347,8 @@ extern void pcb_select_act_init2(void);
 extern void pcb_undo_act_init2(void);
 extern void pcb_draw_init(void);
 extern void pcb_draw_uninit(void);
+extern void pcb_board_init(void);
+extern void pcb_board_uninit(void);
 
 void pcb_main_init_actions(void)
 {
@@ -336,6 +383,7 @@ void pcb_main_uninit(void)
 
 	conf_core_uninit_pre();
 
+	pcb_board_init();
 	pcb_draw_uninit();
 	pcb_brave_uninit();
 	pcb_polygon_uninit();
@@ -362,6 +410,7 @@ void pcb_main_uninit(void)
 	}
 	PCB = NULL;
 
+	pcb_board_uninit();
 	pcb_extobj_uninit();
 
 	rnd_hidlib_uninit(); /* plugin unload */
@@ -384,6 +433,7 @@ void pcb_main_uninit(void)
 	rnd_log_uninit();
 	main_path_uninit();
 	conf_core_uninit();
+
 }
 
 /* action table number of columns for a single action */
@@ -409,6 +459,9 @@ static rnd_funchash_table_t Functions[] = {
 	{"F_END", F_END}
 };
 
+extern const char *rnd_hidlib_default_embedded_menu;
+extern const char *rnd_conf_internal;
+
 int main(int argc, char *argv[])
 {
 	int n;
@@ -416,8 +469,39 @@ int main(int argc, char *argv[])
 
 	rnd_main_args_t ga;
 
-	rnd_conf_dot_dir = DOT_PCB_RND;
-	rnd_conf_lib_dir = PCBLIBDIR;
+	if (((rnd_api_ver & 0xFF0000) >> 16) != PCB_LIBRND_VER_REQ_MAJOR) {
+		fprintf(stderr, "librnd version problem: need %d.x.x but installed version is %d.x.x (major version mismatch)\n", PCB_LIBRND_VER_REQ_MAJOR, (int)(rnd_api_ver & 0xFF0000) >> 16);
+		exit(1);
+	}
+	if (((rnd_api_ver & 0x00FF00) >> 8) < PCB_LIBRND_VER_REQ_MINOR) {
+		fprintf(stderr, "librnd version problem: need >=%d.%d.x but installed version is %d.%d.x (minor version mismatch)\n", PCB_LIBRND_VER_REQ_MAJOR, PCB_LIBRND_VER_REQ_MINOR, (int)(rnd_api_ver & 0xFF0000) >> 16, (int)(rnd_api_ver & 0x00FF00) >> 8);
+		exit(1);
+	}
+
+	rnd_app.menu_file_paths = menu_file_paths;
+	rnd_app.menu_name_fmt   = menu_name_fmt;
+	rnd_app.default_embedded_menu = rnd_hidlib_default_embedded_menu;
+	rnd_app.package = PCB_PACKAGE;
+	rnd_app.version = PCB_VERSION;
+	rnd_app.revision = PCB_REVISION;
+	rnd_app.url = "http://repo.hu/projects/pcb-rnd";
+
+	rnd_app.crosshair_suspend = pcb_crosshair_suspend;
+	rnd_app.crosshair_restore = pcb_crosshair_restore;
+	rnd_app.crosshair_move_to = pcb_hidlib_crosshair_move_to;
+	rnd_app.draw_marks        = pcb_crosshair_draw_marks;
+	rnd_app.draw_attached     = pcb_crosshair_draw_attached;
+	rnd_app.expose_main       = pcb_expose_main;
+	rnd_app.expose_preview    = pcb_expose_preview;
+
+	rnd_app.conf_internal = rnd_conf_internal;
+	rnd_app.conf_core_postproc = pcb_conf_core_postproc;
+	rnd_app.conf_board_ignores = conf_board_ignores;
+	rnd_app.conf_ignores = conf_ignores;
+
+
+	rnd_app.dot_dir = DOT_PCB_RND;
+	rnd_app.lib_dir = PCBLIBDIR;
 
 	rnd_fix_locale_and_env();
 	exec_prefix = main_path_init(argv[0]);
@@ -440,10 +524,6 @@ int main(int argc, char *argv[])
 
 	rnd_hidlib_init1(conf_core_init);
 
-
-TODO("librnd: remove this once librnd is not extern anymore");
-	rnd_plugin_add_dir("../src_3rd/librnd-local/src/plugins");
-
 	pcb_event_init_app();
 	rnd_conf_set(RND_CFR_INTERNAL, "rc/path/exec_prefix", -1, exec_prefix, RND_POL_OVERWRITE);
 	free(exec_prefix);
