@@ -267,6 +267,7 @@ fgw_error_t pcb_act_DumpObjFlags(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
+/* Note: this can not be in librnd because of the app-specific setenvs */
 static const char pcb_acts_System[] = "System(shell_cmd)";
 static const char pcb_acth_System[] = "Run shell command";
 fgw_error_t pcb_act_System(fgw_arg_t *res, int argc, fgw_arg_t *argv)
@@ -287,6 +288,10 @@ fgw_error_t pcb_act_System(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
+/* Note: this can not be in librnd because:
+   - wrong (historical) action name 
+   - app-specific side effects in pcb_act_execute_file
+*/
 static const char pcb_acts_ExecuteFile[] = "ExecuteFile(filename)";
 static const char pcb_acth_ExecuteFile[] = "Run actions from the given file.";
 /* DOC: executefile.html */
@@ -308,7 +313,8 @@ static rnd_action_t main_action_list[] = {
 	{"DumpObjFlags", pcb_act_DumpObjFlags, pcb_acth_DumpObjFlags, pcb_acts_DumpObjFlags},
 	{"System", pcb_act_System, pcb_acth_System, pcb_acts_System},
 	{"ExecCommand", pcb_act_System, pcb_acth_System, pcb_acts_System},
-	{"ExecuteFile", pcb_act_ExecuteFile, pcb_acth_ExecuteFile, pcb_acts_ExecuteFile}
+	{"ExecuteFile", pcb_act_ExecuteFile, pcb_acth_ExecuteFile, pcb_acts_ExecuteFile},
+	{"ExecActionFile", pcb_act_ExecuteFile, pcb_acth_ExecuteFile, pcb_acts_ExecuteFile}
 };
 
 void pcb_main_act_init2(void)
