@@ -56,9 +56,8 @@
 #include "obj_rat_draw.h"
 #include "obj_pstk_draw.h"
 
-TODO("padstack: remove this when via is removed and the padstack is created from style directly")
-#include "src_plugins/lib_compat_help/pstk_compat.h"
-
+TODO("ui_layer parent fix: remove this")
+#include "layer_ui.h"
 
 /**** allocation ****/
 
@@ -67,13 +66,17 @@ void pcb_line_reg(pcb_layer_t *layer, pcb_line_t *line)
 	linelist_append(&layer->Line, line);
 	PCB_SET_PARENT(line, layer, layer);
 
-	if (layer->parent_type == PCB_PARENT_UI)
-		return;
-
-	if (layer->parent_type == PCB_PARENT_DATA) {
+	if (pcb_is_uilayer(layer)) {
 		pcb_obj_id_reg(layer->parent.data, line);
+/* can not register points because they do not have the common object header
 		pcb_obj_id_reg(layer->parent.data, &line->Point1);
-		pcb_obj_id_reg(layer->parent.data, &line->Point2);
+		pcb_obj_id_reg(layer->parent.data, &line->Point2);*/
+	}
+	else if (layer->parent_type == PCB_PARENT_DATA) {
+		pcb_obj_id_reg(layer->parent.data, line);
+/* can not register points because they do not have the common object header
+		pcb_obj_id_reg(layer->parent.data, &line->Point1);
+		pcb_obj_id_reg(layer->parent.data, &line->Point2);*/
 	}
 }
 
@@ -82,11 +85,16 @@ void pcb_line_unreg(pcb_line_t *line)
 	pcb_layer_t *layer = line->parent.layer;
 	assert(line->parent_type == PCB_PARENT_LAYER);
 	linelist_remove(line);
-	if (layer->parent_type != PCB_PARENT_UI) {
+	if (pcb_is_uilayer(layer)) {
+		pcb_obj_id_del(layer->parent.data, line);
+/*		pcb_obj_id_del(layer->parent.data, &line->Point1);
+		pcb_obj_id_del(layer->parent.data, &line->Point2);*/
+	}
+	else {
 		assert(layer->parent_type == PCB_PARENT_DATA);
 		pcb_obj_id_del(layer->parent.data, line);
-		pcb_obj_id_del(layer->parent.data, &line->Point1);
-		pcb_obj_id_del(layer->parent.data, &line->Point2);
+/*		pcb_obj_id_del(layer->parent.data, &line->Point1);
+		pcb_obj_id_del(layer->parent.data, &line->Point2);*/
 	}
 	PCB_CLEAR_PARENT(line);
 }
@@ -972,10 +980,10 @@ struct via_info {
 static rnd_r_dir_t moveline_callback(const rnd_box_t * b, void *cl)
 {
 	struct via_info *i = (struct via_info *) cl;
-	pcb_pstk_t *ps;
+	pcb_pstk_t *ps = pcb_pstk_new(PCB->Data, -1, conf_core.design.via_proto,
+		i->X, i->Y, conf_core.design.clearance, pcb_flag_make(PCB_FLAG_CLEARLINE));
 
-TODO("pstk TODO #21: do not work in comp mode, use a pstk proto - scconfig also has TODO #21, fix it there too")
-	if ((ps = pcb_pstk_new_compat_via(PCB->Data, -1, i->X, i->Y, conf_core.design.via_drilling_hole, conf_core.design.via_thickness, conf_core.design.clearance, 0, PCB_PSTK_COMPAT_ROUND, rnd_true)) != NULL) {
+	if (ps != NULL) {
 		pcb_undo_add_obj_to_create(PCB_OBJ_PSTK, ps, ps, ps);
 		pcb_pstk_invalidate_draw(ps);
 	}
@@ -988,6 +996,7 @@ void *pcb_lineop_move_to_layer(pcb_opctx_t *ctx, pcb_layer_t * Layer, pcb_line_t
 	rnd_box_t sb;
 	pcb_line_t *newone;
 	void *ptr1, *ptr2, *ptr3;
+	rnd_coord_t via_dia2;
 
 	if (PCB_FLAG_TEST(PCB_FLAG_LOCK, Line)) {
 		rnd_message(RND_MSG_WARNING, "Sorry, line object is locked\n");
@@ -1011,13 +1020,18 @@ void *pcb_lineop_move_to_layer(pcb_opctx_t *ctx, pcb_layer_t * Layer, pcb_line_t
 			pcb_layer_get_group_(Layer) ==
 			pcb_layer_get_group_(ctx->move.dst_layer) || !(pcb_layer_flags(PCB, pcb_layer_id(PCB->Data, Layer)) & PCB_LYT_COPPER) || !(pcb_layer_flags_(ctx->move.dst_layer) & PCB_LYT_COPPER))
 		return newone;
+
+	via_dia2 = pcb_pstk_pen_dia(PCB);
+	via_dia2 /= 2;
+
 	/* consider via at Point1 */
 	sb.X1 = newone->Point1.X - newone->Thickness / 2;
 	sb.X2 = newone->Point1.X + newone->Thickness / 2;
 	sb.Y1 = newone->Point1.Y - newone->Thickness / 2;
 	sb.Y2 = newone->Point1.Y + newone->Thickness / 2;
+
 	if ((pcb_search_obj_by_location(PCB_OBJ_CLASS_PIN, &ptr1, &ptr2, &ptr3,
-															newone->Point1.X, newone->Point1.Y, conf_core.design.via_thickness / 2) == PCB_OBJ_VOID)) {
+															newone->Point1.X, newone->Point1.Y, via_dia2) == PCB_OBJ_VOID)) {
 		info.X = newone->Point1.X;
 		info.Y = newone->Point1.Y;
 		if (setjmp(info.env) == 0)
@@ -1028,8 +1042,9 @@ void *pcb_lineop_move_to_layer(pcb_opctx_t *ctx, pcb_layer_t * Layer, pcb_line_t
 	sb.X2 = newone->Point2.X + newone->Thickness / 2;
 	sb.Y1 = newone->Point2.Y - newone->Thickness / 2;
 	sb.Y2 = newone->Point2.Y + newone->Thickness / 2;
+
 	if ((pcb_search_obj_by_location(PCB_OBJ_CLASS_PIN, &ptr1, &ptr2, &ptr3,
-															newone->Point2.X, newone->Point2.Y, conf_core.design.via_thickness / 2) == PCB_OBJ_VOID)) {
+															newone->Point2.X, newone->Point2.Y, via_dia2) == PCB_OBJ_VOID)) {
 		info.X = newone->Point2.X;
 		info.Y = newone->Point2.Y;
 		if (setjmp(info.env) == 0)
