@@ -39,6 +39,6 @@ rnd_r_dir_t pcb_line_draw_term_callback(const rnd_box_t * b, void *cl);
 void pcb_line_draw_(pcb_draw_info_t *info, pcb_line_t *line, int allow_term_gfx);
 void pcb_line_invalidate_erase(pcb_line_t *Line);
 void pcb_line_invalidate_draw(pcb_layer_t *Layer, pcb_line_t *Line);
-void pcb_line_draw_label(pcb_draw_info_t *info, pcb_line_t *line);
+void pcb_line_draw_label(pcb_draw_info_t *info, pcb_line_t *line, rnd_bool vis_side);
 void pcb_line_name_invalidate_draw(pcb_line_t *line);
 
