@@ -38,14 +38,14 @@
 
 #include "board.h"
 #include "polygon.h"
-#include "polygon1_gen.h"
+#include <librnd/poly/polygon1_gen.h>
 #include "obj_pinvia_therm.h"
 
-static pcb_polyarea_t *pcb_pa_diag_line(pcb_coord_t X, pcb_coord_t Y, pcb_coord_t l, pcb_coord_t w, pcb_bool rt)
+static rnd_polyarea_t *pcb_pa_diag_line(rnd_coord_t X, rnd_coord_t Y, rnd_coord_t l, rnd_coord_t w, rnd_bool rt)
 {
-	pcb_pline_t *c;
-	pcb_vector_t v;
-	pcb_coord_t x1, x2, y1, y2;
+	rnd_pline_t *c;
+	rnd_vector_t v;
+	rnd_coord_t x1, x2, y1, y2;
 
 	if (rt) {
 		x1 = (l - w) * M_SQRT1_2;
@@ -62,60 +62,60 @@ static pcb_polyarea_t *pcb_pa_diag_line(pcb_coord_t X, pcb_coord_t Y, pcb_coord_
 
 	v[0] = X + x1;
 	v[1] = Y + y2;
-	if ((c = pcb_poly_contour_new(v)) == NULL)
+	if ((c = rnd_poly_contour_new(v)) == NULL)
 		return NULL;
 	v[0] = X - x2;
 	v[1] = Y - y1;
-	pcb_poly_vertex_include(c->head->prev, pcb_poly_node_create(v));
+	rnd_poly_vertex_include(c->head->prev, rnd_poly_node_create(v));
 	v[0] = X - x1;
 	v[1] = Y - y2;
-	pcb_poly_vertex_include(c->head->prev, pcb_poly_node_create(v));
+	rnd_poly_vertex_include(c->head->prev, rnd_poly_node_create(v));
 	v[0] = X + x2;
 	v[1] = Y + y1;
-	pcb_poly_vertex_include(c->head->prev, pcb_poly_node_create(v));
-	return pcb_poly_from_contour(c);
+	rnd_poly_vertex_include(c->head->prev, rnd_poly_node_create(v));
+	return rnd_poly_from_contour(c);
 }
 
-/* ThermPoly returns a pcb_polyarea_t having all of the clearance that when
+/* ThermPoly returns a rnd_polyarea_t having all of the clearance that when
  * subtracted from the plane create the desired thermal fingers.
  * Usually this is 4 disjoint regions.
  *
  */
-pcb_polyarea_t *ThermPoly_(pcb_board_t *pcb, pcb_coord_t cx, pcb_coord_t cy, pcb_coord_t thickness, pcb_coord_t clearance, pcb_cardinal_t style)
+rnd_polyarea_t *ThermPoly_(pcb_board_t *pcb, rnd_coord_t cx, rnd_coord_t cy, rnd_coord_t thickness, rnd_coord_t clearance, rnd_cardinal_t style)
 {
 	pcb_arc_t a;
-	pcb_polyarea_t *pa, *arc;
+	rnd_polyarea_t *pa, *arc;
 
 	/* must be circular */
 	switch (style) {
 	case 1:
 	case 2:
 		{
-			pcb_polyarea_t *m;
-			pcb_coord_t t = (thickness + clearance) / 2;
-			pcb_coord_t w = 0.5 * pcb->ThermScale * clearance;
-			pa = pcb_poly_from_circle(cx, cy, t);
-			arc = pcb_poly_from_circle(cx, cy, thickness / 2);
+			rnd_polyarea_t *m;
+			rnd_coord_t t = (thickness + clearance) / 2;
+			rnd_coord_t w = 0.5 * pcb->ThermScale * clearance;
+			pa = rnd_poly_from_circle(cx, cy, t);
+			arc = rnd_poly_from_circle(cx, cy, thickness / 2);
 			/* create a thin ring */
-			pcb_polyarea_boolean_free(pa, arc, &m, PCB_PBO_SUB);
+			rnd_polyarea_boolean_free(pa, arc, &m, RND_PBO_SUB);
 			/* fix me needs error checking */
 			if (style == 2) {
 				/* t is the theoretically required length, but we use twice that
 				 * to avoid discretisation errors in our circle approximation.
 				 */
-				pa = pcb_poly_from_rect(cx - t * 2, cx + t * 2, cy - w, cy + w);
-				pcb_polyarea_boolean_free(m, pa, &arc, PCB_PBO_SUB);
-				pa = pcb_poly_from_rect(cx - w, cx + w, cy - t * 2, cy + t * 2);
+				pa = rnd_poly_from_rect(cx - t * 2, cx + t * 2, cy - w, cy + w);
+				rnd_polyarea_boolean_free(m, pa, &arc, RND_PBO_SUB);
+				pa = rnd_poly_from_rect(cx - w, cx + w, cy - t * 2, cy + t * 2);
 			}
 			else {
 				/* t is the theoretically required length, but we use twice that
 				 * to avoid discretisation errors in our circle approximation.
 				 */
-				pa = pcb_pa_diag_line(cx, cy, t * 2, w, pcb_true);
-				pcb_polyarea_boolean_free(m, pa, &arc, PCB_PBO_SUB);
-				pa = pcb_pa_diag_line(cx, cy, t * 2, w, pcb_false);
+				pa = pcb_pa_diag_line(cx, cy, t * 2, w, rnd_true);
+				rnd_polyarea_boolean_free(m, pa, &arc, RND_PBO_SUB);
+				pa = pcb_pa_diag_line(cx, cy, t * 2, w, rnd_false);
 			}
-			pcb_polyarea_boolean_free(arc, pa, &m, PCB_PBO_SUB);
+			rnd_polyarea_boolean_free(arc, pa, &m, RND_PBO_SUB);
 			return m;
 		}
 
