@@ -695,6 +695,7 @@ rnd_r_dir_t pcb_pstk_draw_hole_callback(const rnd_box_t *b, void *cl)
 		r -= r/8; /* +12.5% */
 		rnd_render->set_color(pcb_draw_out.fgGC, PCB_FLAG_TEST(PCB_FLAG_SELECTED, ps) ? &conf_core.appearance.color.selected : &conf_core.appearance.color.subc);
 		rnd_hid_set_line_width(pcb_draw_out.fgGC, 0);
+		rnd_hid_set_line_cap(pcb_draw_out.fgGC, rnd_cap_round);
 		rnd_render->draw_arc(pcb_draw_out.fgGC, ps->x, ps->y, r, r, 20, 290);
 	}
 
@@ -725,6 +726,9 @@ rnd_r_dir_t pcb_pstk_draw_slot_callback(const rnd_box_t *b, void *cl)
 	else
 		proto = pcb_pstk_get_proto(ps);
 
+	if (proto == NULL)
+		return RND_R_DIR_NOT_FOUND;
+
 	/* No slot at all */
 	if (proto->mech_idx < 0)
 		return RND_R_DIR_NOT_FOUND;
@@ -758,6 +762,7 @@ rnd_r_dir_t pcb_pstk_draw_slot_callback(const rnd_box_t *b, void *cl)
 void pcb_pstk_thindraw(pcb_draw_info_t *info, rnd_hid_gc_t gc, pcb_pstk_t *ps)
 {
 	pcb_pstk_shape_t *shape = NULL;
+	pcb_pstk_proto_t *proto = pcb_pstk_get_proto(ps);
 	pcb_board_t *pcb;
 	rnd_layergrp_id_t gid = PCB_CURRLAYER(PCB)->meta.real.grp;
 
@@ -775,6 +780,15 @@ void pcb_pstk_thindraw(pcb_draw_info_t *info, rnd_hid_gc_t gc, pcb_pstk_t *ps)
 
 	if (shape != NULL)
 		pcb_pstk_draw_shape_thin(info, gc, ps, shape);
+
+	if ((proto != NULL) && (proto->hdia > 0)) {
+		rnd_render->draw_arc(gc, ps->x, ps->y, proto->hdia/2, proto->hdia/2, 0, 360);
+	}
+	else {
+		shape = pcb_pstk_shape(ps, PCB_LYT_MECH, PCB_LYC_AUTO);
+		if (shape != NULL)
+			pcb_pstk_draw_shape_thin(info, gc, ps, shape);
+	}
 }
 
 void pcb_pstk_draw_label(pcb_draw_info_t *info, pcb_pstk_t *ps, rnd_bool vis_side)
@@ -859,6 +873,7 @@ void pcb_pstk_draw_preview(pcb_board_t *pcb, const pcb_pstk_t *ps, char *layers,
 		info.objcb.pstk.shape_mask = PCB_LYT_MECH;
 		info.objcb.pstk.is_current = (draw_hole > 1);
 		pcb_pstk_draw_hole_callback((rnd_box_t *)ps, &info);
+		pcb_pstk_draw_slot_callback((rnd_box_t *)ps, &info);
 	}
 
 	if (mark)
@@ -1548,7 +1563,7 @@ void pcb_pstk_rotate(pcb_pstk_t *pstk, rnd_coord_t cx, rnd_coord_t cy, double co
 	ctx.rotate.angle = angle;
 	ctx.rotate.cosa = cosa;
 	ctx.rotate.sina = sina;
-	pcb_pstkop_rotate(&ctx, pstk);
+	pcb_pstkop_rotate_(&ctx, pstk, 0);
 }
 
 rnd_coord_t obj_pstk_get_clearance(pcb_board_t *pcb, pcb_pstk_t *ps, pcb_layer_t *layer)
@@ -1562,6 +1577,8 @@ rnd_coord_t obj_pstk_get_clearance(pcb_board_t *pcb, pcb_pstk_t *ps, pcb_layer_t
 		return ps->Clearance;
 
 	shp = pcb_pstk_shape_at(pcb, ps, layer);
+	if (shp == NULL)
+		return 0;
 	return shp->clearance;
 }
 
