@@ -477,7 +477,7 @@ static void get_aux_layer(pcb_subc_t *sc, int alloc)
 void pcb_subc_create_aux(pcb_subc_t *sc, rnd_coord_t ox, rnd_coord_t oy, double rot, rnd_bool bottom)
 {
 	double unit = PCB_SUBC_AUX_UNIT;
-	double cs, sn;
+	double cs, sn, ydir = 1;
 
 	get_aux_layer(sc, 1);
 
@@ -494,12 +494,12 @@ void pcb_subc_create_aux(pcb_subc_t *sc, rnd_coord_t ox, rnd_coord_t oy, double
 		assert(sc->aux_layer->is_bound);
 		sc->aux_layer->meta.bound.type &= ~PCB_LYT_TOP;
 		sc->aux_layer->meta.bound.type |= PCB_LYT_BOTTOM;
-		cs = -cs;
+		ydir = -1;
 	}
 
 	add_aux_line(sc->aux_layer, "subc-role", "origin", ox, oy, ox, oy);
 	add_aux_line(sc->aux_layer, "subc-role", "x", ox, oy, rnd_round((double)ox + cs*unit), rnd_round((double)oy + sn*unit));
-	add_aux_line(sc->aux_layer, "subc-role", "y", ox, oy, rnd_round((double)ox + sn*unit), rnd_round((double)oy + cs*unit));
+	add_aux_line(sc->aux_layer, "subc-role", "y", ox, oy, rnd_round((double)ox + ydir*sn*unit), rnd_round((double)oy + ydir*cs*unit));
 }
 
 void pcb_subc_create_aux_point(pcb_subc_t *sc, rnd_coord_t x, rnd_coord_t y, const char *role)
@@ -673,19 +673,30 @@ int pcb_subc_convert_from_buffer(pcb_buffer_t *buffer)
 	vtp0_uninit(&mask_pads);
 	vtp0_uninit(&paste_pads);
 
-	pcb_subc_create_aux(sc, buffer->X, buffer->Y, 0.0, rnd_false);
+	pcb_subc_create_aux(sc, buffer->X, buffer->Y, 0.0, !!buffer->from_bottom_side);
 
 	/* Add refdes */
 	if ((conf_core.editor.subc_conv_refdes != NULL) && (*conf_core.editor.subc_conv_refdes != '\0')) {
 		if (strcmp(conf_core.editor.subc_conv_refdes, "<?>") != 0)
 			pcb_attribute_put(&sc->Attributes, "refdes", conf_core.editor.subc_conv_refdes);
 		if (!has_refdes_text) {
-			if (dst_top_silk == NULL)
-				dst_top_silk = pcb_layer_new_bound(sc->data, PCB_LYT_TOP | PCB_LYT_SILK, "top-silk", NULL);
-			if (dst_top_silk != NULL)
-				pcb_text_new(dst_top_silk, pcb_font(PCB, 0, 0), buffer->X, buffer->Y, 0, 100, 0, "%a.parent.refdes%", pcb_flag_make(PCB_FLAG_DYNTEXT | PCB_FLAG_FLOATER));
+			pcb_layer_t *dstly;
+			int botflg = 0;
+
+			if (!buffer->from_bottom_side) {
+				if (dst_top_silk == NULL)
+					dst_top_silk = pcb_layer_new_bound(sc->data, PCB_LYT_TOP | PCB_LYT_SILK, "top-silk", NULL);
+				dstly = dst_top_silk;
+			}
+			else {
+				dstly = pcb_layer_new_bound(sc->data, PCB_LYT_BOTTOM | PCB_LYT_SILK, "bottom-silk", NULL);
+				botflg = PCB_FLAG_ONSOLDER;
+			}
+
+			if (dstly != NULL)
+				pcb_text_new(dstly, pcb_font(PCB, 0, 0), buffer->X, buffer->Y, 0, 100, 0, "%a.parent.refdes%", pcb_flag_make(PCB_FLAG_DYNTEXT | PCB_FLAG_FLOATER | botflg));
 			else
-				rnd_message(RND_MSG_ERROR, "Error: can't create top silk layer in subc for placing the refdes\n");
+				rnd_message(RND_MSG_ERROR, "Error: can't create primary silk layer in subc for placing the refdes\n");
 		}
 	}
 
@@ -855,7 +866,7 @@ TODO(": The wireframe arc drawing code cannot draw ellipses yet so draw the elli
 	pcb_subc_draw_origin(pcb_crosshair.GC, sc, DX, DY);
 }
 
-pcb_layer_t *pcb_subc_alloc_layer_like(pcb_subc_t *subc, const pcb_layer_t *sl)
+pcb_layer_t *pcb_subc_alloc_layer_like(pcb_subc_t *subc, pcb_layer_t *sl)
 {
 	pcb_layer_t *dl;
 
@@ -865,7 +876,19 @@ pcb_layer_t *pcb_subc_alloc_layer_like(pcb_subc_t *subc, const pcb_layer_t *sl)
 	dl = &subc->data->Layer[subc->data->LayerN++];
 	dl->is_bound = 1;
 	dl->type = PCB_OBJ_LAYER;
-	memcpy(&dl->meta.bound, &sl->meta.bound, sizeof(sl->meta.bound));
+	if (!sl->is_bound) {
+		pcb_layer_t tmply;
+
+		memset(&dl->meta.bound, 0, sizeof(sl->meta.bound));
+		pcb_layer_real2bound(&tmply, sl, 0);
+
+		dl->meta.bound.type = tmply.meta.bound.type;
+		dl->meta.bound.stack_offs = tmply.meta.bound.stack_offs;
+		dl->meta.bound.purpose = tmply.meta.bound.purpose;
+	}
+	else
+		memcpy(&dl->meta.bound, &sl->meta.bound, sizeof(sl->meta.bound));
+
 	dl->name = rnd_strdup(sl->name);
 	dl->comb = sl->comb;
 	if (dl->meta.bound.real != NULL)
@@ -1888,6 +1911,11 @@ void *pcb_subcop_destroy(pcb_opctx_t *ctx, pcb_subc_t *sc)
 
 void *pcb_subcop_remove(pcb_opctx_t *ctx, pcb_subc_t *sc)
 {
+	if (ctx->remove.pcb->is_footprint) {
+		rnd_message(RND_MSG_WARNING, "Can not remove the subcircuit being edited in the footprint edit mode\n");
+		return NULL;
+	}
+
 	EraseSubc(sc);
 	pcb_undo_move_obj_to_remove(PCB_OBJ_SUBC, sc, sc, sc);
 	return NULL;
@@ -2196,22 +2224,65 @@ rnd_r_dir_t draw_subc_label_callback(const rnd_box_t *b, void *cl)
 	return RND_R_DIR_FOUND_CONTINUE;
 }
 
+static int subc_prev_layer_vis(pcb_layer_t *layer)
+{
+	pcb_layer_t *real = pcb_layer_get_real(layer);
+	if (real == NULL)
+		return 1;
+	return real->meta.real.vis;
+}
+
+static void subc_prev_draw_pstk(const pcb_subc_t *sc, const rnd_box_t *drawn_area, pcb_draw_info_t *info)
+{
+	rnd_rtree_it_t it;
+	pcb_any_obj_t *o;
+
+	if (sc->data->padstack_tree == NULL)
+		return;
+
+	for(o = rnd_rtree_first(&it, sc->data->padstack_tree, (rnd_rtree_box_t *)drawn_area); o != NULL; o = rnd_rtree_next(&it)) {
+		if (pcb_obj_is_under(o, sc->data)) {
+			pcb_pstk_draw_callback((rnd_box_t *)o, info);
+			if (PCB->hole_on)
+				pcb_pstk_draw_hole_callback((rnd_box_t *)o, info);
+		}
+	}
+}
+
+static void subc_prev_draw_by_lyt(const pcb_subc_t *sc, const rnd_box_t *drawn_area, pcb_draw_info_t *info, pcb_layer_type_t lyt_mask, pcb_layer_combining_t comb)
+{
+	int n;
+
+	/* draw layer objects on matching layers */
+	for(n = 0; n < sc->data->LayerN; n++) {
+		pcb_layer_t *layer = &sc->data->Layer[n];
+		if (((layer->meta.bound.type & lyt_mask) == lyt_mask) && subc_prev_layer_vis(layer))
+			pcb_draw_layer_under(PCB, layer, drawn_area, sc->data, info->xform_caller);
+	}
+
+	/* draw padstack shapes on matching layers */
+	for(n = 0; n < sc->parent.data->LayerN; n++) {
+		pcb_layer_t *layer = &sc->parent.data->Layer[n];
+		pcb_layer_type_t lyt = pcb_layer_flags_(layer);
+
+		if (((lyt & lyt_mask) == lyt_mask) && subc_prev_layer_vis(layer)) {
+			info->objcb.pstk.shape_mask = lyt;
+			info->objcb.pstk.comb = comb;
+			info->objcb.pstk.layer1 = layer;
+			subc_prev_draw_pstk(sc, drawn_area, info);
+		}
+	}
+}
+
 void pcb_subc_draw_preview(const pcb_subc_t *sc, const rnd_box_t *drawn_area)
 {
 	int n;
-	pcb_draw_info_t info;
+	pcb_draw_info_t info = {0};
 	rnd_rtree_it_t it;
 	pcb_any_obj_t *o;
 	rnd_xform_t xf = {0};
 	pcb_draw_setup_default_gui_xform(&xf);
 
-	/* draw copper only first - order doesn't matter */
-	for(n = 0; n < sc->data->LayerN; n++) {
-		pcb_layer_t *layer = &sc->data->Layer[n];
-		if (layer->meta.bound.type & PCB_LYT_COPPER)
-			pcb_draw_layer_under(PCB, layer, drawn_area, sc->data, &xf);
-	}
-
 	/* draw padstacks */
 	info.pcb = PCB;
 	info.drawn_area = drawn_area;
@@ -2220,22 +2291,17 @@ void pcb_subc_draw_preview(const pcb_subc_t *sc, const rnd_box_t *drawn_area)
 	info.objcb.pstk.gid = -1;
 	info.objcb.pstk.is_current = 1;
 	info.objcb.pstk.comb = 0;
-	info.objcb.pstk.shape_mask = PCB_LYT_COPPER | PCB_LYT_TOP;
 	info.objcb.pstk.holetype = PCB_PHOLE_UNPLATED | PCB_PHOLE_PLATED;
 
-	if (sc->data->padstack_tree != NULL)
-	for(o = rnd_rtree_first(&it, sc->data->padstack_tree, (rnd_rtree_box_t *)drawn_area); o != NULL; o = rnd_rtree_next(&it)) {
-		if (pcb_obj_is_under(o, sc->data)) {
-			pcb_pstk_draw_callback((rnd_box_t *)o, &info);
-			if (PCB->hole_on)
-				pcb_pstk_draw_hole_callback((rnd_box_t *)o, &info);
-		}
-	}
+	subc_prev_draw_by_lyt(sc, drawn_area, &info, PCB_LYT_MASK | PCB_LYT_TOP, PCB_LYC_AUTO | PCB_LYC_SUB);
+	subc_prev_draw_by_lyt(sc, drawn_area, &info, PCB_LYT_COPPER, 0);
+	subc_prev_draw_by_lyt(sc, drawn_area, &info, PCB_LYT_PASTE | PCB_LYT_TOP, PCB_LYC_AUTO);
+
 
 	/* draw silk and mech and doc layers, above padstacks */
 	for(n = 0; n < sc->data->LayerN; n++) {
 		pcb_layer_t *layer = &sc->data->Layer[n];
-		if (layer->meta.bound.type & (PCB_LYT_SILK | PCB_LYT_BOUNDARY | PCB_LYT_MECH | PCB_LYT_DOC))
+		if (((layer->meta.bound.type & (PCB_LYT_SILK | PCB_LYT_BOUNDARY | PCB_LYT_MECH | PCB_LYT_DOC)) && subc_prev_layer_vis(layer)))
 			pcb_draw_layer_under(PCB, layer, drawn_area, sc->data, &xf);
 	}
 
