@@ -110,6 +110,20 @@ pcb_term_err_t pcb_term_del(htsp_t *terminals, const char *termid, pcb_any_obj_t
 	return PCB_TERM_ERR_NOT_IN_TERMINAL;
 }
 
+pcb_term_err_t pcb_term_del_auto(pcb_any_obj_t *obj)
+{
+	pcb_subc_t *subc;
+
+	if (obj->term == NULL)
+		return PCB_TERM_ERR_SUCCESS;
+
+	subc = pcb_obj_parent_subc(obj);
+	if (subc == NULL)
+		return PCB_TERM_ERR_SUCCESS;
+
+	return pcb_term_del(&subc->terminals, obj->term, obj);
+}
+
 static pcb_term_err_t pcb_term_remove_entry(htsp_t *terminals, htsp_entry_t *e)
 {
 	vtp0_t *v = e->value;
@@ -175,7 +189,7 @@ static int undo_term_rename_swap(void *udata)
 	/* remove from previous terminal */
 	if (r->obj->term != NULL) {
 		old_term = rnd_strdup(r->obj->term);
-		rnd_attribute_remove(&r->obj->Attributes, "term");
+		pcb_attribute_remove(&r->obj->Attributes, "term");
 		pcb_obj_invalidate_label(r->obj->type, r->obj->parent.any, r->obj, r->obj);
 		r->obj->term = NULL;
 	}
@@ -201,9 +215,9 @@ static int undo_term_rename_swap(void *udata)
 
 	/* Update the attributes */
 	if (r->obj->term != NULL)
-		rnd_attribute_put(&r->obj->Attributes, "term", r->obj->term);
+		pcb_attribute_put(&r->obj->Attributes, "term", r->obj->term);
 	else
-		rnd_attribute_remove(&r->obj->Attributes, "term");
+		pcb_attribute_remove(&r->obj->Attributes, "term");
 
 	if (r->obj->type == PCB_OBJ_POLY)
 		pcb_poly_init_clip(r->obj->parent.layer->parent.data, r->obj->parent.layer, (pcb_poly_t *)r->obj);
