@@ -138,7 +138,8 @@ void pcb_set_design_dir(const char *fn)
 
 static int pcb_test_parse_all(FILE *ft, const char *Filename, const char *fmt, pcb_plug_iot_t type, pcb_find_io_t *available, int *accepts, int *accept_total, int maxav, int ignore_missing, int gen_event)
 {
-	int len, n;
+	int len, n, diff_parsers = 0;
+	void (*first_f)() = NULL;
 
 	if (ft == NULL) {
 		if (!ignore_missing)
@@ -156,11 +157,18 @@ static int pcb_test_parse_all(FILE *ft, const char *Filename, const char *fmt, p
 			void (*f)();
 			switch(type) {
 				case PCB_IOT_PCB: f = (void (*)())available[n].plug->parse_pcb; break;
+				case PCB_IOT_FOOTPRINT: f = (void (*)())available[n].plug->parse_footprint; break;
 				default: assert(!"internal error: pcb_test_parse_all: wrong type"); f = NULL;
 			}
 			if (f != NULL) {
 				accepts[n] = 1; /* force-accept - if it can handle the format, and the user explicitly wanted this format, let's try it */
 				(*accept_total)++;
+				if (first_f != NULL) {
+					if (f != first_f)
+						diff_parsers = 1;
+				}
+				else
+					first_f = f;
 			}
 		}
 
@@ -169,7 +177,7 @@ static int pcb_test_parse_all(FILE *ft, const char *Filename, const char *fmt, p
 			return -1;
 		}
 
-		if (*accept_total > 1) {
+		if ((*accept_total > 1) && diff_parsers) {
 			rnd_message(RND_MSG_INFO, "multiple IO_ plugins can handle format %s - I'm going to try them all, but you may want to be more specific next time; formats found:\n", fmt);
 			for(n = 0; n < len; n++)
 				rnd_message(RND_MSG_INFO, "    %s\n", available[n].plug->description);
@@ -233,19 +241,20 @@ int pcb_parse_pcb(pcb_board_t *Ptr, const char *Filename, const char *fmt, int l
 	pcb_layergrp_inhibit_dec();
 
 
-	if ((res == 0) && (load_settings)) {
+	if ((res == 0) && (load_settings != RND_CFR_invalid)) {
 		if (design_root_cnt == rnd_conf_main_root_replace_cnt[RND_CFR_DESIGN]) /* the newly loaded board did not bring a design root */
 			rnd_conf_reset(RND_CFR_DESIGN, "<pcb_parse_pcb>");
 		rnd_conf_load_project(NULL, Filename);
+
+		pcb_set_design_dir(Filename);
 	}
 
-	if (res == 0)
-		pcb_set_design_dir(Filename);
 
-	if (load_settings)
+	if (load_settings != RND_CFR_invalid) {
 		rnd_event(&PCB->hidlib, RND_EVENT_LOAD_POST, "si", Filename, res);
-	rnd_event(&PCB->hidlib, PCB_EVENT_ROUTE_STYLES_CHANGED, NULL);
-	rnd_conf_set(RND_CFR_DESIGN, "design/text_font_id", 0, "0", RND_POL_OVERWRITE); /* we have only one font now, make sure it is selected */
+		rnd_event(&PCB->hidlib, PCB_EVENT_ROUTE_STYLES_CHANGED, NULL);
+		rnd_conf_set(RND_CFR_DESIGN, "design/text_font_id", 0, "0", RND_POL_OVERWRITE); /* we have only one font now, make sure it is selected */
+	}
 
 	pcb_plug_io_err(&Ptr->hidlib, res, "load pcb", Filename);
 	return res;
@@ -606,7 +615,7 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 
 	switch(how & 0x0F) {
 		case 0: settings_dest = RND_CFR_DESIGN; break;
-		case 1: settings_dest = RND_CFR_DEFAULTPCB; break;
+		case 1: settings_dest = RND_CFR_DEFAULTDSG; break;
 		case 2: settings_dest = RND_CFR_invalid; break;
 		default: abort();
 	}
@@ -670,7 +679,7 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 		extern fgw_error_t pcb_act_GetStyle(fgw_arg_t *res, int argc, fgw_arg_t *argv);
 		fgw_arg_t res, argv;
 		if (RND_ACT_CALL_C(&PCB->hidlib, pcb_act_GetStyle, &res, 1, &argv) < 0)
-			pcb_use_route_style_idx(&PCB->RouteStyle, 0);
+			pcb_use_route_style_idx(PCB, 0);
 	}
 
 		if ((how == 0) || (revert))
@@ -978,7 +987,7 @@ int pcb_write_pcb_file(const char *Filename, rnd_bool thePcb, const char *fmt, r
 
 	/* for askovr, do not make a backup copy - if the user explicitly says overwrite, just overwrite */
 	if (!askovr)
-		overwrite = rnd_file_readable(Filename);
+		overwrite = rnd_file_readable(NULL, Filename);
 
 	if (overwrite) {
 		int len = strlen(Filename);
@@ -1085,7 +1094,7 @@ rnd_cardinal_t pcb_io_incompat_save(pcb_data_t *data, pcb_any_obj_t *obj, const
 	return 0;
 }
 
-pcb_plug_fp_map_t *pcb_io_map_footprint_file(rnd_hidlib_t *hl, const char *fn, pcb_plug_fp_map_t *head, int need_tags)
+pcb_plug_fp_map_t *pcb_io_map_footprint_file(rnd_hidlib_t *hl, const char *fn, pcb_plug_fp_map_t *head, int need_tags, const char **fmt)
 {
 	FILE *f = rnd_fopen(hl, fn, "r");
 	pcb_plug_fp_map_t *res = NULL;
@@ -1104,8 +1113,11 @@ pcb_plug_fp_map_t *pcb_io_map_footprint_file(rnd_hidlib_t *hl, const char *fn, p
 		head->libtype = PCB_LIB_FOOTPRINT;
 		res = plug->map_footprint(NULL, f, fn, head, need_tags);
 		if (res == NULL) continue;
-		if (res->type != PCB_FP_INVALID)
+		if (res->type != PCB_FP_INVALID) {
+			if (fmt != NULL)
+				*fmt = plug->default_fmt;
 			break; /* success */
+		}
 		vts0_uninit(&res->tags);
 	}
 
