@@ -570,7 +570,7 @@ static rnd_r_dir_t padstack_sub_callback(const rnd_box_t *b, void *cl)
 
 	np = pcb_thermal_area_pstk(pcb_data_get_top(info->data), ps, i, polygon);
 	if (np == 0)
-			return RND_R_DIR_FOUND_CONTINUE;
+		return RND_R_DIR_FOUND_CONTINUE;
 
 	info->batch_size++;
 	POLY_CLIP_PROG();
@@ -601,7 +601,7 @@ static rnd_r_dir_t arc_sub_callback(const rnd_box_t * b, void *cl)
 	polygon = info->polygon;
 
 	if (SubtractArc(arc, polygon) < 0)
-		longjmp(info->env, 1);
+		return RND_R_DIR_NOT_FOUND;
 	return RND_R_DIR_FOUND_CONTINUE;
 }
 
@@ -766,7 +766,7 @@ static rnd_r_dir_t poly_sub_callback(const rnd_box_t *b, void *cl)
 	POLY_CLIP_PROG();
 
 	if (SubtractPolyPoly(subpoly, polygon) < 0)
-		longjmp(info->env, 1);
+		return RND_R_DIR_NOT_FOUND;
 
 	return RND_R_DIR_FOUND_CONTINUE;
 }
@@ -790,7 +790,7 @@ static rnd_r_dir_t line_sub_callback(const rnd_box_t * b, void *cl)
 
 	np = line_clearance_poly(-1, NULL, line, polygon);
 	if (!np)
-		longjmp(info->env, 1);
+		return RND_R_DIR_NOT_FOUND;
 
 	rnd_polyarea_boolean_free(info->accumulate, np, &merged, RND_PBO_UNITE);
 	info->accumulate = merged;
@@ -818,7 +818,7 @@ static rnd_r_dir_t text_sub_callback(const rnd_box_t * b, void *cl)
 
 	polygon = info->polygon;
 	if (SubtractText(text, polygon) < 0)
-		longjmp(info->env, 1);
+		return RND_R_DIR_NOT_FOUND;
 	return RND_R_DIR_FOUND_CONTINUE;
 }
 
@@ -1302,6 +1302,7 @@ void pcb_polygon_close_hole(void)
  */
 void pcb_polygon_hole_create_from_attached(void)
 {
+	pcb_poly_t *opoly, *npoly;
 	rnd_polyarea_t *original, *new_hole, *result;
 	pcb_flag_t Flags;
 	
@@ -1318,7 +1319,10 @@ void pcb_polygon_hole_create_from_attached(void)
 	 */
 	pcb_undo_save_serial();
 	Flags = ((pcb_poly_t *) pcb_crosshair.AttachedObject.Ptr2)->Flags;
-	pcb_poly_to_polygons_on_layer(PCB->Data, (pcb_layer_t *) pcb_crosshair.AttachedObject.Ptr1, result, Flags);
+	npoly = pcb_poly_to_polygons_on_layer(PCB->Data, (pcb_layer_t *) pcb_crosshair.AttachedObject.Ptr1, result, Flags);
+	opoly = pcb_crosshair.AttachedObject.Ptr2;
+	memcpy(&npoly->Attributes, &opoly->Attributes, sizeof(opoly->Attributes));
+	memset(&opoly->Attributes, 0, sizeof(opoly->Attributes));
 	pcb_remove_object(PCB_OBJ_POLY,
 							 pcb_crosshair.AttachedObject.Ptr1, pcb_crosshair.AttachedObject.Ptr2, pcb_crosshair.AttachedObject.Ptr3);
 	pcb_undo_restore_serial();
@@ -1731,7 +1735,7 @@ void debug_polygon(pcb_poly_t * p)
 /* Convert a rnd_polyarea_t (and all linked rnd_polyarea_t) to
  * raw PCB polygons on the given layer.
  */
-void pcb_poly_to_polygons_on_layer(pcb_data_t * Destination, pcb_layer_t * Layer, rnd_polyarea_t * Input, pcb_flag_t Flags)
+pcb_poly_t *pcb_poly_to_polygons_on_layer(pcb_data_t * Destination, pcb_layer_t * Layer, rnd_polyarea_t * Input, pcb_flag_t Flags)
 {
 	pcb_poly_t *Polygon;
 	rnd_polyarea_t *pa;
@@ -1740,7 +1744,7 @@ void pcb_poly_to_polygons_on_layer(pcb_data_t * Destination, pcb_layer_t * Layer
 	rnd_bool outer;
 
 	if (Input == NULL)
-		return;
+		return NULL;
 
 	pa = Input;
 	do {
@@ -1776,6 +1780,7 @@ void pcb_poly_to_polygons_on_layer(pcb_data_t * Destination, pcb_layer_t * Layer
 	while ((pa = pa->f) != Input);
 
 	pcb_board_set_changed_flag(PCB, rnd_true);
+	return Polygon;
 }
 
 rnd_bool pcb_pline_is_rectangle(rnd_pline_t *pl)
