@@ -237,6 +237,12 @@ static int parse_inst(uhpgl_ctx_t *ctx)
 			ctx->state.pen_down = 1;
 			p->state = ST_NUMBERS_OR_END;
 			return 0;
+		case inst2num('W','U'):
+		case inst2num('P','W'):
+		case inst2num('L','T'):
+			p->state = ST_NUMBERS_OR_END;
+			return 0;
+
 		case inst2num('P','A'):
 		case inst2num('P','R'):
 		case inst2num('S','P'):
@@ -360,13 +366,38 @@ static int parse_coord(uhpgl_ctx_t *ctx, double coord, int is_last)
 				return 0;
 			}
 			return error(ctx, "PT needs 1 argument");
-		case inst2num('V','S'):
-			if ((p->argc == 1) && (is_last)) {
-				ctx->state.pen_speed = p->argv[0];
-				p->state = ST_INST_END;
-				return 0;
+		case inst2num('L','T'):
+			if (is_last) {
+				if ((p->argc <= 3) && (is_last))
+					return 0;
+				return error(ctx, "LT needs at most 3 argument");
 			}
-			return error(ctx, "VS needs 1 argument");
+			return 0;
+		case inst2num('V','S'):
+			if (is_last) {
+				if ((p->argc == 1) || (p->argc == 2)) {
+					ctx->state.pen_speed = p->argv[0];
+					p->state = ST_INST_END;
+					return 0;
+				}
+				printf("argc=%d\n", p->argc);
+				return error(ctx, "VS needs 1 or 2 arguments");
+			}
+			return 0;
+		case inst2num('W','U'): /* unknown */
+			if (is_last) {
+				if (p->argc == 1)
+					return 0;
+				return error(ctx, "WU needs 1 argument");
+			}
+			return 0;
+		case inst2num('P','W'): /* unknown; maybe pen width? */
+			if (is_last) {
+				if (p->argc == 2)
+					return 0;
+				return error(ctx, "PW needs 2 arguments");
+			}
+			return 0;
 	}
 	return error(ctx, "unimplemented coord instruction");
 }
@@ -396,7 +427,10 @@ int uhpgl_parse_char(uhpgl_ctx_t *ctx, int c)
 			return 0;
 		case '\r':
 		case '\t':
+			return 0;
 		case ' ':
+			if ((p->state == ST_NUMBERS) || (p->state == ST_NUMBERS_OR_END))
+				break;
 			return 0;
 	}
 
@@ -438,7 +472,7 @@ int uhpgl_parse_char(uhpgl_ctx_t *ctx, int c)
 				goto got_end;
 			/* fall thru: number */
 		case ST_NUMBERS:
-			if ((c == ',') || (c == ';')) {
+			if ((c == ',') || (c == ' ') || (c == ';')) {
 				char *end;
 				int last = (c == ';');
 				p->token[p->len] = '\0';
