@@ -42,6 +42,7 @@
 #include "obj_line.h"
 #include "obj_text_draw.h"
 #include "obj_line_draw.h"
+#include "layer_ui.h"
 
 #include "keywords_sphash.h"
 
@@ -104,7 +105,7 @@ static fgw_error_t pcb_act_LineNew(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	if (line != NULL) {
 		RET_IDPATH(line);
-		if (!noundo)
+		if (!noundo && !pcb_is_uilayer(layer))
 			pcb_undo_add_obj_to_create(PCB_OBJ_LINE, layer, line, line);
 	}
 	return 0;
@@ -145,7 +146,7 @@ static fgw_error_t pcb_act_ArcNew(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	if (arc != NULL) {
 		RET_IDPATH(arc);
-		if (!noundo)
+		if (!noundo && !pcb_is_uilayer(layer))
 			pcb_undo_add_obj_to_create(PCB_OBJ_ARC, layer, arc, arc);
 	}
 	return 0;
@@ -192,7 +193,7 @@ static fgw_error_t pcb_act_TextNew(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	if (text != NULL) {
 		RET_IDPATH(text);
-		if (!noundo)
+		if (!noundo && !pcb_is_uilayer(layer))
 			pcb_undo_add_obj_to_create(PCB_OBJ_TEXT, layer, text, text);
 	}
 	return 0;
@@ -260,12 +261,74 @@ static fgw_error_t pcb_act_PolyNewFromRectangle(fgw_arg_t *res, int argc, fgw_ar
 
 	if (poly != NULL) {
 		RET_IDPATH(poly);
-		if (!noundo)
+		if (!noundo && !pcb_is_uilayer(layer))
 			pcb_undo_add_obj_to_create(PCB_OBJ_POLY, layer, poly, poly);
 	}
 	return 0;
 }
 
+static const char pcb_acts_UILayer[] =
+	"UILayer(new, name, color)\n"
+	"UILayer(free, layer)";
+static const char pcb_acth_UILayer[] = "Create or free UI layers. 'New' returns a layer ID that cna be used for addressing.";
+static fgw_error_t pcb_act_UILayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	const char *cmds;
+	int cmdi;
+	static const char uilayer_cookie[] = "act_draw/UILayer()";
+
+	RND_ACT_CONVARG(1, FGW_STR, UILayer, cmds = argv[1].val.str);
+	cmdi = act_draw_keywords_sphash(cmds);
+	switch(cmdi) {
+		case act_draw_keywords_new:
+		{
+			const char *name, *color;
+			pcb_layer_t *layer;
+			rnd_color_t clr;
+
+			RND_ACT_CONVARG(2, FGW_STR, UILayer, name = argv[2].val.str);
+			RND_ACT_CONVARG(3, FGW_STR, UILayer, color = argv[3].val.str);
+			if (rnd_color_load_str(&clr, color) != 0)
+				return FGW_ERR_ARG_CONV;
+
+			layer = pcb_uilayer_alloc(PCB_ACT_BOARD, uilayer_cookie, name, &clr);
+			if (layer == NULL)
+				return FGW_ERR_ARG_CONV;
+
+			res->type = FGW_STR | FGW_DYN;
+			res->val.str = rnd_strdup_printf("#%ld", pcb_uilayer_get_id(layer));
+			return 0;
+		}
+
+		case act_draw_keywords_free:
+		{
+			const char *slid;
+			char *end;
+			pcb_layer_t *layer;
+			long lid;
+
+			RND_ACT_CONVARG(2, FGW_STR, UILayer, slid = argv[2].val.str);
+			lid = strtol(slid+1, &end, 10);
+			if ((*slid != '#') || (*end != '\0'))
+				return FGW_ERR_ARG_CONV;
+			layer = pcb_uilayer_get(lid);
+			if (layer != NULL) {
+				pcb_uilayer_free(layer);
+				RND_ACT_IRES(0);
+			}
+			else
+				RND_ACT_IRES(-1);
+			return 0;
+		}
+
+		default:
+			return FGW_ERR_ARG_CONV;
+	}
+
+	return 0;
+}
+
+
 static long poly_append_ptlist(pcb_poly_t *poly, const char *ptlist)
 {
 	long len;
@@ -332,7 +395,7 @@ static fgw_error_t pcb_act_PolyNewFromPoints(fgw_arg_t *res, int argc, fgw_arg_t
 			pcb_poly_init_clip(data, layer, poly);
 			pcb_add_poly_on_layer(layer, poly);
 			RET_IDPATH(poly);
-			if (!noundo)
+			if (!noundo && !pcb_is_uilayer(layer))
 				pcb_undo_add_obj_to_create(PCB_OBJ_POLY, layer, poly, poly);
 		}
 	}
@@ -422,7 +485,7 @@ static fgw_error_t pcb_act_PolyNewEnd(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	pcb_add_poly_on_layer(layer, poly);
 
 	RET_IDPATH(poly);
-	if (!noundo)
+	if (!noundo && !pcb_is_uilayer(layer))
 		pcb_undo_add_obj_to_create(PCB_OBJ_POLY, layer, poly, poly);
 	fgw_ptr_unreg(&rnd_fgw, &argv[1], PTR_DOMAIN_POLY);
 	return 0;
@@ -597,6 +660,15 @@ static fgw_error_t pcb_act_DrawColor(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
+static const char pcb_acts_InvalidateAll[] = "InvalidateAll()";
+static const char pcb_acth_InvalidateAll[] = "Redraw the drawing area";
+static fgw_error_t pcb_act_InvalidateAll(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	rnd_gui->invalidate_all(rnd_gui);
+	RND_ACT_IRES(0);
+	return 0;
+}
+
 rnd_action_t act_draw_action_list[] = {
 	{"LineNew", pcb_act_LineNew, pcb_acth_LineNew, pcb_acts_LineNew},
 	{"ArcNew", pcb_act_ArcNew, pcb_acth_ArcNew, pcb_acts_ArcNew},
@@ -610,11 +682,13 @@ rnd_action_t act_draw_action_list[] = {
 	{"PstkProtoTmp", pcb_act_PstkProtoTmp, pcb_acth_PstkProtoTmp, pcb_acts_PstkProtoTmp},
 	{"PstkProtoEdit", pcb_act_PstkProtoEdit, pcb_acth_PstkProtoEdit, pcb_acts_PstkProtoEdit},
 	{"LayerObjDup", pcb_act_LayerObjDup, pcb_acth_LayerObjDup, pcb_acts_LayerObjDup},
+	{"UILayer", pcb_act_UILayer, pcb_acth_UILayer, pcb_acts_UILayer},
 	{"DrawText", pcb_act_DrawText, pcb_acth_DrawText, pcb_acts_DrawText},
 	{"DrawLine", pcb_act_DrawLine, pcb_acth_DrawLine, pcb_acts_DrawLine},
 	{"DrawPoly", pcb_act_DrawPoly, pcb_acth_DrawPoly, pcb_acts_DrawPoly},
 	{"DrawColor", pcb_act_DrawColor, pcb_acth_DrawColor, pcb_acts_DrawColor},
-	{"PolyBool", pcb_act_PolyBool, pcb_acth_PolyBool, pcb_acts_PolyBool}
+	{"PolyBool", pcb_act_PolyBool, pcb_acth_PolyBool, pcb_acts_PolyBool},
+	{"InvalidateAll", pcb_act_InvalidateAll, pcb_acth_InvalidateAll, pcb_acts_InvalidateAll}
 };
 
 static const char *act_draw_cookie = "act_draw";
