@@ -62,9 +62,12 @@ typedef struct {
 	rnd_export_opt_t *(*list_conf)(rnd_hidlib_t *hl, const char *method);
 } ext_router_t;
 
-#include "e_route-rnd.c"
+int pcb_ar_extern_progress(double p_total, double p1, double p2);
 
-static const ext_router_t *routers[] = { &route_rnd, NULL };
+#include "e_route-rnd.c"
+#include "e_freerouting.c"
+
+static const ext_router_t *routers[] = { &route_rnd, &freerouting, NULL };
 
 static const ext_router_t *find_router(const char *name)
 {
