@@ -38,8 +38,8 @@
 #ifndef PCB_AUTOPLACE_H
 #define PCB_AUTOPLACE_H
 
-#include "global_typedefs.h"
+#include <librnd/core/global_typedefs.h>
 
-pcb_bool AutoPlaceSelected(void);
+rnd_bool AutoPlaceSelected(void);
 
 #endif
