@@ -26,10 +26,10 @@
  *    mailing list: pcb-rnd (at) list.repo.hu (send "subscribe")
  */
 
-#include "hid_inlines.h"
-#include "compat_misc.h"
+#include <librnd/core/hid_inlines.h>
+#include <librnd/core/compat_misc.h>
 #include "conf_core.h"
-#include "hidlib_conf.h"
+#include <librnd/core/hidlib_conf.h>
 
 #define CLI_MAX_INS_LEN 128
 
@@ -96,9 +96,9 @@ struct cli_node_s {
 	int begin, end; /* cursor pos */
 	int invalid;
 
-	pcb_coord_t x, y, dist;
-	pcb_angle_t angle, offs;
-	pcb_cardinal_t id;
+	rnd_coord_t x, y, dist;
+	rnd_angle_t angle, offs;
+	rnd_cardinal_t id;
 };
 
 static const cli_ntype_t find_type(const char *type, int typelen)
@@ -109,7 +109,7 @@ static const cli_ntype_t find_type(const char *type, int typelen)
 		return CLI_INVALID;
 
 	for(p = cli_tnames; p->name != NULL; p++) {
-		if (pcb_strncasecmp(p->name, type, typelen) == 0) {
+		if (rnd_strncasecmp(p->name, type, typelen) == 0) {
 			if (found != NULL)
 				return CLI_INVALID; /* multiple match */
 			found = p;
@@ -151,7 +151,7 @@ static int cli_parse(cli_node_t *dst, int dstlen, const char *line)
 	char tmp[128];
 	char *sep, *s = strchr(line, ' '), *next; /* skip the instruction */
 	int i;
-	pcb_bool succ;
+	rnd_bool succ;
 
 	if (s == NULL)
 		return 0;
@@ -202,7 +202,7 @@ static int cli_parse(cli_node_t *dst, int dstlen, const char *line)
 							}
 							memcpy(tmp, s, sep-s);
 							tmp[sep-s] = '\0';
-							dst[i-1].x = pcb_get_value_ex(tmp, NULL, NULL, NULL, pcbhl_conf.editor.grid_unit->suffix, &succ);
+							dst[i-1].x = rnd_get_value_ex(tmp, NULL, NULL, NULL, rnd_conf.editor.grid_unit->suffix, &succ);
 							if (!succ)
 								dst[i-1].invalid = 1;
 
@@ -213,12 +213,12 @@ static int cli_parse(cli_node_t *dst, int dstlen, const char *line)
 							}
 							memcpy(tmp, sep, next-sep);
 							tmp[next-sep] = '\0';
-							dst[i-1].y = pcb_get_value_ex(tmp, NULL, NULL, NULL, pcbhl_conf.editor.grid_unit->suffix, &succ);
+							dst[i-1].y = rnd_get_value_ex(tmp, NULL, NULL, NULL, rnd_conf.editor.grid_unit->suffix, &succ);
 							if (!succ)
 								dst[i-1].invalid = 1;
 							break;
 						case CLI_DIST:
-							dst[i-1].dist = pcb_get_value_ex(s, NULL, NULL, NULL, pcbhl_conf.editor.grid_unit->suffix, &succ);
+							dst[i-1].dist = rnd_get_value_ex(s, NULL, NULL, NULL, rnd_conf.editor.grid_unit->suffix, &succ);
 							dst[i-1].invalid = !succ;
 							dst[i-1].end = next - line;
 							break;
@@ -278,11 +278,11 @@ static int cli_str_insert(char *str, int from, char *ins, int enforce_space_befo
 	return from + inslen + extra;
 }
 
-static int cli_apply_coord(cli_node_t *argv, int start, int end, pcb_coord_t *ox, pcb_coord_t *oy, int annot)
+static int cli_apply_coord(cli_node_t *argv, int start, int end, rnd_coord_t *ox, rnd_coord_t *oy, int annot)
 {
 	int n, relative = 0, have_angle = 0, have_dist = 0, len = (start > 1);
 	double angle = 0, dist = 0, lx, ly, x = *ox, y = *oy;
-	pcb_coord_t tx, ty;
+	rnd_coord_t tx, ty;
 
 	for(n = start; n < end; n++) {
 		int moved = 0;
@@ -355,13 +355,13 @@ static int cli_apply_coord(cli_node_t *argv, int start, int end, pcb_coord_t *ox
 				break;
 
 			case CLI_PERP:
-				pcb_message(PCB_MSG_ERROR, "perp not yet implemented\n");
+				rnd_message(RND_MSG_ERROR, "perp not yet implemented\n");
 				return -1;
 			case CLI_PARAL:
-				pcb_message(PCB_MSG_ERROR, "paral not yet implemented\n");
+				rnd_message(RND_MSG_ERROR, "paral not yet implemented\n");
 				return -1;
 			case CLI_TANGENT:
-				pcb_message(PCB_MSG_ERROR, "tangent not yet implemented\n");
+				rnd_message(RND_MSG_ERROR, "tangent not yet implemented\n");
 				return -1;
 
 			case CLI_CENTER:
@@ -413,8 +413,8 @@ static int cli_apply_coord(cli_node_t *argv, int start, int end, pcb_coord_t *ox
 				goto over;
 			apply:;
 				if (have_angle && have_dist) {
-					x += cos(angle / PCB_RAD_TO_DEG) * dist;
-					y += sin(angle / PCB_RAD_TO_DEG) * dist;
+					x += cos(angle / RND_RAD_TO_DEG) * dist;
+					y += sin(angle / RND_RAD_TO_DEG) * dist;
 					have_angle = have_dist = 0;
 					moved = 1;
 				}
@@ -425,13 +425,13 @@ static int cli_apply_coord(cli_node_t *argv, int start, int end, pcb_coord_t *ox
 
 		if (moved) {
 			if ((annot) && (len > 0)) {
-				pcb_coord_t *c = vtc0_alloc_append(&pcb_ddraft_attached.annot_lines, 4);
-				c[0] = pcb_round(lx);
-				c[1] = pcb_round(ly);
-				c[2] = pcb_round(x);
-				c[3] = pcb_round(y);
+				rnd_coord_t *c = vtc0_alloc_append(&pcb_ddraft_attached.annot_lines, 4);
+				c[0] = rnd_round(lx);
+				c[1] = rnd_round(ly);
+				c[2] = rnd_round(x);
+				c[3] = rnd_round(y);
 			}
-			angle = atan2(y - ly, x - lx) * PCB_RAD_TO_DEG;
+			angle = atan2(y - ly, x - lx) * RND_RAD_TO_DEG;
 			lx = x;
 			ly = y;
 			len++;
@@ -441,8 +441,8 @@ static int cli_apply_coord(cli_node_t *argv, int start, int end, pcb_coord_t *ox
 	over:;
 		if (have_angle || have_dist) /* could not apply */
 			return -1;
-	*ox = pcb_round(x);
-	*oy = pcb_round(y);
+	*ox = rnd_round(x);
+	*oy = rnd_round(y);
 	return n;
 }
 
@@ -450,20 +450,20 @@ static void cli_print_args(int argc, cli_node_t *argv)
 {
 	int n;
 	for(n = 0; n < argc; n++) {
-		pcb_trace(" [%d] %s/%d {%d..%d}", n, find_rev_type(argv[n].type), argv[n].type, argv[n].begin, argv[n].end);
+		rnd_trace(" [%d] %s/%d {%d..%d}", n, find_rev_type(argv[n].type), argv[n].type, argv[n].begin, argv[n].end);
 		if (!argv[n].invalid) {
 			switch(argv[n].type) {
-				case CLI_COORD: pcb_trace(": %$mm,%$mm", argv[n].x, argv[n].y); break;
-				case CLI_ANGLE: pcb_trace(": %f", argv[n].angle); break;
-				case CLI_DIST: pcb_trace(": %$mm", argv[n].dist); break;
-				case CLI_OFFS: pcb_trace(": %f", argv[n].offs); break;
-				case_object: pcb_trace(": %ld", (long)argv[n].id); break;
+				case CLI_COORD: rnd_trace(": %$mm,%$mm", argv[n].x, argv[n].y); break;
+				case CLI_ANGLE: rnd_trace(": %f", argv[n].angle); break;
+				case CLI_DIST: rnd_trace(": %$mm", argv[n].dist); break;
+				case CLI_OFFS: rnd_trace(": %f", argv[n].offs); break;
+				case_object: rnd_trace(": %ld", (long)argv[n].id); break;
 				default:;
 			}
-			pcb_trace("\n");
+			rnd_trace("\n");
 		}
 		else
-			pcb_trace(": INVALID\n");
+			rnd_trace(": INVALID\n");
 	}
 }
 
@@ -482,7 +482,7 @@ static const ddraft_op_t *find_op(const char *op, int oplen)
 		return NULL;
 
 	for(p = ddraft_ops; p->name != NULL; p++) {
-		if (pcb_strncasecmp(p->name, op, oplen) == 0) {
+		if (rnd_strncasecmp(p->name, op, oplen) == 0) {
 			if (found != NULL)
 				return NULL; /* multiple match */
 			found = p;
@@ -504,16 +504,16 @@ static fgw_error_t pcb_act_ddraft(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	int ndlen;
 
 	if (argc == 1) {
-		pcb_cli_enter("ddraft", "ddraft");
-		pcb_tool_select_by_id(&PCB->hidlib, pcb_ddraft_tool);
-		PCB_ACT_IRES(0);
+		rnd_cli_enter("ddraft", "ddraft");
+		rnd_tool_select_by_id(&PCB->hidlib, pcb_ddraft_tool);
+		RND_ACT_IRES(0);
 		return 0;
 	}
 
-	PCB_ACT_CONVARG(1, FGW_STR, ddraft, cmd = argv[1].val.str);
+	RND_ACT_CONVARG(1, FGW_STR, ddraft, cmd = argv[1].val.str);
 	if (strcmp(cmd, "/exit") == 0) {
-		pcb_cli_leave();
-		PCB_ACT_IRES(0);
+		rnd_cli_leave();
+		RND_ACT_IRES(0);
 		return 0;
 	}
 
@@ -521,13 +521,13 @@ static fgw_error_t pcb_act_ddraft(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if ((cmd != NULL) && (*cmd != '/'))
 		cline = cmd;
 	else
-		cline = pcb_hid_command_entry(NULL, &cursor);
+		cline = rnd_hid_command_entry(NULL, &cursor);
 	if (cline == NULL)
 		cline = "";
 
 	while(isspace(*cline)) cline++;
 	if ((*cline == '\n') || (*cline == '#') || (*cline == '\0')) { /* empty or comment */
-		PCB_ACT_IRES(0);
+		RND_ACT_IRES(0);
 		return 0;
 	}
 
@@ -550,8 +550,8 @@ static fgw_error_t pcb_act_ddraft(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	opp = find_op(op, oplen);
 	if (opp == NULL) {
 		if (strcmp(cmd, "/edit") != 0)
-			pcb_message(PCB_MSG_ERROR, "ddraft: unknown operator '%s'\n", op);
-		PCB_ACT_IRES(-1);
+			rnd_message(RND_MSG_ERROR, "ddraft: unknown operator '%s'\n", op);
+		RND_ACT_IRES(-1);
 		goto ret0;
 	}
 
@@ -560,20 +560,20 @@ static fgw_error_t pcb_act_ddraft(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	if (*cmd == '/') {
 		if (strcmp(cmd, "/click") == 0) {
-			PCB_ACT_IRES(opp->click(line, cursor, ndlen, nd));
+			RND_ACT_IRES(opp->click(line, cursor, ndlen, nd));
 			cmd = "/edit";
 			goto reparse;
 		}
 		else if (strcmp(cmd, "/tab") == 0)
-			PCB_ACT_IRES(opp->tab(line, cursor, ndlen, nd));
+			RND_ACT_IRES(opp->tab(line, cursor, ndlen, nd));
 		else if (strcmp(cmd, "/edit") == 0)
-			PCB_ACT_IRES(opp->edit(line, cursor, ndlen, nd));
+			RND_ACT_IRES(opp->edit(line, cursor, ndlen, nd));
 		else
-			PCB_ACT_IRES(0); /* ignore anything unhandled */
+			RND_ACT_IRES(0); /* ignore anything unhandled */
 		goto ret0;
 	}
 
-	PCB_ACT_IRES(opp->exec(line, ndlen, nd));
+	RND_ACT_IRES(opp->exec(line, ndlen, nd));
 
 	ret0:;
 	if (line != sline)
