@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2016,2019 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2016,2019,2021 Tibor 'Igor2' Palinkas
  *
  *  This module, diag, was written and is Copyright (C) 2016 by Tibor Palinkas
  *  this module is also subject to the GNU GPL as described below
@@ -51,118 +51,10 @@
 
 conf_diag_t conf_diag;
 
-static const char pcb_acts_DumpConf[] =
-	"dumpconf(native, [verbose], [prefix]) - dump the native (binary) config tree to stdout\n"
-	"dumpconf(lihata, role, [prefix]) - dump in-memory lihata representation of a config tree\n"
-	;
-static const char pcb_acth_DumpConf[] = "Perform various operations on the configuration tree.";
-
-extern lht_doc_t *pcb_conf_main_root[];
-extern lht_doc_t *pcb_conf_plug_root[];
-static fgw_error_t pcb_act_DumpConf(fgw_arg_t *res, int argc, fgw_arg_t *argv)
-{
-	int op;
-
-	RND_ACT_CONVARG(1, FGW_KEYWORD, DumpConf, op = fgw_keyword(&argv[1]));
-
-	switch(op) {
-		case F_Native:
-		{
-			int verbose = 0;
-			const char *prefix = "";
-			RND_ACT_MAY_CONVARG(2, FGW_INT, DumpConf, verbose = argv[2].val.nat_int);
-			RND_ACT_MAY_CONVARG(3, FGW_STR, DumpConf, prefix = argv[3].val.str);
-			conf_dump(stdout, prefix, verbose, NULL);
-		}
-		break;
-		case F_Lihata:
-		{
-		rnd_conf_role_t role;
-		const char *srole, *prefix = "";
-		RND_ACT_CONVARG(2, FGW_STR, DumpConf, srole = argv[2].val.str);
-		RND_ACT_MAY_CONVARG(3, FGW_STR, DumpConf, prefix = argv[3].val.str);
-		role = rnd_conf_role_parse(srole);
-		if (role == RND_CFR_invalid) {
-			rnd_message(RND_MSG_ERROR, "Invalid role: '%s'\n", argv[1]);
-			RND_ACT_IRES(1);
-			return 0;
-		}
-		if (pcb_conf_main_root[role] != NULL) {
-			printf("%s### main\n", prefix);
-			if (pcb_conf_main_root[role] != NULL)
-				lht_dom_export(pcb_conf_main_root[role]->root, stdout, prefix);
-			printf("%s### plugin\n", prefix);
-			if (pcb_conf_plug_root[role] != NULL)
-				lht_dom_export(pcb_conf_plug_root[role]->root, stdout, prefix);
-		}
-		else
-			printf("%s <empty>\n", prefix);
-		}
-		break;
-		default:
-			RND_ACT_FAIL(DumpConf);
-			return 1;
-	}
-
-	RND_ACT_IRES(0);
-	return 0;
-}
-
-static const char pcb_acts_EvalConf[] =
-	"EvalConf(path) - evaluate a config path in different config sources to figure how it ended up in the native database\n"
-	;
-static const char pcb_acth_EvalConf[] = "Perform various operations on the configuration tree.";
-
-static fgw_error_t pcb_act_EvalConf(fgw_arg_t *res, int argc, fgw_arg_t *argv)
-{
-	const char *path;
-	rnd_conf_native_t *nat;
-	int role;
-
-	RND_ACT_CONVARG(1, FGW_STR, EvalConf, path = argv[1].val.str);
-
-	nat = rnd_conf_get_field(path);
-	if (nat == NULL) {
-		rnd_message(RND_MSG_ERROR, "EvalConf: invalid path %s - no such config setting\n", path);
-		RND_ACT_IRES(-1);
-		return 0;
-	}
-
-	printf("Conf node %s\n", path);
-	for(role = 0; role < RND_CFR_max_real; role++) {
-		lht_node_t *n;
-		printf(" Role: %s\n", rnd_conf_role_name(role));
-		n = rnd_conf_lht_get_at(role, path, 0);
-		if (n != NULL) {
-			rnd_conf_policy_t pol = -1;
-			long prio = rnd_conf_default_prio[role];
-
-
-			if (rnd_conf_get_policy_prio(n, &pol, &prio) == 0)
-				printf("  * policy=%s\n  * prio=%ld\n", rnd_conf_policy_name(pol), prio);
-
-			if (n->file_name != NULL)
-				printf("  * from=%s:%d.%d\n", n->file_name, n->line, n->col);
-			else
-				printf("  * from=(unknown)\n");
-
-			lht_dom_export(n, stdout, "  ");
-		}
-		else
-			printf("  * not present\n");
-	}
-
-	printf(" Native:\n");
-	rnd_conf_print_native((rnd_conf_pfn)rnd_fprintf, stdout, "  ", 1, nat);
-
-	RND_ACT_IRES(0);
-	return 0;
-}
-
 static const char pcb_acts_DumpLayers[] = "dumplayers([all])\n";
 static const char pcb_acth_DumpLayers[] = "Print info about each layer";
 
-extern lht_doc_t *pcb_conf_main_root[];
+extern lht_doc_t *rnd_conf_main_root[];
 static fgw_error_t pcb_act_DumpLayers(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	int op = -2, g, n, used;
@@ -560,14 +452,12 @@ static fgw_error_t pcb_act_forcecolor(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 }
 
 rnd_action_t diag_action_list[] = {
-	{"dumpconf", pcb_act_DumpConf, pcb_acth_DumpConf, pcb_acts_DumpConf},
 	{"dumplayers", pcb_act_DumpLayers, pcb_acth_DumpLayers, pcb_acts_DumpLayers},
 	{"dumpfonts", pcb_act_DumpFonts, dump_fonts_help, dump_fonts_syntax},
 	{"dumpdata", pcb_act_DumpData, dump_data_help, dump_data_syntax},
 #ifndef NDEBUG
 	{"dumpundo", pcb_act_DumpUndo, dump_undo_help, dump_undo_syntax},
 #endif
-	{"EvalConf", pcb_act_EvalConf, pcb_acth_EvalConf, pcb_acts_EvalConf},
 	{"d1", pcb_act_d1, pcb_acth_d1, pcb_acts_d1},
 	{"find2perf", pcb_act_Find2Perf, pcb_acth_Find2Perf, pcb_acts_Find2Perf},
 	{"integrity", pcb_act_integrity, integrity_help, integrity_syntax},
@@ -577,6 +467,9 @@ rnd_action_t diag_action_list[] = {
 	{"forcecolor", pcb_act_forcecolor, pcb_acth_forcecolor, pcb_acts_forcecolor}
 };
 
+extern void Rnd_diag_init(const char *cookie);
+
+
 static const char *diag_cookie = "diag plugin";
 
 int pplg_check_ver_diag(int ver_needed) { return 0; }
