@@ -83,10 +83,18 @@ static pcb_layer_type_t int2side(int i)
 	return 0;
 }
 
-static int side2int(pcb_layer_type_t s)
+static int side2int(pcb_layer_type_t s, int offs)
 {
 	if (s & PCB_LYT_TOP) return 0;
 	if (s & PCB_LYT_BOTTOM) return 1;
+
+	if ((s & PCB_LYT_COPPER) && (s & PCB_LYT_INTERN)) { /* copper internal layers are addressed from top or bottom */
+		if (offs > 0)
+			return 0;
+		else
+			return 1;
+	}
+
 	return 2;
 }
 
@@ -169,7 +177,7 @@ static void lb_data2dialog(void *hid_ctx, lb_ctx_t *ctx)
 		/* disable side for non-sided */
 		if (PCB_LAYER_SIDED(layer->meta.bound.type)) {
 			/* side & offset */
-			RND_DAD_SET_VALUE(hid_ctx, w->side, lng, side2int(layer->meta.bound.type));
+			RND_DAD_SET_VALUE(hid_ctx, w->side, lng, side2int(layer->meta.bound.type, layer->meta.bound.stack_offs));
 			rnd_gui->attr_dlg_widget_state(hid_ctx, w->side, 1);
 		}
 		else
@@ -205,8 +213,9 @@ static void lb_dialog2data(void *hid_ctx, lb_ctx_t *ctx)
 		pcb_layer_t *layer = ctx->data->Layer + n;
 
 		if (layer_name_mismatch(w, layer)) {
+			const char *dlg_name = ctx->attrs[w->name].val.str;
 			free((char *)layer->name);
-			layer->name = rnd_strdup(ctx->attrs[w->name].val.str);
+			layer->name = rnd_strdup(dlg_name == NULL ? "" : dlg_name);
 		}
 
 		if (layer_purpose_mismatch(w, layer)) {
@@ -249,12 +258,6 @@ rnd_trace("l2r!\n");
 	lb_data2dialog(hid_ctx, ctx); /* update disables */
 }
 
-static void lb_attr_chg(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
-{
-	if (attr->user_data == NULL) /* do not handle widgets globally if they have data - they then have a local callback too */
-		lb_update_left2right(hid_ctx, caller_data);
-}
-
 static void lb_attr_layer_chg(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
 	lb_ctx_t *ctx = caller_data;
@@ -297,6 +300,12 @@ static void lb_attr_layer_chg(void *hid_ctx, void *caller_data, rnd_hid_attribut
 	lb_update_left2right(hid_ctx, ctx);
 }
 
+static void lb_attr_chg(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	if (attr->change_cb != lb_attr_layer_chg) /* this one is handled by the widget */
+		lb_update_left2right(hid_ctx, caller_data);
+}
+
 const char pcb_acts_LayerBinding[] = "LayerBinding(object)\nLayerBinding(buffer)\n";
 const char pcb_acth_LayerBinding[] = "Change the layer binding.";
 fgw_error_t pcb_act_LayerBinding(fgw_arg_t *res, int argc, fgw_arg_t *argv)
