@@ -407,7 +407,7 @@ static void pstklib_save(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 	if (proto_save_fn == NULL)
 		proto_save_fn = rnd_strdup("padstack.lht");
 	old_fn = proto_save_fn;
-	proto_save_fn = rnd_gui->fileselect(rnd_gui, "Save padstack", "Select a file the padstack prototype is saved to", old_fn, ".lht", NULL, "padstack", 0, NULL);
+	proto_save_fn = rnd_hid_fileselect(rnd_gui, "Save padstack", "Select a file the padstack prototype is saved to", old_fn, ".lht", NULL, "padstack", 0, NULL);
 	if (proto_save_fn == NULL)
 		return; /* cancel */
 	free(old_fn);
@@ -422,6 +422,7 @@ static void pstklib_save(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 		rnd_message(RND_MSG_INFO, "Padstack saved to %s.\n", proto_save_fn);
 	else
 		rnd_message(RND_MSG_ERROR, "Padstack not saved to %s.\n", proto_save_fn);
+	fclose(f);
 }
 
 static void pstklib_load(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -448,7 +449,7 @@ static void pstklib_load(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 	if (proto_load_fn == NULL)
 		proto_load_fn = rnd_strdup("padstack.lht");
 	old_fn = proto_load_fn;
-	proto_load_fn = rnd_gui->fileselect(rnd_gui, "Save padstack", "Select a file the padstack prototype is loaded from", old_fn, ".lht", NULL, "padstack", RND_HID_FSD_READ, NULL);
+	proto_load_fn = rnd_hid_fileselect(rnd_gui, "Save padstack", "Select a file the padstack prototype is loaded from", old_fn, ".lht", NULL, "padstack", RND_HID_FSD_READ, NULL);
 	if (proto_load_fn == NULL)
 		return; /* cancel */
 	free(old_fn);
@@ -882,7 +883,7 @@ rnd_cardinal_t pcb_dlg_pstklib(pcb_board_t *pcb, long subc_id, rnd_bool modal, r
 	return 0;
 }
 
-const char pcb_acts_pstklib[] = "pstklib([board|subcid|object], [retpid, [preselect]])\n";
+const char pcb_acts_pstklib[] = "pstklib([auto|board|subcid|object], [retpid, [preselect]])\n";
 const char pcb_acth_pstklib[] = "Present the padstack library dialog on board padstacks or the padstacks of a subcircuit";
 fgw_error_t pcb_act_pstklib(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
@@ -911,11 +912,21 @@ fgw_error_t pcb_act_pstklib(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		sc = r2;
 		id = sc->ID;
 	}
+	else if ((cmd != NULL) && (strcmp(cmd, "auto") == 0)) {
+		auto_fp:;
+		if (PCB->is_footprint) {
+			pcb_subc_t *sc = pcb_subclist_first(&PCB->Data->subc);
+			if (sc != NULL)
+				id = sc->ID;
+		}
+	}
 	else if ((cmd != NULL) && (strcmp(cmd, "board") == 0)) {
 		/* defaults are fine */
 	}
-	else
+	else {
 		RND_ACT_MAY_CONVARG(1, FGW_LONG, pstklib, id = argv[1].val.nat_long);
+		goto auto_fp;
+	}
 
 	pid = pcb_dlg_pstklib(PCB, id, modal, presel, NULL);
 	if (pid != PCB_PADSTACK_INVALID) {
