@@ -42,8 +42,8 @@
 static const char *shapes[] = { "circle", "square", NULL };
 static const char *sides[] = { "all (top, bottom, intern)", "top & bottom only", "top only", "bottom only", "none", NULL };
 static pcb_layer_type_t sides_lyt[] = { PCB_LYT_TOP | PCB_LYT_BOTTOM | PCB_LYT_INTERN, PCB_LYT_TOP | PCB_LYT_BOTTOM, PCB_LYT_TOP, PCB_LYT_BOTTOM, 0 };
-static const char *thermal_type[] =  {"no thermal", "round", "sharp", "diagonal round", "diagonal sharp", "solid connection", "no shape", NULL};
-static pcb_thermal_t thermal_bit[] = {0, PCB_THERMAL_ON|PCB_THERMAL_ROUND, PCB_THERMAL_ON|PCB_THERMAL_SHARP, PCB_THERMAL_ON|PCB_THERMAL_ROUND|PCB_THERMAL_DIAGONAL, PCB_THERMAL_ON|PCB_THERMAL_SHARP|PCB_THERMAL_DIAGONAL, PCB_THERMAL_ON|PCB_THERMAL_SOLID, PCB_THERMAL_ON|PCB_THERMAL_NOSHAPE};
+static const char *pcb_thermal_type[] =  {"no thermal", "round", "sharp", "diagonal round", "diagonal sharp", "solid connection", "no shape", NULL};
+static pcb_thermal_t pcb_thermal_bit[] = {0, PCB_THERMAL_ON|PCB_THERMAL_ROUND, PCB_THERMAL_ON|PCB_THERMAL_SHARP, PCB_THERMAL_ON|PCB_THERMAL_ROUND|PCB_THERMAL_DIAGONAL, PCB_THERMAL_ON|PCB_THERMAL_SHARP|PCB_THERMAL_DIAGONAL, PCB_THERMAL_ON|PCB_THERMAL_SOLID, PCB_THERMAL_ON|PCB_THERMAL_NOSHAPE};
 
 /* build a group/layer name string in tmp */
 char *pse_group_string(pcb_board_t *pcb, pcb_layergrp_t *grp, char *out, int size)
@@ -99,8 +99,8 @@ static void pse_ps2dlg(void *hid_ctx, pse_t *pse)
 	for(n = 0; n < pse->thermal.len; n++) {
 		rnd_layer_id_t lid = pse->thermal.lid[n];
 		int th = lid < pse->ps->thermals.used ? pse->ps->thermals.shape[lid] : 0;
-		for(i = 0; i < sizeof(thermal_bit) / sizeof(thermal_bit[0]); i++) {
-			if (thermal_bit[i] == th) {
+		for(i = 0; i < sizeof(pcb_thermal_bit) / sizeof(pcb_thermal_bit[0]); i++) {
+			if (pcb_thermal_bit[i] == th) {
 				RND_DAD_SET_VALUE(hid_ctx, pse->thermal.wtype[n], lng, i);
 				break;
 			}
@@ -303,7 +303,7 @@ static void pse_chg_thermal(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 
 	for(thi = 0; thi < pse->thermal.len; thi++) {
 		if (pse->thermal.wtype[thi] == wid) {
-			pcb_pstk_set_thermal(pse->ps, pse->thermal.lid[thi], thermal_bit[attr->val.lng], 1);
+			pcb_pstk_set_thermal(pse->ps, pse->thermal.lid[thi], pcb_thermal_bit[attr->val.lng], 1);
 			pcb_undo_inc_serial();
 			rnd_gui->invalidate_all(rnd_gui);
 			return;
@@ -891,7 +891,7 @@ void pcb_pstkedit_dialog(pse_t *pse, int target_tab)
 									RND_DAD_LABEL(dlg, ly->name);
 									pse->thermal.lid[pse->thermal.len] = g->lid[n];
 									RND_DAD_BEGIN_HBOX(dlg);
-										RND_DAD_ENUM(dlg, thermal_type);
+										RND_DAD_ENUM(dlg, pcb_thermal_type);
 										pse->thermal.wtype[pse->thermal.len] = RND_DAD_CURRENT(dlg);
 										RND_DAD_CHANGE_CB(dlg, pse_chg_thermal);
 									RND_DAD_END(dlg);
