@@ -243,7 +243,7 @@ static void view_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv,
 	pcb_draw_force_termlab = 1;
 	memset(&xform, 0, sizeof(xform));
 	xform.layer_faded = 1;
-	rnd_expose_main(rnd_gui, e, &xform);
+	rnd_app.expose_main(rnd_gui, e, &xform);
 	pcb_draw_force_termlab = old_termlab;
 
 	/* restore object color */
@@ -441,7 +441,7 @@ static void view_save_btn_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 	char *fn;
 	FILE *f;
 
-	fn = rnd_gui->fileselect(rnd_gui, "Save view list", "Save all views from the list", "view.lht", "lht", NULL, "view", 0, NULL);
+	fn = rnd_hid_fileselect(rnd_gui, "Save view list", "Save all views from the list", "view.lht", "lht", NULL, "view", 0, NULL);
 	if (fn == NULL)
 		return;
 
@@ -470,7 +470,7 @@ static void view_load_btn_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 	FILE *f;
 	void *load_ctx;
 
-	fn = rnd_gui->fileselect(rnd_gui, "Load view list", "Load all views from the list", "view.lht", "lht", NULL, "view", RND_HID_FSD_READ, NULL);
+	fn = rnd_hid_fileselect(rnd_gui, "Load view list", "Load all views from the list", "view.lht", "lht", NULL, "view", RND_HID_FSD_READ, NULL);
 	if (fn == NULL)
 		return;
 
@@ -750,7 +750,7 @@ void drc_extra_buttons(view_ctx_t *ctx)
 }
 
 static view_ctx_t drc_gui_ctx = {0};
-const char pcb_acts_DrcDialog[] = "DrcDialog([list|simple]\n";
+const char pcb_acts_DrcDialog[] = "DrcDialog([list|simple])\n";
 const char pcb_acth_DrcDialog[] = "Execute drc checks and invoke a view list dialog box for presenting the results";
 fgw_error_t pcb_act_DrcDialog(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
