@@ -4,7 +4,7 @@
  *
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
- *  Copyright (C) 2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2020,2021 Tibor 'Igor2' Palinkas
  *  (Supported by NLnet NGI0 PET Fund in 2020)
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -35,6 +35,20 @@
 
 #define PCB dont_use
 
+/* Return the lihata node that describes a rule source */
+static lht_node_t *rule_src_node(const char *name)
+{
+	gdl_iterator_t it;
+	rnd_conf_listitem_t *i;
+
+	rnd_conflist_foreach(&conf_drc_query.plugins.drc_query.rules, &it, i) {
+		lht_node_t *rule = i->prop.src;
+		if (strcmp(rule->name, name) == 0)
+			return rule;
+	}
+	return NULL;
+}
+
 typedef struct{
 	RND_DAD_DECL_NOINIT(dlg)
 	drc_query_prog_t *prog;
@@ -146,7 +160,7 @@ static void drc_dlist_pcb2dlg(void);
 typedef struct{
 	RND_DAD_DECL_NOINIT(dlg)
 	rnd_conf_role_t role;
-	char *rule, *path;
+	char *rule;
 	int wtype, wtitle, wsource, wdisable, wdesc, wquery, wsave, wsaveroles;
 	gdl_elem_t link;
 } rule_edit_ctx_t;
@@ -163,7 +177,6 @@ static void rule_edit_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
 
 	gdl_remove(&rule_edit_dialogs, ctx, link);
 
-	free(ctx->path);
 	free(ctx->rule);
 	RND_DAD_FREE(ctx->dlg);
 	free(ctx);
@@ -172,7 +185,7 @@ static void rule_edit_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
 static void drc_rule_pcb2dlg(rule_edit_ctx_t *ctx)
 {
 	rnd_dad_retovr_t retovr;
-	lht_node_t *nd = rnd_conf_lht_get_at_mainplug(ctx->role, ctx->path, 1, 0);
+	lht_node_t *nd = rule_src_node(ctx->rule);
 	if (nd != NULL) {
 		rnd_hid_attribute_t *atxt = &ctx->dlg[ctx->wquery];
 		rnd_hid_text_t *txt = atxt->wdata;
@@ -244,8 +257,8 @@ static void rule_btn_save_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 	}
 
 	role = save_rolee[ri];
-	nd = rnd_conf_lht_get_at_mainplug(role, ctx->path, 1, 0);
-	if (nd == NULL) {
+	nd = rule_src_node(ctx->rule);
+	if ((nd == NULL) || rnd_conf_is_read_only(ctx->role)) {
 		MKDIR_RULE_ROOT(nd, role, RND_POL_OVERWRITE, return);
 		MKDIR_RULES(nd, return);
 		if ((nd->data.list.first == NULL) && (role != RND_CFR_USER)) {
@@ -273,12 +286,13 @@ static void rule_btn_save_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 	drc_rlist_pcb2dlg();
 }
 
+
 static int pcb_dlg_rule_edit(rnd_conf_role_t role, const char *rule)
 {
 	rnd_hid_dad_buttons_t clbtn[] = {{"Close", 0}, {NULL, 0}};
-	char *info, *path;
+	char *info;
 	rule_edit_ctx_t *ctx;
-	lht_node_t *nd;
+	lht_node_t *nd = NULL;
 	int n, srolei = save_role_defaulti;
 
 	for(ctx = gdl_first(&rule_edit_dialogs); ctx != NULL; ctx = gdl_next(&rule_edit_dialogs, ctx))
@@ -289,8 +303,7 @@ static int pcb_dlg_rule_edit(rnd_conf_role_t role, const char *rule)
 		}
 	}
 
-	path = rnd_concat(DRC_CONF_PATH_RULES, rule, ":0", NULL);
-	nd = rnd_conf_lht_get_at_mainplug(role, path, 1, 0);
+	nd = rule_src_node(rule);
 	if (nd == NULL) {
 		rnd_message(RND_MSG_ERROR, "Rule %s not found on this role.\n", rule);
 		return -1;
@@ -299,7 +312,6 @@ static int pcb_dlg_rule_edit(rnd_conf_role_t role, const char *rule)
 	ctx = calloc(sizeof(rule_edit_ctx_t), 1);
 	ctx->role = role;
 	ctx->rule = rnd_strdup(rule);
-	ctx->path = path;
 
 	gdl_insert(&rule_edit_dialogs, ctx, link);
 
@@ -525,6 +537,31 @@ static void rlist_btn_toggle_cb(void *hid_ctx, void *caller_data, rnd_hid_attrib
 	drc_rlist_pcb2dlg();
 }
 
+static void rlist_btn_remove_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr_inp)
+{
+	drc_rlist_ctx_t *ctx = caller_data;
+	rnd_hid_row_t *row = rnd_dad_tree_get_selected(&(ctx->dlg[ctx->wrlist]));
+	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_hidlib(hid_ctx);
+	rnd_conf_role_t role;
+
+	if (row == NULL) {
+		rnd_message(RND_MSG_ERROR, "Select a rule first!\n");
+		return;
+	}
+
+	role = rnd_conf_role_parse(row->cell[1]);
+	if (rnd_conf_is_read_only(role)) {
+		rnd_message(RND_MSG_ERROR, "Can't remove rule on config role %s\n", row->cell[1]);
+		return;
+	}
+
+	/* problem: we don't know what definitions to remove */
+	rnd_actionva(&pcb->hidlib, "DrcQueryRuleMod", "remove", row->cell[0], NULL);
+
+	drc_rlist_pcb2dlg();
+}
+
+
 #define rlist_fetch() \
 do { \
 	if (row == NULL) { \
@@ -652,6 +689,16 @@ static void rlist_select(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row
 	rnd_conf_role_t role;
 	pcb_drcq_stat_t *st;
 
+	if (row == NULL) {
+		hv.str = "-";
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wrule, &hv);
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wtype, &hv);
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wtitle, &hv);
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wdesc, &hv);
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wstat, &hv);
+		return;
+	}
+
 	rlist_fetch();
 	rlist_fetch_nd();
 
@@ -789,6 +836,16 @@ static void dlist_select(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row
 	gds_t tmp;
 	rnd_conf_native_t *nat;
 
+	if (row == NULL) {
+		hv.str = "-";
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wdef, &hv);
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wdtype, &hv);
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wddesc, &hv);
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wdefault, &hv);
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wvalue, &hv);
+		return;
+	}
+
 	dlist_fetch();
 	dlist_fetch_nd();
 
@@ -859,6 +916,8 @@ static void pcb_dlg_drc_rlist_rules(int *wpane)
 					RND_DAD_CHANGE_CB(drc_rlist_ctx.dlg, rlist_btn_edit_cb);
 				RND_DAD_BUTTON(drc_rlist_ctx.dlg, "Toggle disable");
 					RND_DAD_CHANGE_CB(drc_rlist_ctx.dlg, rlist_btn_toggle_cb);
+				RND_DAD_BUTTON(drc_rlist_ctx.dlg, "Remove");
+					RND_DAD_CHANGE_CB(drc_rlist_ctx.dlg, rlist_btn_remove_cb);
 				RND_DAD_BUTTON(drc_rlist_ctx.dlg, "Export...");
 					RND_DAD_CHANGE_CB(drc_rlist_ctx.dlg, rlist_btn_export_cb);
 				RND_DAD_BUTTON(drc_rlist_ctx.dlg, "Import...");
