@@ -67,10 +67,12 @@ static const char *drc_query_cookie = "drc_query";
 
 extern conf_drc_query_t conf_drc_query;
 
+#define DRC_CONF_PATH_RULES_NODE "plugins/drc_query/rules"
+
 #define DRC_CONF_PATH_PLUGIN "plugins/drc_query/"
 #define DRC_CONF_PATH_DISABLE "design/drc_disable/"
 #define DRC_CONF_PATH_CONST "design/drc/"
-#define DRC_CONF_PATH_RULES "plugins/drc_query/rules/"
+#define DRC_CONF_PATH_RULES DRC_CONF_PATH_RULES_NODE "/"
 #define DRC_CONF_PATH_DEFS "plugins/drc_query/definitions/"
 
 typedef struct {
@@ -127,6 +129,8 @@ void drc_qry_exec_cb(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current)
 		bv = res->data.lng != 0;
 	else if (res->type == PCBQ_VT_LST)
 		bv = res->data.lst.used > 0;
+	else if (res->type == PCBQ_VT_OBJ)
+		bv = res->data.obj != NULL;
 	else
 		return;
 
@@ -631,6 +635,24 @@ static int pcb_drc_query_set(rnd_hidlib_t *hidlib, int is_rule, const char *rule
 	return 0;
 }
 
+static int pcb_drc_query_remove(rnd_hidlib_t *hidlib, int is_rule, const char *name)
+{
+	const rnd_conflist_t *l = DRC_QUERY_RULE_OR_DEF(is_rule);
+	gdl_iterator_t it;
+	rnd_conf_listitem_t *i;
+
+	rnd_conflist_foreach(l, &it, i) {
+		lht_node_t *rule = i->prop.src;
+		if ((rule != NULL) && (strcmp(rule->name, name) == 0)) {
+			rnd_conflist_remove(i);
+			lht_tree_del(rule);
+			return 0;
+		}
+	}
+
+	return -1;
+}
+
 static int pcb_drc_query_get(rnd_hidlib_t *hidlib, int is_rule, const char *rule, const char *key, fgw_arg_t *res)
 {
 	lht_node_t *nd;
@@ -681,7 +703,8 @@ static const char pcb_acts_DrcQueryRuleMod[] = \
 	"DrcQueryRuleMod(clear, source)\n"
 	"DrcQueryRuleMod(create, rule_name)\n"
 	"DrcQueryRuleMod(get, rule_name, field_name)\n"
-	"DrcQueryRuleMod(set, rule_name, field_name, value)\n";
+	"DrcQueryRuleMod(set, rule_name, field_name, value)\n"
+	"DrcQueryRuleMod(remove, rule_name)\n";
 static const char pcb_acth_DrcQueryRuleMod[] = "Automated DRC rule editing (for scripting and import)";
 static fgw_error_t pcb_act_DrcQueryRuleMod(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
@@ -697,6 +720,7 @@ static fgw_error_t pcb_act_DrcQueryRuleMod(fgw_arg_t *res, int argc, fgw_arg_t *
 	if (strcmp(cmd, "clear") == 0) resi = pcb_drc_query_clear(hl, 1, target);
 	else if (strcmp(cmd, "create") == 0) resi = pcb_drc_query_create(hl, 1, target);
 	else if (strcmp(cmd, "set") == 0) resi = pcb_drc_query_set(hl, 1, target, key, val);
+	else if (strcmp(cmd, "remove") == 0) resi = pcb_drc_query_remove(hl, 1, target);
 	else if (strcmp(cmd, "get") == 0) {
 		if (strcmp(key, "defs") == 0)
 			return pcb_drc_query_get_rule_defs(hl, target, res);
@@ -772,7 +796,7 @@ static fgw_error_t pcb_act_DrcQueryExport(fgw_arg_t *res, int argc, fgw_arg_t *a
 		const char *ext = ".tdx", *sep;
 		char *fnid = rnd_concat(id, ext, NULL);
 TODO("cleanup: fix format selection: generalize dlg_loadsave.c's subfmt code");
-		fn = autofree = rnd_gui->fileselect(rnd_gui, "drc_query_rule", "Export a drc_query rule and related definitions",
+		fn = autofree = rnd_hid_fileselect(rnd_gui, "drc_query_rule", "Export a drc_query rule and related definitions",
 			fnid, ext, flt, "drc_query", 0, NULL);
 		free(fnid);
 		if (fn == NULL)
@@ -815,7 +839,7 @@ static fgw_error_t pcb_act_DrcQueryImport(fgw_arg_t *res, int argc, fgw_arg_t *a
 
 	if (fn == NULL) {
 		const char *ext = ".tdx";
-		fn = autofree = rnd_gui->fileselect(rnd_gui, "drc_query_rule", "Import a drc_query rule and related definitions",
+		fn = autofree = rnd_hid_fileselect(rnd_gui, "drc_query_rule", "Import a drc_query rule and related definitions",
 			NULL, ext, flt, "drc_query", RND_HID_FSD_READ, NULL);
 		if (fn == NULL)
 			return -1;
