@@ -235,7 +235,7 @@ static void excellon_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	fnbase = options[HA_excellonfile].str;
 	if (!fnbase)
-		fnbase = "pcb-out";
+		fnbase = "pcb-rnd-out";
 
 	i = strlen(fnbase);
 	filename = (char *) realloc(filename, i + SUFF_LEN);
@@ -252,11 +252,11 @@ static void excellon_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	lastwidth = -1;
 	finding_apertures = 1;
-	rnd_expose_main(&excellon_hid, &ctx, &xform);
+	rnd_app.expose_main(&excellon_hid, &ctx, &xform);
 
 	lastwidth = -1;
 	finding_apertures = 0;
-	rnd_expose_main(&excellon_hid, &ctx, &xform);
+	rnd_app.expose_main(&excellon_hid, &ctx, &xform);
 	rnd_conf_update(NULL, -1); /* resotre forced sets */
 
 
