@@ -65,15 +65,15 @@ static rnd_hid_t fidocadj_hid;
 
 const char *fidocadj_cookie = "fidocadj HID";
 
-rnd_export_opt_t fidocadj_attribute_list[] = {
+static const rnd_export_opt_t fidocadj_attribute_list[] = {
 	/* other HIDs expect this to be first.  */
 
 	{"outfile", "Output file name",
-	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_fidocadjfile 0
 
 	{"libfile", "path to PCB.fcl",
-	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_libfile 1
 };
 
@@ -81,12 +81,12 @@ rnd_export_opt_t fidocadj_attribute_list[] = {
 
 static rnd_hid_attr_val_t fidocadj_values[NUM_OPTIONS];
 
-static rnd_export_opt_t *fidocadj_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *fidocadj_get_export_options(rnd_hid_t *hid, int *n)
 {
 	const char *suffix = ".fcd";
-	char **val = fidocadj_attribute_list[HA_fidocadjfile].value;
-	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &fidocadj_attribute_list[HA_fidocadjfile], suffix);
+	const char *val = fidocadj_values[HA_fidocadjfile].str;
+	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(PCB->hidlib.filename, &fidocadj_values[HA_fidocadjfile], suffix);
 
 	if (n)
 		*n = NUM_OPTIONS;
@@ -387,6 +387,7 @@ int pplg_init_export_fidocadj(void)
 	fidocadj_hid.usage = fidocadj_usage;
 
 	rnd_hid_register_hid(&fidocadj_hid);
+	rnd_hid_load_defaults(&fidocadj_hid, fidocadj_attribute_list, NUM_OPTIONS);
 
 	return 0;
 }
