@@ -989,7 +989,7 @@ static void ia_save_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 	FILE *f;
 	gds_t tmp;
 
-	fname = rnd_gui->fileselect(rnd_gui, "Save mesh settings...",
+	fname = rnd_hid_fileselect(rnd_gui, "Save mesh settings...",
 															"Picks file for saving mesh settings.\n",
 															default_file, ".lht", NULL, "mesh", RND_HID_FSD_MAY_NOT_EXIST, NULL);
 	if (fname == NULL)
@@ -1036,7 +1036,7 @@ static void ia_load_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 {
 	char *fname = NULL;
 
-	fname = rnd_gui->fileselect(rnd_gui, "Load mesh settings...",
+	fname = rnd_hid_fileselect(rnd_gui, "Load mesh settings...",
 															"Picks file for loading mesh settings from.\n",
 															default_file, ".lht", NULL, "mesh", RND_HID_FSD_READ, NULL);
 	if (fname == NULL)
