@@ -588,14 +588,14 @@ void ps_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options, rnd_xf
 		fprintf(the_file, "/tocp { /y y 12 sub def 90 y moveto rightshow } bind def\n");
 
 		global.doing_toc = 1;
-		global.pagecount = 1;				/* 'pagecount' is modified by rnd_expose_main() call */
-		rnd_expose_main(&ps_hid, &global.exps, xform);
+		global.pagecount = 1;				/* 'pagecount' is modified by rnd_app.expose_main() call */
+		rnd_app.expose_main(&ps_hid, &global.exps, xform);
 	}
 
 	global.pagecount = 1;					/* Reset 'pagecount' if single file */
 	global.doing_toc = 0;
 	ps_set_layer_group(rnd_render, -1, NULL, -1, -1, 0, -1, NULL); /* reset static vars */
-	rnd_expose_main(&ps_hid, &global.exps, xform);
+	rnd_app.expose_main(&ps_hid, &global.exps, xform);
 
 	if (the_file)
 		fprintf(the_file, "showpage\n");
@@ -621,7 +621,7 @@ static void ps_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	global.filename = options[HA_psfile].str;
 	if (!global.filename)
-		global.filename = "pcb-out.ps";
+		global.filename = "pcb-rnd-out.ps";
 
 	/* cam mode shall result in a single file, no matter what other attributes say */
 	if (ps_cam.active) {
