@@ -42,6 +42,7 @@
 #include <genvector/gds_char.h>
 
 #include <librnd/core/math_helper.h>
+#include <librnd/core/hidlib_conf.h>
 #include "board.h"
 #include "data.h"
 #include "draw.h"
@@ -94,7 +95,7 @@ static const char *CAPS(rnd_cap_style_t cap)
 
 static FILE *f = NULL;
 static int group_open = 0;
-static int opacity = 100, drawing_mask, drawing_hole, photo_mode, flip;
+static int opacity = 100, drawing_mask, drawing_hole, photo_mode, photo_noise, flip;
 
 static gds_t sbright, sdark, snormal, sclip;
 static rnd_composite_op_t drawing_mode;
@@ -183,9 +184,13 @@ Flip board, look at it from the bottom side
 	 RND_HATT_BOOL, 0, 0, {0, 0, 0}, 0},
 #define HA_true_size 5
 
+	{"photo-noise", "Add noise in photo mode to make the output more realistic",
+	 RND_HATT_BOOL, 0, 0, {0, 0, 0}, 0},
+#define HA_photo_noise 6
+
 	{"cam", "CAM instruction",
 	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0}
-#define HA_cam 6
+#define HA_cam 7
 };
 
 #define NUM_OPTIONS (sizeof(svg_attribute_list)/sizeof(svg_attribute_list[0]))
@@ -235,9 +240,23 @@ void svg_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options, rnd_x
 		else
 			photo_mode = 0;
 
+		if (options[HA_photo_noise].lng)
+			photo_noise = 1;
+		else
+			photo_noise = 0;
+
 		if (options[HA_flip].lng) {
+			rnd_layer_id_t topcop[32];
+			int n, v;
+
 			flip = 1;
 			rnd_conf_force_set_bool(conf_core.editor.show_solder_side, 1);
+
+			/* make sure bottom side copper is top on visibility so it is rendered last */
+			pcb_layervis_save_stack();
+			v = pcb_layer_list(PCB, PCB_LYT_BOTTOM | PCB_LYT_COPPER, topcop, sizeof(topcop)/sizeof(topcop[0]));
+			for(n = 0; n < v; n++)
+				pcb_layervis_change_group_vis(&PCB->hidlib, topcop[n], 1, 1);
 		}
 		else
 			flip = 0;
@@ -263,8 +282,10 @@ void svg_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options, rnd_x
 		xform->enable_silk_invis_clr = 1;
 	}
 
-	rnd_expose_main(&svg_hid, &ctx, xform);
+	rnd_app.expose_main(&svg_hid, &ctx, xform);
 
+	if (flip)
+		pcb_layervis_restore_stack();
 	rnd_conf_update(NULL, -1); /* restore forced sets */
 }
 
@@ -326,6 +347,17 @@ static void svg_footer(void)
 		group_open--;
 	}
 
+	/* blend some noise on top to make it a bit more artificial */
+	if (photo_mode && photo_noise) {
+		fprintf(f, "<filter id=\"noise\">\n");
+		fprintf(f, "	<feTurbulence type=\"fractalNoise\" baseFrequency=\"30\" result=\"noisy\" />\n");
+		fprintf(f, "</filter>\n");
+		fprintf(f, "<g opacity=\"0.25\">\n");
+		rnd_fprintf(f, "	<rect filter=\"url(#noise)\" x=\"%mm\" y=\"%mm\" width=\"%mm\" height=\"%mm\" fill=\"none\" stroke=\"none\"/>\n",
+			0, 0, PCB->hidlib.size_x, PCB->hidlib.size_y);
+		fprintf(f, "</g>\n");
+	}
+
 	fprintf(f, "</svg>\n");
 }
 
@@ -419,6 +451,8 @@ static int svg_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const ch
 		svg_header();
 	}
 
+printf("GRP: '%s'\n", PCB->LayerGroups.grp[group].name);
+
 	if (!svg_cam.active) {
 		if (flags & PCB_LYT_INVIS)
 			return 0;
@@ -440,6 +474,11 @@ static int svg_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const ch
 			return 0;
 	}
 
+	if (photo_mode && (group < 0)) {
+		drawing_hole = PCB_LAYER_IS_DRILL(flags, purpi);
+		return 1; /* photo mode drill: do not create a separate group */
+	}
+
 	while(group_open) {
 		group_close();
 		group_open--;
@@ -476,7 +515,6 @@ static int svg_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const ch
 	}
 
 	drawing_hole = PCB_LAYER_IS_DRILL(flags, purpi);
-
 	return 1;
 }
 
@@ -636,7 +674,7 @@ static void svg_draw_rect(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_c
 static void draw_fill_rect(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t w, rnd_coord_t h)
 {
 	const char *clip_color = svg_clip_color(gc);
-	if ((photo_mode) && (clip_color == NULL)) {
+	if (photo_mode) {
 		rnd_coord_t photo_offs = photo_palette[photo_color].offs;
 		if (photo_offs != 0) {
 			indent(&sdark);
@@ -654,10 +692,10 @@ static void draw_fill_rect(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_
 		indent(&snormal);
 		rnd_append_printf(&snormal, "<rect x=\"%mm\" y=\"%mm\" width=\"%mm\" height=\"%mm\" fill=\"%s\" stroke=\"none\"/>\n",
 			x1, y1, w, h, svg_color(gc));
-		if (clip_color != NULL)
-			rnd_append_printf(&sclip, "<rect x=\"%mm\" y=\"%mm\" width=\"%mm\" height=\"%mm\" fill=\"%s\" stroke=\"none\"/>\n",
-				x1, y1, w, h, clip_color);
 	}
+	if (clip_color != NULL)
+		rnd_append_printf(&sclip, "<rect x=\"%mm\" y=\"%mm\" width=\"%mm\" height=\"%mm\" fill=\"%s\" stroke=\"none\"/>\n",
+			x1, y1, w, h, clip_color);
 }
 
 static void svg_fill_rect(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2)
@@ -671,7 +709,7 @@ static void svg_fill_rect(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_c
 static void pcb_line_draw(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2)
 {
 	const char *clip_color = svg_clip_color(gc);
-	if ((photo_mode) && (clip_color == NULL)) {
+	if (photo_mode) {
 		rnd_coord_t photo_offs = photo_palette[photo_color].offs;
 		if (photo_offs != 0) {
 			indent(&sbright);
@@ -689,10 +727,10 @@ static void pcb_line_draw(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_c
 		indent(&snormal);
 		rnd_append_printf(&snormal, "<line x1=\"%mm\" y1=\"%mm\" x2=\"%mm\" y2=\"%mm\" stroke-width=\"%mm\" stroke=\"%s\" stroke-linecap=\"%s\"/>\n",
 			x1, y1, x2, y2, gc->width, svg_color(gc), CAPS(gc->cap));
-		if (clip_color != NULL) {
-			rnd_append_printf(&sclip, "<line x1=\"%mm\" y1=\"%mm\" x2=\"%mm\" y2=\"%mm\" stroke-width=\"%mm\" stroke=\"%s\" stroke-linecap=\"%s\"/>\n",
-				x1, y1, x2, y2, gc->width, clip_color, CAPS(gc->cap));
-		}
+	}
+	if (clip_color != NULL) {
+		rnd_append_printf(&sclip, "<line x1=\"%mm\" y1=\"%mm\" x2=\"%mm\" y2=\"%mm\" stroke-width=\"%mm\" stroke=\"%s\" stroke-linecap=\"%s\"/>\n",
+			x1, y1, x2, y2, gc->width, clip_color, CAPS(gc->cap));
 	}
 }
 
@@ -706,7 +744,7 @@ static void svg_draw_line(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_c
 static void pcb_arc_draw(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t r, rnd_coord_t x2, rnd_coord_t y2, rnd_coord_t stroke, int large, int sweep)
 {
 	const char *clip_color = svg_clip_color(gc);
-	if ((photo_mode) && (clip_color == NULL)) {
+	if (photo_mode) {
 		rnd_coord_t photo_offs = photo_palette[photo_color].offs;
 		if (photo_offs != 0) {
 			indent(&sbright);
@@ -724,10 +762,10 @@ static void pcb_arc_draw(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, rnd_co
 		indent(&snormal);
 		rnd_append_printf(&snormal, "<path d=\"M %.8mm %.8mm A %mm %mm 0 %d %d %mm %mm\" stroke-width=\"%mm\" stroke=\"%s\" stroke-linecap=\"%s\" fill=\"none\"/>\n",
 			x1, y1, r, r, large, sweep, x2, y2, gc->width, svg_color(gc), CAPS(gc->cap));
-		if (clip_color != NULL)
-			rnd_append_printf(&sclip, "<path d=\"M %.8mm %.8mm A %mm %mm 0 %d %d %mm %mm\" stroke-width=\"%mm\" stroke=\"%s\" stroke-linecap=\"%s\" fill=\"none\"/>\n",
-				x1, y1, r, r, large, sweep, x2, y2, gc->width, clip_color, CAPS(gc->cap));
 	}
+	if (clip_color != NULL)
+		rnd_append_printf(&sclip, "<path d=\"M %.8mm %.8mm A %mm %mm 0 %d %d %mm %mm\" stroke-width=\"%mm\" stroke=\"%s\" stroke-linecap=\"%s\" fill=\"none\"/>\n",
+			x1, y1, r, r, large, sweep, x2, y2, gc->width, clip_color, CAPS(gc->cap));
 }
 
 static void svg_draw_arc(rnd_hid_gc_t gc, rnd_coord_t cx, rnd_coord_t cy, rnd_coord_t width, rnd_coord_t height, rnd_angle_t start_angle, rnd_angle_t delta_angle)
@@ -795,7 +833,7 @@ static void draw_fill_circle(rnd_hid_gc_t gc, rnd_coord_t cx, rnd_coord_t cy, rn
 
 	svg_drawn_objs++;
 
-	if ((photo_mode) && (clip_color == NULL)) {
+	if (photo_mode) {
 		if (!drawing_hole) {
 			rnd_coord_t photo_offs = photo_palette[photo_color].offs;
 			if ((!gc->drill) && (photo_offs != 0)) {
@@ -821,10 +859,10 @@ static void draw_fill_circle(rnd_hid_gc_t gc, rnd_coord_t cx, rnd_coord_t cy, rn
 		indent(&snormal);
 		rnd_append_printf(&snormal, "<circle cx=\"%mm\" cy=\"%mm\" r=\"%mm\" stroke-width=\"%mm\" fill=\"%s\" stroke=\"none\"/>\n",
 			cx, cy, r, stroke, svg_color(gc));
-		if (clip_color != NULL)
-			rnd_append_printf(&sclip, "<circle cx=\"%mm\" cy=\"%mm\" r=\"%mm\" stroke-width=\"%mm\" fill=\"%s\" stroke=\"none\"/>\n",
-				cx, cy, r, stroke, clip_color);
 	}
+	if (clip_color != NULL)
+		rnd_append_printf(&sclip, "<circle cx=\"%mm\" cy=\"%mm\" r=\"%mm\" stroke-width=\"%mm\" fill=\"%s\" stroke=\"none\"/>\n",
+			cx, cy, r, stroke, clip_color);
 }
 
 static void svg_fill_circle(rnd_hid_gc_t gc, rnd_coord_t cx, rnd_coord_t cy, rnd_coord_t radius)
@@ -842,9 +880,9 @@ static void draw_poly(gds_t *s, rnd_hid_gc_t gc, int n_coords, rnd_coord_t * x,
 	indent(s);
 	gds_append_str(s, "<polygon points=\"");
 	for (i = 0; i < n_coords; i++) {
-		rnd_coord_t px = x[i], py = y[i];
+		rnd_coord_t px = x[i] + dx, py = y[i] + dy;
 		TRX(px); TRY(py);
-		rnd_append_printf(s, "%mm,%mm ", px+dx, py+dy);
+		rnd_append_printf(s, "%mm,%mm ", px, py);
 	}
 	rnd_append_printf(s, "\" stroke-width=\"%.3f\" stroke=\"%s\" fill=\"%s\"/>\n", poly_bloat, clr, clr);
 }
@@ -853,19 +891,21 @@ static void svg_fill_polygon_offs(rnd_hid_gc_t gc, int n_coords, rnd_coord_t *x,
 {
 	const char *clip_color = svg_clip_color(gc);
 	svg_drawn_objs++;
-	if ((photo_mode) && (clip_color == NULL)) {
-		rnd_coord_t photo_offs = photo_palette[photo_color].offs;
-		if (photo_offs != 0) {
-			draw_poly(&sbright, gc, n_coords, x, y, dx-photo_offs, dy-photo_offs, photo_palette[photo_color].bright);
-			draw_poly(&sdark, gc, n_coords, x, y, dx+photo_offs, dy+photo_offs, photo_palette[photo_color].dark);
+	if (photo_mode) {
+		rnd_coord_t photo_offs_x = photo_palette[photo_color].offs, photo_offs_y = photo_palette[photo_color].offs;
+		if (photo_offs_x != 0) {
+			if (flip)
+				photo_offs_y = -photo_offs_y;
+			draw_poly(&sbright, gc, n_coords, x, y, dx-photo_offs_x, dy-photo_offs_y, photo_palette[photo_color].bright);
+			draw_poly(&sdark, gc, n_coords, x, y, dx+photo_offs_x, dy+photo_offs_y, photo_palette[photo_color].dark);
 		}
 		draw_poly(&snormal, gc, n_coords, x, y, dx, dy, photo_palette[photo_color].normal);
 	}
-	else {
+	else
 		draw_poly(&snormal, gc, n_coords, x, y, dx, dy, svg_color(gc));
-		if (clip_color != NULL)
-			draw_poly(&sclip, gc, n_coords, x, y, dx, dy, clip_color);
-	}
+
+	if (clip_color != NULL)
+		draw_poly(&sclip, gc, n_coords, x, y, dx, dy, clip_color);
 }
 
 static void svg_fill_polygon(rnd_hid_gc_t gc, int n_coords, rnd_coord_t *x, rnd_coord_t *y)
