@@ -38,7 +38,7 @@ static const char *export_vfs_fuse_cookie = "export_vfs_fuse HID";
 static int pcb_fuse_changed;
 static char fuse_cwd[RND_PATH_MAX];
 
-static rnd_export_opt_t *export_vfs_fuse_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *export_vfs_fuse_get_export_options(rnd_hid_t *hid, int *n)
 {
 	return 0;
 }
@@ -385,5 +385,6 @@ int pplg_init_export_vfs_fuse(void)
 	export_vfs_fuse_hid.usage = export_vfs_fuse_usage;
 
 	rnd_hid_register_hid(&export_vfs_fuse_hid);
+
 	return 0;
 }
