@@ -18,6 +18,7 @@
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/plugins.h>
 #include <librnd/core/compat_misc.h>
+#include <librnd/core/rotate.h>
 #include "obj_pstk_inlines.h"
 #include "obj_subc_op.h"
 #include "layer.h"
@@ -73,10 +74,13 @@ Unit of XY dimensions. Defaults to mil.
 	{"format", "file format (template)",
 	 RND_HATT_ENUM, 0, 0, {0, 0, 0}, NULL},
 #define HA_format 2
+	{"vendor", "vendor specific ID used for xy::VENDOR::rotate and xy::VENDOR::translate",
+	 RND_HATT_STRING, 0, 0, {0, 0, 0}, NULL},
+#define HA_vendor 3
 
 	{"cam", "CAM instruction",
 	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
-#define HA_cam 3
+#define HA_cam 4
 
 };
 
@@ -167,50 +171,63 @@ typedef struct {
 	char utcTime[64];
 	char *name, *descr, *value;
 	const char *pad_netname;
-	rnd_coord_t x, y;
-	double theta, xray_theta;
+	rnd_coord_t x, y, bottom_x, bottom_y;
+	rnd_coord_t tx, ty;   /* translate x and y (xy::translate attr) */
+	double theta;
 	pcb_subc_t *subc;
-	rnd_coord_t pad_cx, pad_cy;
+	rnd_coord_t pad_cx, pad_cy, bottom_pad_cx, bottom_pad_cy;
 	rnd_coord_t pad_w, pad_h;
 	rnd_coord_t prpad_cx, prpad_cy;
 	rnd_coord_t prpad_w, prpad_h;
 	rnd_cardinal_t count;
-	rnd_coord_t ox, oy;
+	rnd_coord_t ox, oy, bottom_ox, bottom_oy;
 	int origin_score;
-	char *origin_tmp;
 	rnd_bool front;
+	gds_t tmp;
 } subst_ctx_t;
 
 /* Find the pick and place 0;0 mark, if there is any */
-static void find_origin(subst_ctx_t *ctx, const char *format_name)
+static void find_origin_(const char *format_name, const char *prefix, rnd_coord_t *ox, rnd_coord_t *oy)
 {
-	char tmp[128];
+	char tmp[128], tmp2[128];
 	pcb_data_it_t it;
 	pcb_any_obj_t *obj;
+	int origin_score = 0;
 
-	rnd_snprintf(tmp, sizeof(tmp), "pnp-origin-%s", format_name);
-
-	ctx->origin_score = 0;
-	ctx->ox = ctx->oy = 0;
-	ctx->origin_tmp = tmp;
+	rnd_snprintf(tmp, sizeof(tmp), "%spnp-origin-%s", prefix, format_name);
+	rnd_snprintf(tmp2, sizeof(tmp), "%spnp-origin", prefix);
 
 	for(obj = pcb_data_first(&it, PCB->Data, PCB_OBJ_CLASS_REAL); obj != NULL; obj = pcb_data_next(&it)) {
 		int score;
 
-		if (pcb_attribute_get(&obj->Attributes, ctx->origin_tmp) != NULL)
+		if (pcb_attribute_get(&obj->Attributes, tmp) != NULL)
 			score = 2; /* first look for the format-specific attribute */
-		else if (pcb_attribute_get(&obj->Attributes, "pnp-origin") != NULL)
+		else if (pcb_attribute_get(&obj->Attributes, tmp2) != NULL)
 			score = 1; /* then for the generic pnp-specific attribute */
 		else
 			continue;
 
-		if (score > ctx->origin_score) {
-			ctx->origin_score = score;
-			pcb_obj_center(obj, &ctx->ox, &ctx->oy);
+		if (score > origin_score) {
+			origin_score = score;
+			pcb_obj_center(obj, ox, oy);
 		}
 	}
 }
 
+/* Find the pick and place 0;0 mark, if there is any */
+static void find_origin(subst_ctx_t *ctx, const char *format_name)
+{
+	/* default: bottom left of the drawing area */
+	ctx->ox = 0;
+	ctx->oy = PCB->hidlib.size_y;
+	ctx->bottom_ox = PCB->hidlib.size_x;
+	ctx->bottom_oy = PCB->hidlib.size_y;
+
+	find_origin_(format_name, "", &ctx->ox, &ctx->oy);
+	find_origin_(format_name, "bottom-", &ctx->bottom_ox, &ctx->bottom_oy);
+}
+
+
 /* Calculate the bounding box of the subc as the bounding box of all terminals
    ("pads", bot heavy and light) */
 static void calc_pad_bbox_(subst_ctx_t *ctx, rnd_coord_t *pw, rnd_coord_t *ph, rnd_coord_t *pcx, rnd_coord_t *pcy)
@@ -489,21 +506,41 @@ static int subst_cb(void *ctx_, gds_t *s, const char **input)
 			rnd_append_printf(s, "%m+%mN", xy_unit->allow, ctx->x);
 			return 0;
 		}
+		if (strncmp(*input, "side-x%", 7) == 0) {
+			*input += 7;
+			rnd_append_printf(s, "%m+%mN", xy_unit->allow, ctx->front ? ctx->x : ctx->bottom_x);
+			return 0;
+		}
 		if (strncmp(*input, "y%", 2) == 0) {
 			*input += 2;
 			rnd_append_printf(s, "%m+%mN", xy_unit->allow, ctx->y);
 			return 0;
 		}
+		if (strncmp(*input, "side-y%", 7) == 0) {
+			*input += 7;
+			rnd_append_printf(s, "%m+%mN", xy_unit->allow, ctx->front ? ctx->y : ctx->bottom_y);
+			return 0;
+		}
 		if (strncmp(*input, "padcx%", 6) == 0) {
 			*input += 6;
 			rnd_append_printf(s, "%m+%mN", xy_unit->allow, ctx->pad_cx);
 			return 0;
 		}
+		if (strncmp(*input, "side-padcx%", 11) == 0) {
+			*input += 11;
+			rnd_append_printf(s, "%m+%mN", xy_unit->allow, ctx->front ? ctx->pad_cx : ctx->bottom_pad_cx);
+			return 0;
+		}
 		if (strncmp(*input, "padcy%", 6) == 0) {
 			*input += 6;
 			rnd_append_printf(s, "%m+%mN", xy_unit->allow, ctx->pad_cy);
 			return 0;
 		}
+		if (strncmp(*input, "side-padcy%", 11) == 0) {
+			*input += 11;
+			rnd_append_printf(s, "%m+%mN", xy_unit->allow, ctx->front ? ctx->pad_cy : ctx->bottom_pad_cy);
+			return 0;
+		}
 		if (strncmp(*input, "padcx_prerot%", 13) == 0) {
 			*input += 13;
 			rnd_append_printf(s, "%m+%mN", xy_unit->allow, ctx->prpad_cx);
@@ -524,9 +561,29 @@ static int subst_cb(void *ctx_, gds_t *s, const char **input)
 			rnd_append_printf(s, "%g", -ctx->theta);
 			return 0;
 		}
-		if (strncmp(*input, "siderot%", 8) == 0) {
+		if (strncmp(*input, "siderot%", 8) == 0) { /* old, broken, kept for compatibility */
 			*input += 8;
-			rnd_append_printf(s, "%g", ctx->xray_theta);
+			rnd_append_printf(s, "%g", ctx->theta);
+			return 0;
+		}
+		if (strncmp(*input, "side-rot%", 9) == 0) {
+			*input += 9;
+			rnd_append_printf(s, "%g", ctx->front ? ctx->theta : -ctx->theta);
+			return 0;
+		}
+		if (strncmp(*input, "side-rot180%", 12) == 0) {
+			*input += 12;
+			rnd_append_printf(s, "%g", ctx->front ? ctx->theta : -ctx->theta + 180);
+			return 0;
+		}
+		if (strncmp(*input, "side-negrot%", 12) == 0) {
+			*input += 12;
+			rnd_append_printf(s, "%g", ctx->front ? -ctx->theta : ctx->theta);
+			return 0;
+		}
+		if (strncmp(*input, "side-negrot180%", 15) == 0) {
+			*input += 15;
+			rnd_append_printf(s, "%g", (ctx->front ? -ctx->theta : ctx->theta + 180));
 			return 0;
 		}
 		if (strncmp(*input, "270-rot%", 8) == 0) {
@@ -652,16 +709,96 @@ static void fprintf_templ(FILE *f, subst_ctx_t *ctx, const char *templ)
 	}
 }
 
-static void xy_translate(subst_ctx_t *ctx, rnd_coord_t *x, rnd_coord_t *y)
+static void xy_translate(subst_ctx_t *ctx, rnd_coord_t *dstx, rnd_coord_t *dsty, rnd_coord_t *bottom_dstx, rnd_coord_t *bottom_dsty, int atrans)
 {
-		/* translate the xy coords using explicit or implicit origin; implicit origin
-		   is lower left corner (looking from top) of board extents */
-		if (ctx->origin_score > 0) {
-			*y = ctx->oy - *y;
-			*x = *x - ctx->ox;
+	rnd_coord_t x = *dstx, y = *dsty, tx = 0, ty = 0;
+
+	if (atrans) { /* apply attribute translation */
+		tx = ctx->tx;
+		ty = ctx->ty;
+	}
+
+	/* apply attribute translation (affected by the final rotation of the part
+	   because the p&p machine will rotate around this point while the subc was
+	   rotated around it's pcb-rnd-origin) */
+	if (atrans && ((ctx->tx != 0) || (ctx->ty != 0))) {
+		if (ctx->theta != 0) {
+			double tdeg = ctx->front ? -ctx->theta : ctx->theta;
+			double trad = tdeg / RND_RAD_TO_DEG;
+			rnd_rotate(&tx, &ty, 0, 0, cos(trad), sin(trad));
 		}
+		if (!ctx->front)
+			ty = -ty;
+	}
+	x += tx;
+	y += ty;
+
+	/* translate the xy coords using origin */
+	*dstx = x - ctx->ox;
+	*dsty = ctx->oy - y;
+	*bottom_dstx = ctx->bottom_ox - x;
+	*bottom_dsty = ctx->bottom_oy - y;
+}
+
+static const char *xy_xform_get_attr(subst_ctx_t *ctx, pcb_subc_t *subc, const char *key)
+{
+	ctx->tmp.used = 0;
+	gds_append_str(&ctx->tmp, "xy::");
+
+	if ((xy_values[HA_vendor].str != NULL) && (*xy_values[HA_vendor].str != '\0')) {
+		gds_append_str(&ctx->tmp, xy_values[HA_vendor].str);
+		gds_append_str(&ctx->tmp, "::");
+	}
+
+	gds_append_str(&ctx->tmp, key);
+	return pcb_attribute_get(&subc->Attributes, ctx->tmp.array);
+}
+
+static void xy_xform_by_subc_attrs(subst_ctx_t *ctx, pcb_subc_t *subc)
+{
+	const char *sval, *sx, *sy;
+	char *end;
+
+	ctx->tx = ctx->ty = 0;
+
+	sval = xy_xform_get_attr(ctx, subc, "rotate");
+	if (sval != NULL) {
+		double r = strtod(sval, &end);
+		while(isspace(*end)) end++;
+		if (!ctx->front) /* rotation is mirrored on bottom */
+			r = -r;
+		if (*end != '\0')
+			rnd_message(RND_MSG_ERROR, "xy: invalid subc rotate (%s) on subc '%s'\n", sval, ((subc->refdes == NULL) ? "" : subc->refdes));
 		else
-			*y = PCB->hidlib.size_y - *y;
+			ctx->theta += r;
+	}
+
+	sval = xy_xform_get_attr(ctx, subc, "translate");
+	if (sval != NULL) {
+		double x, y;
+		rnd_bool succ;
+
+		sx = sval;
+		sy = strpbrk(sx, " \t,;");
+		if (sy == NULL) {
+			rnd_message(RND_MSG_ERROR, "xy: invalid subc translate (%s) on subc '%s': need both x and y\n", sval, ((subc->refdes == NULL) ? "" : subc->refdes));
+			return;
+		}
+		sy++;
+
+		x = rnd_get_value_ex(sx, NULL, NULL, NULL, "mm", &succ);
+		if (!succ) {
+			rnd_message(RND_MSG_ERROR, "xy: invalid subc translate (%s) on subc '%s': error in X coord\n", sval, ((subc->refdes == NULL) ? "" : subc->refdes));
+			return;
+		}
+		y = rnd_get_value_ex(sy, NULL, NULL, NULL, "mm", &succ);
+		if (!succ) {
+			rnd_message(RND_MSG_ERROR, "xy: invalid subc translate (%s) on subc '%s': error in Y coord\n", sval, ((subc->refdes == NULL) ? "" : subc->refdes));
+			return;
+		}
+		ctx->tx += x;
+		ctx->ty += y;
+	}
 }
 
 typedef struct {
@@ -681,6 +818,7 @@ static int PrintXY(const template_t *templ, const char *format_name)
 	}
 
 	ctx.count = 0;
+	gds_init(&ctx.tmp);
 
 	rnd_print_utc(ctx.utcTime, sizeof(ctx.utcTime), 0);
 
@@ -697,7 +835,7 @@ static int PrintXY(const template_t *templ, const char *format_name)
 		ctx.count++;
 
 		ctx.pad_w = ctx.pad_h = 0;
-		ctx.theta = ctx.xray_theta = 0.0;
+		ctx.theta = 0.0;
 
 		ctx.name = pcb_bom_clean_str((char *) RND_UNKNOWN(pcb_attribute_get(&subc->Attributes, "refdes")));
 		ctx.descr = pcb_bom_clean_str((char *) RND_UNKNOWN(pcb_subc_name(subc, "export_xy::footprint")));
@@ -711,18 +849,20 @@ static int PrintXY(const template_t *templ, const char *format_name)
 		if (pcb_subc_get_rotation(subc, &ctx.theta) != 0) rnd_message(RND_MSG_ERROR, "xy: can't get subc rotation for %s\n", ctx.name);
 		if (pcb_subc_get_side(subc, &bott) != 0) rnd_message(RND_MSG_ERROR, "xy: can't get subc side for %s\n", ctx.name);
 
-		ctx.theta = -ctx.theta;
-		if (ctx.theta == -0)
-			ctx.theta = 0;
-	
-		xy_translate(&ctx, &ctx.x, &ctx.y);
-
 		ctx.subc = subc;
 		ctx.front = !bott;
 
+		xy_xform_by_subc_attrs(&ctx, subc);
+
+		ctx.theta = -ctx.theta;
+		if (ctx.theta == -0)
+			ctx.theta = 0;
+
+		xy_translate(&ctx, &ctx.x, &ctx.y, &ctx.bottom_x, &ctx.bottom_y, 1);
+
 		calc_pad_bbox(&ctx, 0, &ctx.pad_w, &ctx.pad_h, &ctx.pad_cx, &ctx.pad_cy);
 		calc_pad_bbox(&ctx, 1, &ctx.prpad_w, &ctx.prpad_h, &ctx.prpad_cx, &ctx.prpad_cy);
-		xy_translate(&ctx, &ctx.pad_cx, &ctx.pad_cy);
+		xy_translate(&ctx, &ctx.pad_cx, &ctx.pad_cy, &ctx.bottom_pad_cx, &ctx.bottom_pad_cy, 0);
 
 		fprintf_templ(fp, &ctx, templ->subc);
 
@@ -751,6 +891,7 @@ static int PrintXY(const template_t *templ, const char *format_name)
 	fprintf_templ(fp, &ctx, templ->foot);
 
 	fclose(fp);
+	gds_uninit(&ctx.tmp);
 
 	return 0;
 }
@@ -810,7 +951,7 @@ static void xy_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	xy_filename = options[HA_xyfile].str;
 	if (!xy_filename)
-		xy_filename = "pcb-out.xy";
+		xy_filename = "pcb-rnd-out.xy";
 
 	pcb_cam_begin_nolayer(PCB, &cam, NULL, options[HA_cam].str, &xy_filename);
 
