@@ -155,7 +155,7 @@ static void invoke(extedit_method_t *mth, const char *fn, const char *fn_cfg)
 			fread(tmp, 1, sizeof(tmp), fc);
 		}
 	}
-	pclose(fc);
+	rnd_pclose(fc);
 
 	if (rnd_gui != NULL)
 		rnd_hid_progress(0, 0, NULL);
@@ -312,7 +312,7 @@ static fgw_error_t pcb_act_extedit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 					pcb_remove_selected(rnd_true);
 				if (paste) {
 					pcb_undo_save_serial();
-					pcb_buffer_copy_to_layout(PCB, pastex, pastey, rnd_false);
+					pcb_buffer_copy_to_layout(PCB, pastex, pastey, rnd_false, rnd_false);
 					pcb_undo_restore_serial();
 					pcb_remove_object(type, ptr1, ptr2, ptr3);
 					pcb_undo_inc_serial();
