@@ -8,13 +8,11 @@
 
 conf_fp_wget_t conf_fp_wget;
 
-#define FP_WGET_CONF_FN "fp_wget.conf"
-
 int pplg_check_ver_fp_wget(int ver_needed) { return 0; }
 
 void pplg_uninit_fp_wget(void)
 {
-	rnd_conf_unreg_file(FP_WGET_CONF_FN, fp_wget_conf_internal);
+	rnd_conf_unreg_intern(fp_wget_conf_internal);
 	fp_gedasymbols_uninit();
 	fp_edakrill_uninit();
 	rnd_conf_unreg_fields("plugins/fp_wget/");
@@ -28,7 +26,7 @@ int pplg_init_fp_wget(void)
 	rnd_conf_reg_field(conf_fp_wget, field,isarray,type_name,cpath,cname,desc,flags);
 #include "fp_wget_conf_fields.h"
 
-	rnd_conf_reg_file(FP_WGET_CONF_FN, fp_wget_conf_internal);
+	rnd_conf_reg_intern(fp_wget_conf_internal);
 
 	fp_gedasymbols_init();
 	fp_edakrill_init();
