@@ -208,7 +208,7 @@ fgw_error_t pcb_act_LoadCalayFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_MAY_CONVARG(1, FGW_STR, LoadCalayFrom, fname_net = argv[1].val.str);
 
 	if (!fname_net || !*fname_net) {
-		fname_net = rnd_gui->fileselect(rnd_gui,
+		fname_net = rnd_hid_fileselect(rnd_gui,
 			"Load calay netlist file...", "Picks a calay netlist file to load.\n",
 			default_file, NETEXT, NULL, "calay", RND_HID_FSD_READ, NULL);
 		if (fname_net == NULL)
