@@ -158,7 +158,7 @@ fgw_error_t pcb_act_LoadHpglFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_MAY_CONVARG(1, FGW_STR, LoadHpglFrom, fname = argv[1].val.str);
 
 	if (!fname || !*fname) {
-		fname = rnd_gui->fileselect(rnd_gui, "Load HP-GL file...",
+		fname = rnd_hid_fileselect(rnd_gui, "Load HP-GL file...",
 																"Picks a HP-GL plot file to load.\n",
 																default_file, ".hpgl", NULL, "hpgl", RND_HID_FSD_READ, NULL);
 		if (fname == NULL)
