@@ -372,7 +372,7 @@ fgw_error_t pcb_act_LoadIpc356From(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_MAY_CONVARG(1, FGW_STR, LoadIpc356From, fname = argv[1].val.str);
 
 	if ((fname == NULL) || (*fname == '\0')) {
-		fname = rnd_gui->fileselect(rnd_gui, "Load IPC-D-356 netlist...",
+		fname = rnd_hid_fileselect(rnd_gui, "Load IPC-D-356 netlist...",
 			"Pick an IPC-D-356 netlist file.\n",
 			default_file, ".net", NULL, "ipcd356", RND_HID_FSD_READ, NULL);
 		if (fname == NULL) {
