@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2016, 2017, 2018 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2016, 2017, 2018, 2020 Tibor 'Igor2' Palinkas
  *  Copyright (C) 2016, 2017 Erich S. Heinzle
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -209,8 +209,6 @@ static int rdax_text(read_state_t *st, FILE *FP, pcb_subc_t *subc)
 	ltrim(t);
 	rtrim(t); /*need to remove trailing '\r' to avoid rendering oddities */
 
-	/* # TODO - ABOUT HERE, CAN DO ROTATION/DIRECTION CONVERSION */
-
 	ly = autotrax_get_layer(st, subc, autotrax_layer, "text");
 	if (ly == NULL)
 		return 0;
@@ -219,18 +217,10 @@ static int rdax_text(read_state_t *st, FILE *FP, pcb_subc_t *subc)
 	if (lyt & PCB_LYT_BOTTOM) Flags = pcb_flag_make(PCB_FLAG_ONSOLDER);
 	else Flags = pcb_flag_make(0);
 
-TODO("textrot: is there a real rotation angle available?")
+	/* Text rotation is limited to 90*direction by the file format */
 	if (pcb_text_new(ly, pcb_font(st->pcb, 0, 1), X, Y, 90.0*direction, scaling, 0, t, Flags) != 0)
 		return 1;
 	return -1;
-
-TODO("do not use strlen() for this, decide where to move this code")
-/*
-		if (strlen(t) == 0) {
-			rnd_message(RND_MSG_ERROR, "Empty free string not placed on layout, %s:%d\n", st->Filename, st->lineno);
-			return 0;
-		}
-*/
 }
 
 /* autotrax_pcb free_track/component_track */
@@ -542,11 +532,11 @@ static int rdax_pad(read_state_t *st, FILE *FP, pcb_subc_t *subc, int component)
 
 	if (!valid) {
 		rnd_message(RND_MSG_ERROR, "Insufficient pad attribute fields, %s:%d\n", st->Filename, st->lineno);
+		fgetline(line, sizeof(line), FP, st->lineno); /* read the whole construct before exit */
 		return -1;
 	}
 
 /* now find name as string on next line and copy it */
-TODO("can not exit above if we need to read this line")
 	if (fgetline(line, sizeof(line), FP, st->lineno) == NULL) {
 		rnd_message(RND_MSG_ERROR, "Error parsing pad text field line, %s:%d\n", st->Filename, st->lineno);
 		return -1;
@@ -791,8 +781,6 @@ static int autotrax_create_layers(read_state_t *st)
 	if (pcb_layer_list(st->pcb, PCB_LYT_SILK | PCB_LYT_TOP, &id, 1) == 1) {
 		rnd_layergrp_id_t gid;
 		pcb_layergrp_list(st->pcb, PCB_LYT_SILK | PCB_LYT_TOP, &gid, 1);
-		st->protel_to_stackup[11] = pcb_layer_create(st->pcb, gid, "Board", 0); /* != outline, cutouts */
-		pcb_layergrp_list(st->pcb, PCB_LYT_SILK | PCB_LYT_TOP, &gid, 1);
 		st->protel_to_stackup[13] = pcb_layer_create(st->pcb, gid, "Multi", 0);
 	}
 	else {
@@ -818,10 +806,16 @@ static int autotrax_create_layers(read_state_t *st)
 	st->protel_to_stackup[10] = pcb_layer_create(st->pcb, g - st->pcb->LayerGroups.grp, "Power", 0);
 
 	g = pcb_get_grp_new_intern(st->pcb, -1);
-	g->name = rnd_strdup("outline"); /* equivalent to keepout = layer 12 in autotrax */
-	g->ltype = PCB_LYT_BOUNDARY; /* and includes cutouts */
+	g->name = rnd_strdup("board"); /* 11 (board) is the contour */
+	g->ltype = PCB_LYT_BOUNDARY;
 	pcb_layergrp_set_purpose__(g, rnd_strdup("uroute"), 0);
-	st->protel_to_stackup[12] = autotrax_reg_layer(st, "outline", PCB_LYT_BOUNDARY);
+	st->protel_to_stackup[11] = autotrax_reg_layer(st, "outline", PCB_LYT_BOUNDARY);
+
+	g = pcb_get_grp_new_intern(st->pcb, -1);
+	g->name = rnd_strdup("keepout"); /* 12 (keepout) is where cutouts are specified */
+	g->ltype = PCB_LYT_BOUNDARY;
+	pcb_layergrp_set_purpose__(g, rnd_strdup("uroute"), 0);
+	st->protel_to_stackup[12] = autotrax_reg_layer(st, "keepout", PCB_LYT_BOUNDARY);
 
 	pcb_layergrp_inhibit_dec();
 
@@ -1016,7 +1010,7 @@ TODO("load placement status and apply PCB_FLAG_LOCK if needed")
 
 	new_module = pcb_subc_alloc();
 	pcb_subc_create_aux(new_module, module_X, module_Y, 0.0, 0);
-	rnd_attribute_put(&new_module->Attributes, "refdes", "A1");
+	pcb_attribute_put(&new_module->Attributes, "refdes", "A1");
 	pcb_subc_reg(st->pcb->Data, new_module);
 	pcb_subc_bind_globals(st->pcb, new_module);
 
