@@ -4,7 +4,8 @@
  *  pcb-rnd, interactive printed circuit board design
  *
  *  dsn IO plugin - file format read, parser
- *  pcb-rnd Copyright (C) 2018 Tibor 'Igor2' Palinkas
+ *  pcb-rnd Copyright (C) 2018,2021 Tibor 'Igor2' Palinkas
+ *  (Supported by NLnet NGI0 PET Fund in 2021)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -60,6 +61,7 @@ typedef struct {
 	rnd_cardinal_t testpoint;
 	unsigned has_pcb_boundary:1;
 	unsigned has_testpoint:1;
+	unsigned conf_root_replaced:1;
 } dsn_read_t;
 
 static char *STR(gsxl_node_t *node)
@@ -228,11 +230,28 @@ static int dsn_parse_rect(dsn_read_t *ctx, rnd_box_t *dst, gsxl_node_t *src, int
 
 static int dsn_parse_rule(dsn_read_t *ctx, gsxl_node_t *rule)
 {
+	int changed = 0;
+
 	if ((rule == NULL) || (rule->str == NULL))
 		return 0;
-	if (rnd_strcasecmp(rule->str, "width") == 0)
-		rnd_conf_set_design("design/min_wid", "%$mS", COORD(ctx, rule->children));
+
+	if (rnd_strcasecmp(rule->str, "width") == 0) {
+		rnd_conf_set_design("design/drc/min_copper_thickness", "%$mS", COORD(ctx, rule->children));
+		changed = 1;
+	}
+	else if (rnd_strcasecmp(rule->str, "clearance") == 0) {
+		rnd_conf_set_design("design/drc/min_copper_clearance", "%$mS", COORD(ctx, rule->children));
+		changed = 1;
+	}
 	/* the rest of the rules do not have a direct mapping in the current DRC code */
+
+	if (changed && !ctx->conf_root_replaced) {
+		/* we do not have a config subtree; we have to emulate one if we are
+		   setting CFR_DESIGN, else the caller (plug_io) will drop the new conf */
+		ctx->conf_root_replaced = 1;
+		rnd_conf_main_root_replace_cnt[RND_CFR_DESIGN]++;
+	}
+
 	return 0;
 }
 
@@ -367,19 +386,19 @@ do { \
 static int dsn_parse_structure(dsn_read_t *ctx, gsxl_node_t *str)
 {
 	const pcb_dflgmap_t *m;
-	gsxl_node_t *n, *i;
+	gsxl_node_t *n, *i, *r;
 	pcb_layergrp_t *topcop = NULL, *botcop = NULL, *grp;
 	rnd_layergrp_id_t gid;
 	const rnd_unit_t *old_unit;
 	const pcb_dflgmap_t doclayers[] = {
-		{"top_outline",         PCB_LYT_TOP | PCB_LYT_DOC,    "outline", PCB_LYC_AUTO, 0},
-		{"bot_outline",         PCB_LYT_BOTTOM | PCB_LYT_DOC, "outline", PCB_LYC_AUTO, 0},
-		{"top_all_keepout",     PCB_LYT_TOP | PCB_LYT_DOC,    "all_keepout", PCB_LYC_AUTO, 0},
-		{"bot_all_keepout",     PCB_LYT_BOTTOM | PCB_LYT_DOC, "all_keepout", PCB_LYC_AUTO, 0},
-		{"top_copper_keepout",  PCB_LYT_TOP | PCB_LYT_DOC,    "copper_keepout", PCB_LYC_AUTO, 0},
-		{"bot_copper_keepout",  PCB_LYT_BOTTOM | PCB_LYT_DOC, "copper_keepout", PCB_LYC_AUTO, 0},
-		{"top_subc_keepout",    PCB_LYT_TOP | PCB_LYT_DOC,    "subc_keepout", PCB_LYC_AUTO, 0},
-		{"bot_subc_keepout",    PCB_LYT_BOTTOM | PCB_LYT_DOC, "subc_keepout", PCB_LYC_AUTO, 0},
+		{"top_outline",         PCB_LYT_TOP | PCB_LYT_DOC,    "ko@courtyard", PCB_LYC_AUTO, 0},
+		{"bot_outline",         PCB_LYT_BOTTOM | PCB_LYT_DOC, "ko@courtyard", PCB_LYC_AUTO, 0},
+		{"top_all_keepout",     PCB_LYT_TOP | PCB_LYT_DOC,    "ko@top", PCB_LYC_AUTO, 0},
+		{"bot_all_keepout",     PCB_LYT_BOTTOM | PCB_LYT_DOC, "ko@bottom", PCB_LYC_AUTO, 0},
+		{"top_copper_keepout",  PCB_LYT_TOP | PCB_LYT_DOC,    "ko@top-copper", PCB_LYC_AUTO, 0},
+		{"bot_copper_keepout",  PCB_LYT_BOTTOM | PCB_LYT_DOC, "ko@bottom-copper", PCB_LYC_AUTO, 0},
+		{"top_subc_keepout",    PCB_LYT_TOP | PCB_LYT_DOC,    "ko@courtyard", PCB_LYC_AUTO, 0},
+		{"bot_subc_keepout",    PCB_LYT_BOTTOM | PCB_LYT_DOC, "ko@courtyard", PCB_LYC_AUTO, 0},
 		{"top_via_keepout",     PCB_LYT_TOP | PCB_LYT_DOC,    "via_keepout", PCB_LYC_AUTO, 0},
 		{"bot_via_keepout",     PCB_LYT_BOTTOM | PCB_LYT_DOC, "via_keepout", PCB_LYC_AUTO, 0},
 		{NULL, 0}
@@ -478,8 +497,9 @@ static int dsn_parse_structure(dsn_read_t *ctx, gsxl_node_t *str)
 				return -1;
 		}
 		else if (rnd_strcasecmp(n->str, "rule") == 0) {
-			if (dsn_parse_rule(ctx, n->children) != 0)
-				return -1;
+			for(r = n->children; r != NULL; r = r->next)
+				if (dsn_parse_rule(ctx, r) != 0)
+					return -1;
 		}
 	}
 
@@ -845,9 +865,12 @@ static int dsn_parse_img_via(dsn_read_t *ctx, gsxl_node_t *pn, pcb_subc_t *subc)
 		rnd_coord_t crd[2];
 		rnd_cardinal_t pid;
 
-		DSN_LOAD_COORDS_FMT(crd, ncoord, "XY", goto err_coord);
-		pid = pcb_pstk_proto_insert_dup(subc->data, proto, 1, 0);
-		pcb_pstk_new(subc->data, -1, pid, crd[0], crd[1], conf_core.design.clearance/2, pcb_flag_make(PCB_FLAG_CLEARLINE));
+		if (ncoord->str == NULL) continue;
+		if (isdigit(*ncoord->str) || (*ncoord->str == '+') || (*ncoord->str == '-') || (*ncoord->str == '.')) {
+			DSN_LOAD_COORDS_FMT(crd, ncoord, "XY", goto err_coord);
+			pid = pcb_pstk_proto_insert_dup(subc->data, proto, 1, 0);
+			pcb_pstk_new(subc->data, -1, pid, crd[0], crd[1], conf_core.design.clearance/2, pcb_flag_make(PCB_FLAG_CLEARLINE));
+		}
 	}
 
 	return 0;
@@ -1017,19 +1040,19 @@ static int dsn_parse_lib_image(dsn_read_t *ctx, gsxl_node_t *imr)
 				return -1;
 		}
 		else if (rnd_strcasecmp(imr->str, "keepout") == 0) {
-			if (dsn_parse_img_keepout(ctx, imr, "all", subc) != 0)
+			if (dsn_parse_img_keepout(ctx, imr, "all_keepout", subc) != 0)
 				return -1;
 		}
 		else if (rnd_strcasecmp(imr->str, "wire_keepout") == 0) {
-			if (dsn_parse_img_keepout(ctx, imr, "copper", subc) != 0)
+			if (dsn_parse_img_keepout(ctx, imr, "copper_keepout", subc) != 0)
 				return -1;
 		}
 		else if (rnd_strcasecmp(imr->str, "place_keepout") == 0) {
-			if (dsn_parse_img_keepout(ctx, imr, "subc", subc) != 0)
+			if (dsn_parse_img_keepout(ctx, imr, "subc_keepout", subc) != 0)
 				return -1;
 		}
 		else if (rnd_strcasecmp(imr->str, "via_keepout") == 0) {
-			if (dsn_parse_img_keepout(ctx, imr, "via", subc) != 0)
+			if (dsn_parse_img_keepout(ctx, imr, "via_keepout", subc) != 0)
 				return -1;
 		}
 		else if (rnd_strcasecmp(imr->str, "property") == 0) {
@@ -1038,6 +1061,8 @@ static int dsn_parse_lib_image(dsn_read_t *ctx, gsxl_node_t *imr)
 		}
 	}
 
+	pcb_subc_create_aux(subc, 0, 0, 0, 0);
+
 	pcb_attribute_put(&subc->Attributes, "footprint", id);
 	id = pcb_attribute_get(&subc->Attributes, "footprint");
 	htsp_set(&ctx->subcs, id, subc);
@@ -1156,7 +1181,7 @@ static int dsn_parse_wire_poly(dsn_read_t *ctx, gsxl_node_t *wrr, pcb_subc_t *su
 		return -1;
 	}
 
-	if (aper != 0) {
+	if (aper > 10) {
 		double dv;
 		long n;
 		rnd_polo_t *p;
@@ -1340,6 +1365,9 @@ static int dsn_parse_wire_qarc(dsn_read_t *ctx, gsxl_node_t *wrr, pcb_subc_t *su
 		return -1;
 	}
 
+	if (sa < ea)
+		sa += 360;
+
 	pcb_arc_new(ly, crd[4], crd[5], r1, r1, sa, ea-sa, aper, conf_core.design.clearance, pcb_flag_make(PCB_FLAG_CLEARLINE), 0);
 
 	return 0;
@@ -1564,6 +1592,9 @@ static int dsn_parse_place_component(dsn_read_t *ctx, gsxl_node_t *plr, int mirr
 			return -1;
 		}
 
+		if (need_mirror)
+			rot = 180-rot;
+
 		nsc = pcb_subc_dup_at(ctx->pcb, ctx->pcb->Data, subc, crd[0], crd[1], 0, rnd_false);
 		pcb_attribute_put(&nsc->Attributes, "refdes", refdes);
 
@@ -1742,7 +1773,7 @@ static int dsn_parse_pcb(dsn_read_t *ctx, gsxl_node_t *root)
 int io_dsn_test_parse(pcb_plug_io_t *ctx, pcb_plug_iot_t typ, const char *Filename, FILE *f)
 {
 	char line[1024], *s;
-	int phc = 0, in_pcb = 0, lineno = 0;
+	int phc = 0, in_pcb = 0, lineno = 0, hint = 0;
 
 	if (typ != PCB_IOT_PCB)
 		return 0;
@@ -1758,12 +1789,25 @@ int io_dsn_test_parse(pcb_plug_io_t *ctx, pcb_plug_iot_t typ, const char *Filena
 				in_pcb = 1;
 			if ((phc > 0) && (strstr(s, "PCB") != 0))
 				in_pcb = 1;
+
+			/* these are so special that we can assume dsn */
 			if ((phc > 2) && in_pcb && (strstr(s, "space_in_quoted_tokens") != 0))
 				return 1;
 			if ((phc > 2) && in_pcb && (strstr(s, "host_cad") != 0))
 				return 1;
 			if ((phc > 2) && in_pcb && (strstr(s, "host_version") != 0))
 				return 1;
+
+			/* these are only hints */
+			if ((phc > 1) && in_pcb && (strstr(s, "resolution") != 0))
+				hint++;
+			if ((phc > 1) && in_pcb && (strstr(s, "structure") != 0))
+				hint++;
+
+			if (hint >= 2) {
+				/* if we had enough hints, accept it */
+				return 1;
+			}
 		}
 	}
 
@@ -1776,7 +1820,7 @@ static int dsn_parse_file(dsn_read_t *rdctx, const char *fn)
 	int c, blen = -1;
 	gsx_parse_res_t res;
 	FILE *f;
-	char buff[12];
+	char buff[13];
 	long q_offs = -1, offs;
 
 
@@ -1810,6 +1854,7 @@ static int dsn_parse_file(dsn_read_t *rdctx, const char *fn)
 
 	gsxl_init(&rdctx->dom, gsxl_node_t);
 	rdctx->dom.parse.line_comment_char = '#';
+	rdctx->dom.parse.allow_nospace_open = 1;
 	offs = 0;
 	do {
 		c = fgetc(f);
