@@ -73,9 +73,9 @@ int pplg_init_io_eagle(void)
 	io_eagle_xml.fmt_support_prio = io_eagle_fmt;
 	io_eagle_xml.test_parse = io_eagle_test_parse_xml;
 	io_eagle_xml.parse_pcb = io_eagle_read_pcb_xml;
-/*	io_eagle_xml.parse_footprint = NULL;
-	io_eagle_xml.map_footprint = NULL;
-	io_eagle_xml.parse_font = NULL;
+	io_eagle_xml.parse_footprint = io_eagle_parse_footprint_xml;
+	io_eagle_xml.map_footprint = io_eagle_map_footprint_xml;
+/*	io_eagle_xml.parse_font = NULL;
 	io_eagle_xml.write_buffer = io_eagle_write_buffer;
 	io_eagle_xml.write_pcb = io_eagle_write_pcb;*/
 	io_eagle_xml.default_fmt = "eagle";
@@ -84,6 +84,7 @@ int pplg_init_io_eagle(void)
 	io_eagle_xml.default_extension = ".eagle_pcb";
 	io_eagle_xml.fp_extension = ".eagle_mod";
 	io_eagle_xml.mime_type = "application/x-eagle-pcb";
+	io_eagle_xml.multi_footprint = 1;
 
 	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_xml);
 
@@ -92,9 +93,9 @@ int pplg_init_io_eagle(void)
 	io_eagle_bin.fmt_support_prio = io_eagle_fmt;
 	io_eagle_bin.test_parse = io_eagle_test_parse_bin;
 	io_eagle_bin.parse_pcb = io_eagle_read_pcb_bin;
-/*	io_eagle_bin.parse_footprint = NULL;
-	io_eagle_bin.map_footprint = NULL;
-	io_eagle_bin.parse_font = NULL;
+	io_eagle_bin.parse_footprint = io_eagle_parse_footprint_bin;
+	io_eagle_bin.map_footprint = io_eagle_map_footprint_bin;
+/*	io_eagle_bin.parse_font = NULL;
 	io_eagle_bin.write_buffer = io_eagle_write_buffer;
 	io_eagle_bin.write_pcb = io_eagle_write_pcb;*/
 	io_eagle_bin.default_fmt = "eagle";
@@ -103,6 +104,7 @@ int pplg_init_io_eagle(void)
 	io_eagle_bin.default_extension = ".brd";
 	io_eagle_bin.fp_extension = ".???";
 	io_eagle_bin.mime_type = "application/x-eagle-pcb";
+	io_eagle_bin.multi_footprint = 1;
 
 	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_bin);
 
