@@ -87,6 +87,8 @@ typedef struct eagle_library_s {
 typedef struct read_state_s {
 	trparse_t parser;
 	pcb_board_t *pcb;
+	pcb_data_t *fp_data;        /* if pcb==NULL then fp_data points to the subcircuit's data and we are reading a footprint (bound layers) */
+	pcb_data_t *fp_parent_data; /* if pcb==NULL then fp_parent_data the data (usually buffer) where the subc is created */
 
 	htip_t layers;
 	htsp_t libs;
@@ -189,7 +191,7 @@ static int eagle_read_nop(read_state_t *st, trnode_t *subtree, void *obj, int ty
 
 int io_eagle_test_parse_xml(pcb_plug_io_t *ctx, pcb_plug_iot_t typ, const char *Filename, FILE *f)
 {
-	char line[1024];
+	char *s, line[1024];
 	int found = 0, lineno = 0;
 
 	/* look for <!DOCTYPE.*eagle.dtd in the first 32 lines, not assuming it is in a single line */
@@ -198,6 +200,12 @@ int io_eagle_test_parse_xml(pcb_plug_io_t *ctx, pcb_plug_iot_t typ, const char *
 			found = 1;
 		if ((found == 1) && (strstr(line, "eagle.dtd")))
 			return 1;
+		if ((s = strstr(line, "<eagle")) != NULL) { /* in footprints doctype and the dtd are often omitted */
+			s += 6;
+			while(isspace(*s)) s++;
+			if (strncmp(s, "version=", 8) == 0)
+				return 1;
+		}
 		lineno++;
 		if (lineno > 32)
 			break;
@@ -292,11 +300,26 @@ static rnd_coord_t eagle_get_attrcu(read_state_t *st, trnode_t *nd, const char *
 	return c;
 }
 
-static int eagle_read_layers(read_state_t *st, trnode_t *subtree, void *obj, int type)
+
+#include "layertab.c"
+
+static pcb_layer_t *eagle_layer_get(read_state_t *st, eagle_layerid_t id, eagle_loc_t loc, void *obj);
+
+	/* create layers that are always required */
+static void eagle_setup_layers_auto(read_state_t *st)
+{
+	const int *elid;
+
+	for(elid = eagle_layer_always; *elid != 0; elid++)
+		eagle_layer_get(st, *elid, ON_BOARD, NULL);
+}
+
+static int eagle_read_layers_(read_state_t *st, pcb_data_t *data, trnode_t *subtree, void *obj, int type)
 {
 	trnode_t *n;
 
-	pcb_layergrp_inhibit_inc();
+	if (data == NULL)
+		pcb_layergrp_inhibit_inc();
 
 	for(n = CHILDREN(subtree); n != NULL; n = NEXT(n)) {
 		if (STRCMP(NODENAME(n), "layer") == 0) {
@@ -344,33 +367,59 @@ static int eagle_read_layers(read_state_t *st, trnode_t *subtree, void *obj, int
 					typ = PCB_LYT_SILK | PCB_LYT_BOTTOM;
 					break;
 				case 20: /*199:   20 is dimension, 199 is contour */
-					grp = pcb_get_grp_new_intern(st->pcb, -1);
-					ly->lid = pcb_layer_create(st->pcb, grp - st->pcb->LayerGroups.grp, ly->name, 0);
-					pcb_layergrp_fix_turn_to_outline(grp);
+					if (data == NULL) { /* pcb context: new layer */
+						grp = pcb_get_grp_new_intern(st->pcb, -1);
+						ly->lid = pcb_layer_create(st->pcb, grp - st->pcb->LayerGroups.grp, ly->name, 0);
+						pcb_layergrp_fix_turn_to_outline(grp);
+					}
+					else {
+						pcb_layer_t *l = pcb_layer_new_bound(data, PCB_LYT_BOUNDARY, ly->name, "uroute");
+						ly->lid = l - data->Layer;
+					}
 					break;
 
 				default:
 					if ((id > 1) && (id < 16)) {
-						/* new internal layer */
-						grp = pcb_get_grp_new_intern(st->pcb, -1);
-						ly->lid = pcb_layer_create(st->pcb, grp - st->pcb->LayerGroups.grp, ly->name, 0);
+						if (data == NULL) { /* pcb context: new layer */
+							/* new internal layer */
+							grp = pcb_get_grp_new_intern(st->pcb, -1);
+							ly->lid = pcb_layer_create(st->pcb, grp - st->pcb->LayerGroups.grp, ly->name, 0);
+						}
+						else
+							typ = PCB_LYT_COPPER & PCB_LYT_INTERN;
 					}
 			}
 			if (typ != 0) {
-				if (reuse)
-					pcb_layer_list(st->pcb, typ, &ly->lid, 1);
-				if ((ly->lid < 0) && (pcb_layergrp_list(st->pcb, typ, &gid, 1) > 0))
-					ly->lid = pcb_layer_create(st->pcb, gid, ly->name, 0);
+				if (data == NULL) { /* pcb context: maybe new layer */
+					if (reuse)
+						pcb_layer_list(st->pcb, typ, &ly->lid, 1);
+					if ((ly->lid < 0) && (pcb_layergrp_list(st->pcb, typ, &gid, 1) > 0))
+						ly->lid = pcb_layer_create(st->pcb, gid, ly->name, 0);
+				}
+				else {
+					pcb_layer_t *l = pcb_layer_new_bound(data, typ, ly->name, NULL);
+					ly->lid = l - data->Layer;
+				}
 			}
 		}
 	}
-	pcb_layer_group_setup_silks(st->pcb);
-	pcb_layer_auto_fixup(st->pcb);
-	pcb_layergrp_inhibit_dec();
+
+	if (data == NULL)
+		pcb_layer_group_setup_silks(st->pcb);
+
+	eagle_setup_layers_auto(st);
+
+	if (data == NULL) {
+		pcb_layer_auto_fixup(st->pcb);
+		pcb_layergrp_inhibit_dec();
+	}
 	return 0;
 }
 
-#include "layertab.c"
+static int eagle_read_layers(read_state_t *st, trnode_t *subtree, void *obj, int type)
+{
+	return eagle_read_layers_(st, NULL, subtree, obj, type);
+}
 
 static pcb_layer_t *eagle_layer_get(read_state_t *st, eagle_layerid_t id, eagle_loc_t loc, void *obj)
 {
@@ -392,20 +441,38 @@ static pcb_layer_t *eagle_layer_get(read_state_t *st, eagle_layerid_t id, eagle_
 				/* create docu on the first reference */
 			pcb_layer_type_t typ = t->lyt;
 			rnd_layergrp_id_t gid;
+
+			if (ly == NULL) {
+				ly = calloc(sizeof(eagle_layer_t), 1);
+				htip_set(&st->layers, id, ly);
+			}
+
 			ly->name    = t->name;
 			ly->color   = t->color;
 			ly->fill    = 1;
 			ly->visible = 0;
 			ly->active  = 1;
-			if (pcb_layergrp_listp(st->pcb, typ, &gid, 1, -1, t->purp) != 1) {
-				pcb_layergrp_t *grp = pcb_get_grp_new_misc(st->pcb);
-				grp->name = rnd_strdup(ly->name);
-				grp->ltype = typ;
-				if (t->purp != NULL)
-					pcb_layergrp_set_purpose(grp, t->purp, 0);
-				gid = grp - st->pcb->LayerGroups.grp;
+			if (st->pcb != NULL) {
+				if (pcb_layergrp_listp(st->pcb, typ, &gid, 1, -1, t->purp) != 1) {
+					pcb_layergrp_t *grp = pcb_get_grp_new_misc(st->pcb);
+					grp->name = rnd_strdup(ly->name);
+					grp->ltype = typ;
+					if (t->purp != NULL)
+						pcb_layergrp_set_purpose(grp, t->purp, 0);
+					gid = grp - st->pcb->LayerGroups.grp;
+				}
+				ly->lid = pcb_layer_create(st->pcb, gid, ly->name, 0);
+				if (ly->lid >= 0) {
+					pcb_layer_t *lay = pcb_get_layer(st->pcb->Data, ly->lid);
+					lay->comb = t->comb;
+				}
+			}
+			else {
+				pcb_data_t *data = (loc == IN_SUBC) ? subc->data : st->fp_parent_data;
+				pcb_layer_t *l = pcb_layer_new_bound(data, typ, ly->name, t->purp);
+				l->comb = t->comb;
+				ly->lid = l - data->Layer;
 			}
-			ly->lid = pcb_layer_create(st->pcb, gid, ly->name, 0);
 		}
 		else
 			return NULL; /* not found and not supported */
@@ -413,7 +480,9 @@ static pcb_layer_t *eagle_layer_get(read_state_t *st, eagle_layerid_t id, eagle_
 
 	switch(loc) {
 		case ON_BOARD:
-			return &st->pcb->Data->Layer[ly->lid];
+			if (st->pcb != NULL)
+				return &st->pcb->Data->Layer[ly->lid];
+			return &st->fp_data->Layer[ly->lid];
 		case IN_SUBC:
 			/* check if the layer already exists (by name) */
 			lid = pcb_layer_by_name(subc->data, ly->name);
@@ -426,9 +495,14 @@ static pcb_layer_t *eagle_layer_get(read_state_t *st, eagle_layerid_t id, eagle_
 				comb = 0;
 				return pcb_subc_get_layer(subc, lyt, comb, 1, ly->name, rnd_true);
 			}
-			lyt = pcb_layer_flags(st->pcb, ly->lid);
-			comb = 0;
-			return pcb_subc_get_layer(subc, lyt, comb, 1, ly->name, rnd_true);
+			if (st->pcb != NULL) {
+				lyt = pcb_layer_flags(st->pcb, ly->lid);
+				comb = 0;
+				return pcb_subc_get_layer(subc, lyt, comb, 1, ly->name, rnd_true);
+			}
+			if ((ly->lid < 0) || (ly->lid >= subc->data->LayerN))
+				return NULL;
+			return &subc->data->Layer[ly->lid];
 	}
 	return NULL;
 }
@@ -815,7 +889,7 @@ static int eagle_read_wire(read_state_t * st, trnode_t * subtree, void *obj, int
 
 	ly = eagle_layer_get(st, ln, loc, obj);
 	if (ly == NULL) {
-		rnd_message(RND_MSG_ERROR, "Failed to allocate wire layer 'ly' to ln:%d in eagle_read_wire()\n");
+		rnd_message(RND_MSG_ERROR, "Failed to allocate wire layer 'ly' to ln:%d in eagle_read_wire()\n", ln);
 		return 0;
 	}
 
@@ -1145,8 +1219,16 @@ static int eagle_read_pkg_txt(read_state_t *st, trnode_t *subtree, void *obj, in
 
 	/* figure if target layer is on top or bottom */
 	ely = htip_get(&st->layers, layer);
-	if (ely != NULL)
-		lyt = pcb_layer_flags(st->pcb, ely->lid);
+	if (ely != NULL) {
+		if (st->pcb == NULL) {
+			if ((ely->lid < 0) || (ely->lid >= st->fp_data->LayerN))
+				lyt = 0;
+			else
+				lyt = st->fp_data->Layer[ely->lid].meta.bound.type;
+		}
+		else
+			lyt = pcb_layer_flags(st->pcb, ely->lid);
+	}
 	else
 		lyt = 0; /* unknown - at least not bottom */
 
@@ -1226,7 +1308,9 @@ TODO("bin: can remove the following if dealt with in post processor for binary t
 	}
 
 	pcb_add_poly_on_layer(ly, poly);
-	pcb_poly_init_clip(st->pcb->Data, ly, poly);
+
+	if (st->pcb != NULL)
+		pcb_poly_init_clip(st->pcb->Data, ly, poly);
 
 	return 0;
 }
@@ -1242,63 +1326,87 @@ static int eagle_read_pkg(read_state_t *st, trnode_t *subtree, pcb_subc_t *subc)
 		{"smd",         eagle_read_smd},
 		{"pad",         eagle_read_pad},
 		{"text",        eagle_read_pkg_txt},
-		{"polygon",     eagle_read_poly}, /* TODO: check this to handle subc */
+		{"polygon",     eagle_read_poly},
 		{"rectangle",   eagle_read_rect},
 		{"@text",       eagle_read_nop},
 		{NULL, NULL}
 	};
 
-	TODO("^^^ can polygon be in footprints?");
+	TODO("^^^ can polygon be in footprints? YES, see USB4056-03-A.lbr; verify eagle_read_poly to handle it");
 
 	return eagle_foreach_dispatch(st, CHILDREN(subtree), disp, subc, IN_SUBC);
 }
 
+static int eagle_read_package(read_state_t *st, trnode_t *n)
+{
+	pcb_subc_t *subc;
+
+	subc = pcb_subc_alloc();
+	if (st->pcb == NULL)
+		st->fp_data = subc->data;
+
+	pcb_attribute_put(&subc->Attributes, "refdes", "K1");
+
+	if (st->pcb != NULL) {
+		/* subc part of a board */
+		pcb_subc_reg(st->pcb->Data, subc);
+		pcb_subc_bind_globals(st->pcb, subc);
+	}
+	else {
+		rnd_layer_id_t lid;
+
+		/* subc being loaded from a footprint file: create all parent layers with matching IDs */
+		pcb_subc_reg(st->fp_parent_data, subc);
+		for(lid = 0; lid < st->fp_parent_data->LayerN; lid++)
+			pcb_subc_alloc_layer_like(subc, &st->fp_parent_data->Layer[lid]);
+	}
+
+	eagle_read_pkg(st, n, subc);
+	if (pcb_data_is_empty(subc->data)) {
+		pcb_subc_free(subc);
+		rnd_message(RND_MSG_WARNING, "Ignoring empty package in library\n");
+		return 0;
+	}
+
+	pcb_attribute_put(&subc->Attributes, "refdes", eagle_get_attrs(st, n, "name", NULL));
+	pcb_attribute_put(&subc->Attributes, "value", eagle_get_attrs(st, n, "value", NULL));
+	pcb_attribute_put(&subc->Attributes, "footprint", eagle_get_attrs(st, n, "package", NULL));
+
+	pcb_subc_bbox(subc);
+TODO("subc: revise this: are we loading an instance here? do we need to place it? do not even bump if not!")
+	if (st->pcb != NULL) {
+		if (st->pcb->Data->subc_tree == NULL)
+			st->pcb->Data->subc_tree = rnd_r_create_tree();
+		rnd_r_insert_entry(st->pcb->Data->subc_tree, (rnd_box_t *)subc);
+		pcb_subc_rebind(st->pcb, subc);
+	}
+
+TODO("revise rotation and flip")
+#if 0
+	if ((moduleRotation == 90) || (moduleRotation == 180) || (moduleRotation == 270)) {
+		/* lossles module rotation for round steps */
+		moduleRotation = moduleRotation / 90;
+		pcb_subc_rotate90(subc, moduleX, moduleY, moduleRotation);
+	}
+	else if (moduleRotation != 0) {
+		double rot = moduleRotation;
+		pcb_subc_rotate(subc, moduleX, moduleY, cos(rot/RND_RAD_TO_DEG), sin(rot/RND_RAD_TO_DEG), rot);
+	}
+#endif
+
+	if (st->pcb != NULL)
+		size_bump(st, subc->BoundingBox.X2, subc->BoundingBox.Y2);
+	return 0;
+}
+
 static int eagle_read_library_file_pkgs(read_state_t *st, trnode_t *subtree, void *obj, int type)
 {
 	trnode_t *n;
 
 	for(n = CHILDREN(subtree); n != NULL; n = NEXT(n)) {
-		rnd_trace("looking at child %s of packages node\n", NODENAME(n)); 
-		if (STRCMP(NODENAME(n), "package") == 0) {
-			pcb_subc_t *subc;
-
-			subc = pcb_subc_alloc();
-			pcb_attribute_put(&subc->Attributes, "refdes", "K1");
-			pcb_subc_reg(st->pcb->Data, subc);
-			pcb_subc_bind_globals(st->pcb, subc);
-			eagle_read_pkg(st, n, subc);
-			if (pcb_data_is_empty(subc->data)) {
-				pcb_subc_free(subc);
-				rnd_message(RND_MSG_WARNING, "Ignoring empty package in library\n");
-				continue;
-			}
-
-			pcb_attribute_put(&subc->Attributes, "refdes", eagle_get_attrs(st, n, "name", NULL));
-			pcb_attribute_put(&subc->Attributes, "value", eagle_get_attrs(st, n, "value", NULL));
-			pcb_attribute_put(&subc->Attributes, "footprint", eagle_get_attrs(st, n, "package", NULL));
-
-			pcb_subc_bbox(subc);
-TODO("subc: revise this: are we loading an instance here? do we need to place it? do not even bump if not!")
-			if (st->pcb->Data->subc_tree == NULL)
-				st->pcb->Data->subc_tree = rnd_r_create_tree();
-			rnd_r_insert_entry(st->pcb->Data->subc_tree, (rnd_box_t *)subc);
-			pcb_subc_rebind(st->pcb, subc);
-
-TODO("revise rotation and flip")
-#if 0
-			if ((moduleRotation == 90) || (moduleRotation == 180) || (moduleRotation == 270)) {
-				/* lossles module rotation for round steps */
-				moduleRotation = moduleRotation / 90;
-				pcb_subc_rotate90(subc, moduleX, moduleY, moduleRotation);
-			}
-			else if (moduleRotation != 0) {
-				double rot = moduleRotation;
-				pcb_subc_rotate(subc, moduleX, moduleY, cos(rot/RND_RAD_TO_DEG), sin(rot/RND_RAD_TO_DEG), rot);
-			}
-#endif
-
-			size_bump(st, subc->BoundingBox.X2, subc->BoundingBox.Y2);
-		}
+		rnd_trace("looking at child %s of packages node\n", NODENAME(n));
+		if (STRCMP(NODENAME(n), "package") == 0) 
+			eagle_read_package(st, n);
 	}
 	return 0;
 }
@@ -1739,7 +1847,8 @@ static void st_init(read_state_t *st)
 {
 	htip_init(&st->layers, longhash, longkeyeq);
 	htsp_init(&st->libs, strhash, strkeyeq);
-	pcb_layer_group_setup_default(st->pcb);
+	if (st->pcb != NULL)
+		pcb_layer_group_setup_default(st->pcb);
 }
 
 static void st_uninit(read_state_t *st)
@@ -1747,7 +1856,8 @@ static void st_uninit(read_state_t *st)
 	htip_entry_t *ei;
 	htsp_entry_t *es;
 
-	pcb_layergrp_fix_old_outline(st->pcb);
+	if (st->pcb != NULL)
+		pcb_layergrp_fix_old_outline(st->pcb);
 
 	for (ei = htip_first(&st->layers); ei; ei = htip_next(&st->layers, ei))
 		free(ei->value);
@@ -1802,7 +1912,6 @@ static int post_process_polyholes(read_state_t *st)
 	return 0;
 }
 
-
 int io_eagle_read_pcb_xml(pcb_plug_io_t *ctx, pcb_board_t *pcb, const char *Filename, rnd_conf_role_t settings_dest)
 {
 	int pp_res, res, old_leni;
@@ -1922,3 +2031,123 @@ int io_eagle_read_pcb_bin(pcb_plug_io_t *ctx, pcb_board_t *pcb, const char *File
 	return pp_res;
 }
 
+
+
+static pcb_plug_fp_map_t *io_eagle_map_footprint_any(read_state_t *st, pcb_plug_io_t *ctx, FILE *f, const char *fn, pcb_plug_fp_map_t *head, int need_tags)
+{
+	trnode_t *n, *npkgs;
+	pcb_plug_fp_map_t *res = NULL, *tail = head;
+
+	/* have not read design rules section yet but need this for rectangle parsing */
+	st->ms_width = RND_MIL_TO_COORD(10); /* default minimum feature width */
+
+	if (st->parser.calls->load(&st->parser, fn) != 0)
+		return NULL;
+
+	npkgs = eagle_trpath(st, st->parser.root, "drawing", "library", "packages", NULL);
+	if (npkgs != NULL) {
+		for(n = CHILDREN(npkgs); n != NULL; n = NEXT(n)) {
+			if (strcmp(NODENAME(n), "package") == 0) {
+				const char *name = GET_PROP(n, "name");
+				if (name != NULL) {
+					res = head;
+					pcb_io_fp_map_append(&tail, head, fn, name);
+				}
+			}
+		}
+	}
+
+
+	st_uninit(st);
+	return res;
+}
+
+pcb_plug_fp_map_t *io_eagle_map_footprint_xml(pcb_plug_io_t *ctx, FILE *f, const char *fn, pcb_plug_fp_map_t *head, int need_tags)
+{
+	read_state_t st_tmp = {0}, *st = &st_tmp;
+
+	if (!io_eagle_test_parse_xml(ctx, PCB_IOT_FOOTPRINT, fn, f))
+		return NULL;
+
+	rewind(f);
+
+	st->parser.calls = &trparse_xml_calls;
+	return io_eagle_map_footprint_any(st, ctx, f, fn, head, need_tags);
+}
+
+pcb_plug_fp_map_t *io_eagle_map_footprint_bin(pcb_plug_io_t *ctx, FILE *f, const char *fn, pcb_plug_fp_map_t *head, int need_tags)
+{
+	read_state_t st_tmp = {0}, *st = &st_tmp;
+
+	if (!io_eagle_test_parse_bin(ctx, PCB_IOT_FOOTPRINT, fn, f))
+		return NULL;
+
+	rewind(f);
+
+	st->parser.calls = &trparse_bin_calls;
+	return io_eagle_map_footprint_any(st, ctx, f, fn, head, need_tags);
+}
+
+
+static int io_eagle_parse_footprint_any(read_state_t *st, pcb_plug_io_t *ctx, pcb_data_t *data, const char *fn, const char *subfpname, int tolerant)
+{
+	int res = -1;
+	trnode_t *nlayers, *npkgs, *n, *npkg = NULL;
+
+	/* have not read design rules section yet but need this for rectangle parsing */
+	st->ms_width = RND_MIL_TO_COORD(10); /* default minimum feature width */
+
+	if (st->parser.calls->load(&st->parser, fn) != 0)
+		return -1;
+
+	npkgs = eagle_trpath(st, st->parser.root, "drawing", "library", "packages", NULL);
+	nlayers = eagle_trpath(st, st->parser.root, "drawing", "layers", NULL);
+	if ((npkgs == NULL) || (!tolerant && (nlayers == NULL))) {
+		rnd_message(RND_MSG_ERROR, "io_eagle: missing layers (or packages) subtree\n");
+		goto error;
+	}
+
+	st->fp_parent_data = data;
+	st_init(st);
+
+	if (nlayers != NULL) {
+		if (eagle_read_layers_(st, data, nlayers, NULL, -1) != 0) {
+			rnd_message(RND_MSG_ERROR, "io_eagle: failed to parse or create layers\n");
+			goto error;
+		}
+	}
+
+
+	for(n = CHILDREN(npkgs); n != NULL; n = NEXT(n)) {
+		if (strcmp(NODENAME(n), "package") == 0) {
+			const char *name = GET_PROP(n, "name");
+			if ((subfpname == NULL) || ((name != NULL) && (strcmp(name, subfpname) == 0))) {
+				npkg = n;
+				break;
+			}
+		}
+	}
+
+	if (npkg != NULL)
+		res = eagle_read_package(st, npkg);
+
+	error:;
+	st_uninit(st);
+	return res;
+}
+
+int io_eagle_parse_footprint_xml(pcb_plug_io_t *ctx, pcb_data_t *data, const char *fn, const char *subfpname)
+{
+	read_state_t st_tmp = {0}, *st = &st_tmp;
+	st->parser.calls = &trparse_xml_calls;
+	st->default_unit = "mm";
+	return io_eagle_parse_footprint_any(st, ctx, data, fn, subfpname, 0);
+}
+
+int io_eagle_parse_footprint_bin(pcb_plug_io_t *ctx, pcb_data_t *data, const char *fn, const char *subfpname)
+{
+	read_state_t st_tmp = {0}, *st = &st_tmp;
+	st->parser.calls = &trparse_bin_calls;
+	st->default_unit = "du";
+	return io_eagle_parse_footprint_any(st, ctx, data, fn, subfpname, 1);
+}
