@@ -31,8 +31,8 @@
 #include <string.h>
 #include <assert.h>
 
-#include "error.h"
-#include "safe_fs.h"
+#include <librnd/core/error.h>
+#include <librnd/core/safe_fs.h>
 #include "egb_tree.h"
 #include "eagle_bin.h"
 
@@ -45,7 +45,7 @@ static int eagle_bin_load(trparse_t *pst, const char *fn)
 	FILE *f;
 	int res;
 
-	f = pcb_fopen(NULL, fn, "rb");
+	f = rnd_fopen(NULL, fn, "rb");
 	if (f == NULL)
 		return -1;
 
@@ -72,6 +72,7 @@ static int eagle_bin_load(trparse_t *pst, const char *fn)
 static int eagle_bin_unload(trparse_t *pst)
 {
 	egb_node_free(pst->root);
+	pst->root = NULL;
 	return 0;
 }
 
