@@ -71,6 +71,7 @@ typedef struct {
 	int rdver;
 	unsigned long warned, old_model_warned;
 	rnd_conf_role_t cfg_dest;
+	unsigned conf_root_replaced:1;
 } lht_read_t;
 
 static pcb_data_t DUMMY_BUFFER_SUBC;
@@ -405,8 +406,16 @@ static int parse_coord_conf(lht_read_t *rctx, const char *path, lht_node_t *nd)
 	if (parse_coord(&tmp, nd) != 0)
 		return -1;
 
-	if (rctx->cfg_dest != RND_CFR_invalid)
+	if (rctx->cfg_dest != RND_CFR_invalid) {
+		if ((rctx->cfg_dest == RND_CFR_DESIGN) && !rctx->conf_root_replaced) {
+			/* special case: old versions of the format did not have a config subtree;
+			   we have to emulate one if we are setting CFR_DESIGN, else the
+			   caller (plug_io) will drop the new conf */
+			rctx->conf_root_replaced = 1;
+			rnd_conf_main_root_replace_cnt[RND_CFR_DESIGN]++;
+		}
 		rnd_conf_set(rctx->cfg_dest, path, -1, nd->data.text.value, RND_POL_OVERWRITE);
+	}
 	return 0;
 }
 
@@ -1183,7 +1192,12 @@ static int parse_data_layer(lht_read_t *rctx, pcb_board_t *pcb, pcb_data_t *dt,
 	ly->parent_type = PCB_PARENT_DATA;
 	ly->type = PCB_OBJ_LAYER;
 
-	parse_attributes(&ly->Attributes, lht_dom_hash_get(grp, "attributes"));
+	/* Layer attributes are not loaded if config is not to be loaded; this
+	   happens when the board is loaded withotu side effects (e.g. into buffer)
+	   so that layer keys do not need to be updated. In such situation losing
+	   other layer attributes is not a big deal either, for now. */
+	if (rctx->cfg_dest != RND_CFR_invalid)
+		parse_attributes(&ly->Attributes, lht_dom_hash_get(grp, "attributes"));
 
 	ncmb = lht_dom_hash_get(grp, "combining");
 	if (ncmb != NULL) {
@@ -2756,6 +2770,7 @@ int io_lihata_parse_padstack(pcb_plug_io_t *ctx, pcb_pstk_proto_t *proto, const
 
 	if ((doc->root->type == LHT_HASH) && (strncmp(doc->root->name, "pcb-rnd-padstack-v", 18) == 0)) {
 		lht_node_t *datand = lht_dom_hash_get(doc->root, "ps_proto_v6.0");
+		rctx.rdver = atoi(doc->root->name+18);
 		if (datand == NULL) {
 			iolht_error(doc->root, "Error loading '%s': padstack has no ps_proto_v6\n", filename);
 			res = -1;
