@@ -1678,7 +1678,7 @@ static lht_node_t *build_netlists(pcb_board_t *pcb, pcb_netlist_t *netlists, pcb
 	return nls;
 }
 
-extern lht_doc_t *pcb_conf_main_root[RND_CFR_max_alloc];
+extern lht_doc_t *rnd_conf_main_root[RND_CFR_max_alloc];
 static lht_node_t *build_conf()
 {
 	const char **s, *del_paths[] = { "editor/mode", NULL };
@@ -1687,10 +1687,10 @@ static lht_node_t *build_conf()
 	if (conf_io_lihata.plugins.io_lihata.omit_config)
 		return dummy_node("pcb-rnd-conf-v1");
 
-	if ((pcb_conf_main_root[RND_CFR_DESIGN] == NULL) || (pcb_conf_main_root[RND_CFR_DESIGN]->root == NULL) || (pcb_conf_main_root[RND_CFR_DESIGN]->root->type != LHT_LIST))
+	if ((rnd_conf_main_root[RND_CFR_DESIGN] == NULL) || (rnd_conf_main_root[RND_CFR_DESIGN]->root == NULL) || (rnd_conf_main_root[RND_CFR_DESIGN]->root->type != LHT_LIST))
 		return lht_dom_node_alloc(LHT_LIST, "pcb-rnd-conf-v1");
 
-	res = lht_dom_duptree(pcb_conf_main_root[RND_CFR_DESIGN]->root);
+	res = lht_dom_duptree(rnd_conf_main_root[RND_CFR_DESIGN]->root);
 
 	for(n = res->data.list.first; n != NULL; n = n->next) {
 		for(s = del_paths; *s != NULL; s++) {
@@ -1726,7 +1726,8 @@ static lht_doc_t *build_board(pcb_board_t *pcb)
 		goto error;
 
 	lht_dom_hash_put(brd->root, ntmp);
-	lht_dom_hash_put(brd->root, build_pxms());
+	if (wrver >= 7)
+		lht_dom_hash_put(brd->root, build_pxms());
 	lht_dom_hash_put(brd->root, build_attributes(&pcb->Attributes));
 	lht_dom_hash_put(brd->root, build_fontkit(&pcb->fontkit));
 	lht_dom_hash_put(brd->root, build_styles(pcb->Data, &pcb->RouteStyle));
@@ -1748,7 +1749,7 @@ static lhtpers_ev_res_t check_text(void *ev_ctx, lht_perstyle_t *style, lht_node
 		rnd_coord_t v1, v2;
 		rnd_bool success1, success2;
 
-/*		fprintf(stderr, "SMART d='%s' m='%s'\n", ondisk_value, inmem_node->data.text.value);*/
+/*		rnd_trace("SMART crd %s d='%s' m='%s'\n", inmem_node->name, ondisk_value, inmem_node->data.text.value);*/
 
 		v1 = rnd_get_value_ex(ondisk_value, NULL, NULL, NULL, NULL, &success1);
 		v2 = rnd_get_value_ex(inmem_node->data.text.value, NULL, NULL, NULL, NULL, &success2);
@@ -1760,8 +1761,24 @@ static lhtpers_ev_res_t check_text(void *ev_ctx, lht_perstyle_t *style, lht_node
 			else
 				return LHTPERS_MEM;
 		}
-		/* else fall back to the string compare below */
 	}
+	else if (lhtpers_rule_find(io_lihata_out_doubles, inmem_node) != NULL) {
+		double d1, d2;
+		char *end1, *end2;
+
+/*		rnd_trace("SMART dbl %s d='%s' m='%s'\n", inmem_node->name, ondisk_value, inmem_node->data.text.value);*/
+
+		d1 = strtod(ondisk_value, &end1);
+		d2 = strtod(inmem_node->data.text.value, &end2);
+		if ((*end1 == '\0') && (*end2 == '\0')) {
+			/* smart: if values are the same, keep the on-disk version */
+			if (d1 == d2)
+				return LHTPERS_DISK;
+			else
+				return LHTPERS_MEM;
+		}
+	}
+	/* else fall back to the string compare below */
 
 	if (inmem_node->data.text.value == NULL)
 		return LHTPERS_INHIBIT;
