@@ -545,9 +545,8 @@ static void parse_dwg_text(hkp_ctx_t *ctx, pcb_subc_t *subc, pcb_layer_t *ly, co
 		return;
 	}
 	tmp = find_nth(attr->first_child, "ROTATION", 0);
-	if (tmp != NULL) {
+	if (tmp != NULL)
 		parse_rot(ctx, tmp, &rot, (pcb_layer_flags_(ly) & PCB_LYT_BOTTOM));
-	}
 	else {
 		hkp_error(attr, "Can not find rotation of text. Text will be NOT rendered.\n");
 		return;
@@ -555,11 +554,8 @@ static void parse_dwg_text(hkp_ctx_t *ctx, pcb_subc_t *subc, pcb_layer_t *ly, co
 
 	tmp = find_nth(attr->first_child, "TEXT_OPTIONS", 0);
 	if (tmp != NULL)
-		if (strcmp(tmp->argv[1], "MIRRORED") == 0) {
-			mirrored = PCB_TXT_MIRROR_Y;
-			rot = rot + 180;
-			if (rot > 360) rot = rot - 360;
-		}
+		if (strcmp(tmp->argv[1], "MIRRORED") == 0)
+			mirrored = PCB_TXT_MIRROR_X;
 
 	tmp = find_nth(attr->first_child, "HEIGHT", 0);
 	if (tmp != NULL)
@@ -604,15 +600,12 @@ static void parse_dwg_text(hkp_ctx_t *ctx, pcb_subc_t *subc, pcb_layer_t *ly, co
 
 	tmp = find_nth(attr->first_child, "HORZ_JUST", 0);
 	if (tmp != NULL) {
-		if (strcmp(tmp->argv[1], "Left") == 0) {
+		if (strcmp(tmp->argv[1], "Left") == 0)
 			anchx = 0;
-		}
-		else if (strcmp(tmp->argv[1], "Center") == 0) {
+		else if (strcmp(tmp->argv[1], "Center") == 0)
 			anchx = width >> 1;
-		}
-		else if (strcmp(tmp->argv[1], "Right") == 0) {
+		else if (strcmp(tmp->argv[1], "Right") == 0)
 			anchx = width;
-		}
 		else
 			hkp_error(tmp, "Unknown horizontal alignment (%s). Text will be rendered, but it may not have a correct size.\n", tmp->argv[1]);
 	}
@@ -624,20 +617,12 @@ static void parse_dwg_text(hkp_ctx_t *ctx, pcb_subc_t *subc, pcb_layer_t *ly, co
 	tmp = find_nth(attr->first_child, "VERT_JUST", 0);
 	if (tmp != NULL) {
 		rnd_coord_t ymax = height+ymin;
-		TODO(
-			"Consider rotation, using:"
-			"  rnd_rotate(rnd_coord_t * x, rnd_coord_t * y, rnd_coord_t cx, rnd_coord_t cy, double cosa, double sina)"
-			"Maybe:"
-			"  double sina = sin(-(double)rot / RND_RAD_TO_DEG), cosa = cos(-(double)rot / RND_RAD_TO_DEG);");
-		if (strcmp(tmp->argv[1], "Top") == 0) {
+		if (strcmp(tmp->argv[1], "Top") == 0)
 			anchy = 0;
-		}
-		else if (strcmp(tmp->argv[1], "Center") == 0) {
+		else if (strcmp(tmp->argv[1], "Center") == 0)
 			anchy = ymax >> 1;
-		}
-		else if (strcmp(tmp->argv[1], "Bottom") == 0) {
+		else if (strcmp(tmp->argv[1], "Bottom") == 0)
 			anchy = height+ymin; /* ymin is negative */
-		}
 		else
 			hkp_error(tmp, "Unknown horizontal alignment (%s). Text will be rendered, but it may not have a correct size.\n", tmp->argv[1]);
 	}
@@ -646,16 +631,7 @@ static void parse_dwg_text(hkp_ctx_t *ctx, pcb_subc_t *subc, pcb_layer_t *ly, co
 		return;
 	}
 
-TODO("we should compensate for HOTIZ_JUST and VERT_JUST but for that we need to figure how big the text is originally");
-TODO("HEIGHT should become scale");
 TODO("figure what TEXT_OPTIONS we have. One of them is MIRRORED (brd2 example)");
-TODO("[easy] STROKE_WIDTH: we have support for that, but what's the unit? what if it is 0?. STROKE_WIDTH == 0 and != 0 in brd1 example");
-/* STROKE_WIDTH is the thickness of the "pen" drawing the text. */
-/*  Its units are mm or inches, whatever is used in the file at that moment */
-/*  When it is 0, original SW draws the outline of the letters, with 0.005mm pen thickness.*/
-/*  When drawing the outline of a vertical trace for '1' character, there are two thin traces.*/
-/*  The distance between those traces seems to depend on text height.*/
-/*  In brd2 example, it is 0.04mm for J1, assembly layer, and 0.02mm for R1.*/
 
 	if (mirrored != 0)
 		rot = -rot;
@@ -766,8 +742,8 @@ static int parse_side(node_t *n, pcb_subc_t *subc, pcb_layer_type_t *side, const
 		}
 	}
 
-	/* In some sections, like ..ASSEMBLY_OUTLINE inside .PACKAGE_CELL (a subcircuit), there is no explicit SIDE line. */
-	/* So if this is a subcircuit, and there is no SIDE line, get the side from subc side.*/
+	/* In some sections, like ..ASSEMBLY_OUTLINE inside .PACKAGE_CELL (a subcircuit), there is no explicit SIDE line.
+	   So if this is a subcircuit, and there is no SIDE line, get the side from subc side.*/
 	tmp = find_nth(n->first_child, "SIDE", 0);
 	if (tmp == NULL) {
 		if (subc != NULL) {
@@ -1003,12 +979,12 @@ static void parse_subc_text(hkp_ctx_t *ctx, pcb_subc_t *subc, const hkp_netclass
 
 	text_str = textnode->argv[1];
 	if (strcmp(tt->argv[1], "REF_DES") == 0) {
-		rnd_attribute_put(&subc->Attributes, "refdes", textnode->argv[1]);
+		pcb_attribute_put(&subc->Attributes, "refdes", textnode->argv[1]);
 		text_str = "%a.parent.refdes%";
 		flg |= PCB_FLAG_DYNTEXT;
 	}
 	else if (strcmp(tt->argv[1], "PARTNO") == 0) {
-		rnd_attribute_put(&subc->Attributes, "footprint", textnode->argv[1]);
+		pcb_attribute_put(&subc->Attributes, "footprint", textnode->argv[1]);
 		text_str = "%a.parent.footprint%";
 		flg |= PCB_FLAG_DYNTEXT;
 		omit_on_silk = 1;
@@ -1032,7 +1008,7 @@ static pcb_subc_t *parse_package(hkp_ctx_t *ctx, pcb_data_t *dt, node_t *nd)
 	/* extract global */
 	for(n = nd->first_child; n != NULL; n = n->next) {
 		if (strcmp(n->argv[0], "DESCRIPTION") == 0) {
-			rnd_attribute_put(&subc->Attributes, "description", n->argv[1]);
+			pcb_attribute_put(&subc->Attributes, "description", n->argv[1]);
 		}
 		else if (strcmp(n->argv[0], "XY") == 0) {
 			if ((parse_x(ctx, n->argv[1], &ox) != 0) || (parse_y(ctx, n->argv[2], &oy) != 0)) {
