@@ -34,6 +34,10 @@
 #include <librnd/core/hid.h>
 #include <librnd/core/compat_misc.h>
 #include "plug_io.h"
+#include "io_pads_conf.h"
+#include "../src_plugins/io_pads/conf_internal.c"
+
+conf_io_pads_t conf_io_pads;
 
 #include "read.h"
 #include "write.h"
@@ -50,10 +54,8 @@ int io_pads_fmt(pcb_plug_io_t *ctx, pcb_plug_iot_t typ, int wr, const char *fmt)
 	if (((typ & (~(PCB_IOT_FOOTPRINT))) != 0) && ((typ & (~(PCB_IOT_PCB))) != 0)) /* support only footprints */
 		return 0;
 
-#if 0
 	if (wr)
 		return 93;
-#endif
 	if (wr)
 		return 0;
 
@@ -67,6 +69,8 @@ void pplg_uninit_io_pads(void)
 {
 	RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_pads_2005);
 	RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_pads_9_4);
+	rnd_conf_unreg_intern(io_pads_conf_internal);
+	rnd_conf_unreg_fields("plugins/io_pads/");
 }
 
 int pplg_init_io_pads(void)
@@ -81,9 +85,7 @@ int pplg_init_io_pads(void)
 	io_pads_2005.map_footprint = io_pads_map_footprint;*/
 	io_pads_2005.parse_font = NULL;
 	io_pads_2005.write_buffer = NULL;
-#if 0
 	io_pads_2005.write_pcb = io_pads_write_pcb_2005;
-#endif
 	io_pads_2005.default_fmt = "pads";
 	io_pads_2005.description = "PADS ASCII board (V2005)";
 	io_pads_2005.save_preference_prio = 61;
@@ -97,11 +99,14 @@ int pplg_init_io_pads(void)
 	io_pads_9_4 = io_pads_2005;
 	io_pads_9_4.description = "PADS ASCII board (V9.4)";
 	io_pads_9_4.save_preference_prio = 63;
-#if 0
 	io_pads_9_4.write_pcb = io_pads_write_pcb_9_4;
-#endif
 	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_pads_9_4);
 
+	rnd_conf_reg_intern(io_pads_conf_internal);
+#define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
+	rnd_conf_reg_field(conf_io_pads, field,isarray,type_name,cpath,cname,desc,flags);
+#include "io_pads_conf_fields.h"
+
 	return 0;
 }
 
