@@ -46,6 +46,15 @@ static int pads_parse_ignore_sect(pads_read_ctx_t *rctx)
 		ungetc(c, rctx->f);
 
 		res = pads_read_word(rctx, word, sizeof(word), 0);
+
+		/* special case: we ignored an empty section, the first thing we see
+		   is a *SECT* that is not *REMARK*. Return success before this next
+		   *SECT* is read */
+		c = fgetc(rctx->f);
+		ungetc(c, rctx->f);
+		if (c == '*')
+			return 1;
+
 		if (res <= 0)
 			return res;
 		pads_eatup_till_nl(rctx);
@@ -298,7 +307,13 @@ TODO("''KEEPOUT'' objects are not handled: CIRCUT and COPCUT and COPCIR are poly
 	else if ((strcmp(ptype, "COPCCO") == 0) || (strcmp(ptype, "COPCIR") == 0) || (strcmp(ptype, "CIRCUR") == 0)) {
 		if ((res = pads_parse_piece_circle(rctx, &lpc, num_crds, 1)) <= 0) return res;
 	}
+	else if (strcmp(ptype, "COPCLS") == 0) {
+TODO("read COPCLS here in another branch of the else if - should be poly");
+		goto todo1;
+	}
 	else {
+		/* "CLOSED" comes here: it is reallt unfilled polygon */
+		todo1:;
 		for(n = 0; n < num_crds; n++)
 			if ((res = pads_parse_piece_crd(rctx, &lpc, n)) <= 0) return res;
 	}
@@ -591,7 +606,7 @@ static int pads_parse_pstk_proto(pads_read_ctx_t *rctx, vtp0_t *terms, long *def
 	for(n = sn = 0; n < num_lines; n++) {
 		double rot = 0, slotrot = 0, spokerot = 0;
 		char plated[8];
-		int c, is_thermal;
+		int c, is_thermal, has_corner = 0;
 		long spoke_num = 0;
 		rnd_coord_t finlen = 0, finoffs = 0, inner = 0, corner = 0, drill = 0, slotlen = 0, slotoffs = 0, spoke_outsize = 0, spoke_width = 0;
 		pcb_pstk_shape_t *shp = ts->shape + sn;
@@ -609,11 +624,14 @@ static int pads_parse_pstk_proto(pads_read_ctx_t *rctx, vtp0_t *terms, long *def
 				if (OPTF) if ((res = pads_read_double(rctx, &rot)) <= 0) return res;
 				if (OPTF) if ((res = pads_read_coord(rctx, &finlen)) <= 0) return res;
 				if (OPTF) if ((res = pads_read_coord(rctx, &finoffs)) <= 0) return res;
-				if (pads_has_field(rctx) && (shape[0] == 'R')) /* RF=rectangular finger */
+				if (pads_has_field(rctx) && (shape[0] == 'R')) { /* RF=rectangular finger */
 					if ((res = pads_read_coord(rctx, &corner)) <= 0) return res;
+					has_corner = 1;
+				}
 			}
 			else if (pads_has_field(rctx) && shape[0] == 'S') { /* S=square */
 				if ((res = pads_read_coord(rctx, &corner)) <= 0) return res;
+				has_corner = 1;
 			}
 
 			/* next word is either drill diameter or P/N for plated-or-not */
@@ -626,6 +644,12 @@ static int pads_parse_pstk_proto(pads_read_ctx_t *rctx, vtp0_t *terms, long *def
 				if ((res = pads_read_coord(rctx, &drill)) <= 0) return res;
 				proto->hdia = drill;
 			}
+			else if (has_corner) {
+				/* special case: for Square and RF: if corner is not followed by drill, corner must be the drill instead (corner is optional) */
+				proto->hdia = corner;
+				corner = 0;
+			}
+
 			plated[0] = '\0';
 			if (pads_has_field(rctx))
 				if ((res = pads_read_word(rctx, plated, sizeof(plated), 0)) <= 0) return res;
@@ -1094,6 +1118,9 @@ static void add_teardrop(void *rctx_, pcb_any_obj_t *obj, void *call_ctx)
 	pcb_layer_t *ly;
 	pcb_data_t *dt;
 
+	if (!conf_io_pads.plugins.io_pads.load_teardrops)
+		return;
+
 	if (obj->parent_type != PCB_PARENT_LAYER)
 		return;
 
@@ -1293,6 +1320,8 @@ static int pads_parse_net(pads_read_ctx_t *rctx)
 	pads_sig_piece_t spc = {0};
 	pcb_net_t *net;
 
+	next_trace:;
+
 	if ((res = pads_read_word(rctx, term1, sizeof(term1), 0)) <= 0) return res;
 	if ((res = pads_read_word(rctx, term2, sizeof(term2), 0)) <= 0) return res;
 	pads_eatup_till_nl(rctx);
@@ -1306,9 +1335,22 @@ static int pads_parse_net(pads_read_ctx_t *rctx)
 	for(idx = 0; ;idx++) {
 		double tmp;
 
-		pads_eatup_ws(rctx);
-		c = fgetc(rctx->f);
+		/* look ahead for the first non-whitespace, non-newline character; it's
+		   either the next coord, or the next trace in the same net (refdes),
+		   or the next section ('*') */
+		while(!(feof(rctx->f))) {
+			pads_eatup_ws(rctx);
+			c = fgetc(rctx->f);
+			if ((c == '\r') || (c == '\n'))
+				pads_update_loc(rctx, c);
+			else
+				break;
+		}
 		ungetc(c, rctx->f);
+		if (c == '*')
+			return -4;
+		if (!isspace(c) && !isdigit(c)) /* if the line starts with a refdes, it's the next trace for the same net */
+			goto next_trace;
 
 		if (pads_maybe_read_double(rctx, pads_saved_word, sizeof(pads_saved_word), &tmp) == 1)
 			break; /* when next word is a string; also save the next word so it is returned in the next read */
@@ -1386,6 +1428,12 @@ static int pads_parse_pour_piece_polycnt(pads_read_ctx_t *rctx, pads_poly_type_t
 	if ((res = pads_read_long(rctx, &level)) <= 0) return res;
 	pads_eatup_till_nl(rctx); /* ignore rest of the arguments */
 
+	if (!conf_io_pads.plugins.io_pads.load_polygons) {
+		for(n = 0; n < num_corners + num_arcs; n++)
+			if ((res = pads_parse_pour_piece_crd(rctx, NULL, PADS_POTY_NOOP, xo, yo)) <= 0) return res;
+		return 1;
+	}
+
 	rnd_trace(" %s:\n", type);
 	if (poty != PADS_POTY_NOOP)
 		poly = pcb_dlcr_poly_new(&rctx->dlcr, 0, num_corners + num_arcs*8);
