@@ -4,7 +4,7 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996,1997,1998,2005,2006 Thomas Nau
- *  Copyright (C) 2015, 2018 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2015, 2018, 2021 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -70,11 +70,13 @@
 #include "funchash_core.h"
 #include "netlist.h"
 #include "plug_footprint.h"
+#include "obj_pstk_inlines.h"
 
 #include "src_plugins/lib_compat_help/layer_compat.h"
 #include "src_plugins/lib_compat_help/pstk_compat.h"
 #include "src_plugins/lib_compat_help/subc_help.h"
 #include "src_plugins/lib_compat_help/elem_rot.h"
+#include "src_plugins/lib_compat_help/route_style.h"
 
 /* Note: this works because of using str_flag compat_types */
 #define PCB_OBJ_VIA PCB_OBJ_PSTK
@@ -304,13 +306,17 @@ static void WritePCBDataHeader(FILE * FP)
 	fputs("Styles[\"", FP);
 
 	if (vtroutestyle_len(&PCB->RouteStyle) > 0) {
-		for (group = 0; group < vtroutestyle_len(&PCB->RouteStyle) - 1; group++)
+		rnd_coord_t drill_dia, pad_dia, mask;
+		for (group = 0; group < vtroutestyle_len(&PCB->RouteStyle) - 1; group++) {
+			pcb_compat_route_style_via_save(PCB->Data, &PCB->RouteStyle.array[group], &drill_dia, &pad_dia, &mask);
 			rnd_fprintf(FP, "%s,%[0],%[0],%[0],%[0]:", PCB->RouteStyle.array[group].name,
-									PCB->RouteStyle.array[group].Thick,
-									PCB->RouteStyle.array[group].Diameter, PCB->RouteStyle.array[group].Hole, PCB->RouteStyle.array[group].Clearance);
+				PCB->RouteStyle.array[group].Thick, pad_dia,
+				drill_dia, PCB->RouteStyle.array[group].Clearance);
+		}
+		pcb_compat_route_style_via_save(PCB->Data, &PCB->RouteStyle.array[group], &drill_dia, &pad_dia, &mask);
 		rnd_fprintf(FP, "%s,%[0],%[0],%[0],%[0]\"]\n\n", PCB->RouteStyle.array[group].name,
-								PCB->RouteStyle.array[group].Thick,
-								PCB->RouteStyle.array[group].Diameter, PCB->RouteStyle.array[group].Hole, PCB->RouteStyle.array[group].Clearance);
+			PCB->RouteStyle.array[group].Thick, pad_dia,
+			drill_dia, PCB->RouteStyle.array[group].Clearance);
 	}
 	else {
 		pcb_io_incompat_save(PCB->Data, NULL, "route-style", "There are no routing styles - many versions of gEDA/PCB will segfault on loading the file", "Create exactly 4 routing styles.");
@@ -646,6 +652,8 @@ static void WriteLayerData(FILE * FP, rnd_cardinal_t Number, pcb_layer_t *layer)
 				pcb_io_incompat_save(NULL, (pcb_any_obj_t *)text, "text-mirror-x", "file format does not support different mirroring text in the x direction", "do not mirror, or mirror in the y direction (with the ONSOLDER flag)");
 			if (!pcb_text_old_direction(&dir, text->rot))
 				pcb_io_incompat_save(NULL, (pcb_any_obj_t *)text, "text rotation", "text rotation angle rounded", "the gEDA/PCB file format does not support text rotation other than multiple of 90 degree");
+			if (text->clearance != 0)
+				pcb_io_incompat_save(NULL, (pcb_any_obj_t *)text, "text-clearance", "file format does not support custom text clearance value", "do not use text clearance or save in lihata >=v8");
 			rnd_fprintf(FP, "\tText[%[0] %[0] %d %d ", text->X, text->Y, dir, scale);
 			pcb_print_quoted_string(FP, (char *) RND_EMPTY(text->TextString));
 			fprintf(FP, " %s]\n", F2S(text, PCB_OBJ_TEXT));
