@@ -37,10 +37,12 @@
 #include "parse.h"
 
 #include <librnd/core/unit.h>
-#include <librnd/core/attrib.h>
+#include "attrib.h"
 #include <librnd/core/error.h>
 #include "data.h"
 #include "board.h"
+#include "conf_core.h"
+#include "plug_footprint.h"
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/safe_fs.h>
@@ -228,6 +230,9 @@ int tedax_fp_fsave_subc_(pcb_subc_t *subc, const char *fpname, int lyrecipe, FIL
 				rnd_coord_t x, y;
 				pcb_poly_it_t it;
 
+				if (polygon->Clipped == NULL)
+					pcb_poly_init_clip(polygon->parent.layer->parent.data, polygon->parent.layer, polygon);
+
 				pcb_poly_iterate_polyarea(polygon->Clipped, &it);
 				if (pcb_poly_contour(&it) == NULL) {
 					rnd_message(RND_MSG_ERROR, "tEDAx footprint export: omitting subc polygon with no clipped contour\n");
@@ -281,11 +286,11 @@ int tedax_fp_fsave_subc_(pcb_subc_t *subc, const char *fpname, int lyrecipe, FIL
 
 int tedax_fp_fsave_subc(pcb_subc_t *subc, FILE *f)
 {
-	const char *fpname = rnd_attribute_get(&subc->Attributes, "tedax::footprint");
+	const char *fpname = pcb_attribute_get(&subc->Attributes, "tedax::footprint");
 	if (fpname == NULL)
-		fpname = rnd_attribute_get(&subc->Attributes, "visible_footprint");
+		fpname = pcb_attribute_get(&subc->Attributes, "visible_footprint");
 	if (fpname == NULL)
-		fpname = rnd_attribute_get(&subc->Attributes, "footprint");
+		fpname = pcb_attribute_get(&subc->Attributes, "footprint");
 	if ((fpname == NULL) && (subc->refdes != NULL))
 		fpname = subc->refdes;
 	if (fpname == NULL)
@@ -389,16 +394,14 @@ do { \
 
 #define load_term(obj, src, msg) \
 do { \
-	int termid; \
 	term_t *term; \
 	if ((src[0] == '-') && (src[1] == '\0')) break; \
-	load_int(termid, src, msg); \
-	term = htip_get(&terms, termid); \
+	term = htsp_get(&terms, src); \
 	if (term == NULL) { \
-		rnd_message(RND_MSG_ERROR, "undefined terminal %s - skipping footprint\n", src); \
+		rnd_message(RND_MSG_ERROR, msg, src); \
 		return -1; \
 	} \
-	rnd_attribute_put(&obj->Attributes, "term", term->name); \
+	pcb_attribute_put(&obj->Attributes, "term", term->name); \
 	vtp0_append(&term->objs, obj); \
 } while(0)
 
@@ -479,24 +482,26 @@ static pcb_layer_t **subc_get_layer(pcb_subc_t *subc, const char *lloc, const ch
 /* Parse one footprint block */
 static int tedax_parse_1fp_(pcb_subc_t *subc, FILE *fn, char *buff, int buff_size, char *argv[], int argv_size)
 {
-	int argc, termid, numpt, res = -1;
-	htip_entry_t *ei;
-	htip_t terms;
+	int argc, numpt, res = -1;
+	htsp_entry_t *ei;
+	htsp_t terms;
 	term_t *term;
 	rnd_coord_t px[256], py[256], clr;
 	pcb_layer_t **ly;
 
-	htip_init(&terms, longhash, longkeyeq);
+	htsp_init(&terms, strhash, strkeyeq);
 	while((argc = tedax_getline(fn, buff, buff_size, argv, argv_size)) >= 0) {
 		if ((argc == 5) && (strcmp(argv[0], "term") == 0)) {
-			load_int(termid, argv[1], "invalid term ID '%s', skipping footprint\n");
 			term = term_new(argv[2], argv[4]);
-			htip_set(&terms, termid, term);
+			htsp_set(&terms, rnd_strdup(argv[1]), term);
 		}
-		else if ((argc > 12) && (strcmp(argv[0], "polygon") == 0)) {
+		else if ((argc >= 12) && (strcmp(argv[0], "polygon") == 0)) {
 			pcb_poly_t *p;
 			ly = subc_get_layer(subc, argv[1], argv[2]);
-			if (ly == NULL) return -1;
+			if (ly == NULL) {
+				rnd_message(RND_MSG_ERROR, "tEDAx footprint load: invalid polygon layer %s %s\n", argv[1], argv[2]);
+				return -1;
+			}
 
 			numpt = load_poly(px, py, (sizeof(px) / sizeof(px[0])), argc-5, argv+5);
 			if (numpt < 0) {
@@ -525,6 +530,10 @@ static int tedax_parse_1fp_(pcb_subc_t *subc, FILE *fn, char *buff, int buff_siz
 			pcb_line_t *l;
 
 			ly = subc_get_layer(subc, argv[1], argv[2]);
+			if (ly == NULL) {
+				rnd_message(RND_MSG_ERROR, "tEDAx footprint load: invalid line layer %s %s\n", argv[1], argv[2]);
+				return -1;
+			}
 
 			load_val(x1, argv[4], "invalid line x1");
 			load_val(y1, argv[5], "invalid line y1");
@@ -544,6 +553,10 @@ static int tedax_parse_1fp_(pcb_subc_t *subc, FILE *fn, char *buff, int buff_siz
 			pcb_arc_t *a;
 
 			ly = subc_get_layer(subc, argv[1], argv[2]);
+			if (ly == NULL) {
+				rnd_message(RND_MSG_ERROR, "tEDAx footprint load: invalid arc layer %s %s\n", argv[1], argv[2]);
+				return -1;
+			}
 
 			load_val(cx, argv[4], "invalid arc cx");
 			load_val(cy, argv[5], "invalid arc cy");
@@ -575,6 +588,11 @@ static int tedax_parse_1fp_(pcb_subc_t *subc, FILE *fn, char *buff, int buff_siz
 			pcb_line_t *l;
 
 			ly = subc_get_layer(subc, argv[1], argv[2]);
+			if (ly == NULL) {
+				rnd_message(RND_MSG_ERROR, "tEDAx footprint load: invalid fillcircle layer %s %s\n", argv[1], argv[2]);
+				return -1;
+			}
+
 			load_val(cx, argv[4], "invalid fillcircle cx");
 			load_val(cy, argv[5], "invalid fillcircle cy");
 			load_val(r, argv[6], "invalid fillcircle radius");
@@ -589,19 +607,24 @@ static int tedax_parse_1fp_(pcb_subc_t *subc, FILE *fn, char *buff, int buff_siz
 			res = 0;
 			break;
 		}
+		else {
+			rnd_message(RND_MSG_ERROR, "tEDAx footprint load: invalid object %s with %d fields\n", argv[0], argc);
+			return -1;
+		}
 	}
 
 	/* By now we have heavy terminals and a list of object for each terminal in
 	   the terms hash. Iterate over the terminals and try to convert the objects
 	   into one or more padstacks */
-	for (ei = htip_first(&terms); ei; ei = htip_next(&terms, ei)) {
+	for(ei = htsp_first(&terms); ei; ei = htsp_next(&terms, ei)) {
 		term = ei->value;
 		pcb_pstk_vect2pstk(subc->data, &term->objs, rnd_true);
 		term_destroy(term);
+		free(ei->key);
 	}
-	htip_uninit(&terms);
+	htsp_uninit(&terms);
 
-	rnd_attribute_put(&subc->Attributes, "refdes", "X1");
+	pcb_attribute_put(&subc->Attributes, "refdes", "X1");
 	pcb_subc_add_refdes_text(subc, 0, 0, 0, 100, rnd_false);
 	pcb_subc_create_aux(subc, 0, 0, 0.0, rnd_false);
 
@@ -645,12 +668,17 @@ static int tedax_parse_fp(pcb_data_t *data, FILE *fn, int multi, const char *blk
 	return 0;
 }
 
-int tedax_fp_load(pcb_data_t *data, const char *fn, int multi, const char *blk_id, int silent)
+int tedax_fp_load(pcb_data_t *data, const char *fn, int multi, const char *blk_id, int silent, int searchlib)
 {
 	FILE *f;
 	int ret = 0;
+	pcb_fp_fopen_ctx_t st;
 
-	f = rnd_fopen(&PCB->hidlib, fn, "r");
+
+	if (searchlib)
+		f = pcb_fp_fopen(&conf_core.rc.library_search_paths, fn, &st, NULL);
+	else
+		f = rnd_fopen(&PCB->hidlib, fn, "r");
 	if (f == NULL) {
 		rnd_message(RND_MSG_ERROR, "can't open file '%s' for read\n", fn);
 		return -1;
@@ -658,7 +686,10 @@ int tedax_fp_load(pcb_data_t *data, const char *fn, int multi, const char *blk_i
 
 	ret = tedax_parse_fp(data, f, multi, blk_id, silent);
 
-	fclose(f);
+	if (searchlib)
+		pcb_fp_fclose(f, &st);
+	else
+		fclose(f);
 	return ret;
 }
 
