@@ -139,7 +139,7 @@ static fgw_error_t pcb_act_Savetedax(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 do { \
 	static char *default_file = NULL; \
 	if ((fname == NULL) || (*fname == '\0')) { \
-		fname = rnd_gui->fileselect(rnd_gui, "Load tedax " #type " file...", \
+		fname = rnd_hid_fileselect(rnd_gui, "Load tedax " #type " file...", \
 																"Picks a tedax " #type " file to load.\n", \
 																default_file, ".tdx", NULL, "tedax-" #type, RND_HID_FSD_READ, NULL); \
 		if (fname == NULL) \
