@@ -138,7 +138,7 @@ static void compat_shape_free(pcb_pstk_shape_t *shp)
 		free(shp->data.poly.x);
 }
 
-rnd_cardinal_t pcb_pstk_new_compat_via_proto(pcb_data_t *data, rnd_coord_t drill_dia, rnd_coord_t pad_dia, rnd_coord_t mask, pcb_pstk_compshape_t cshape, rnd_bool plated, rnd_bool hole_clearance_hack)
+static rnd_cardinal_t pcb_pstk_new_compat_via_proto_(pcb_data_t *data, rnd_coord_t drill_dia, rnd_coord_t pad_dia, rnd_coord_t mask, pcb_pstk_compshape_t cshape, rnd_bool plated, rnd_bool hole_clearance_hack, int bb_top, int bb_bottom)
 {
 	pcb_pstk_proto_t proto;
 	pcb_pstk_shape_t shape[5]; /* max number of shapes: 3 coppers, 2 masks */
@@ -158,6 +158,8 @@ rnd_cardinal_t pcb_pstk_new_compat_via_proto(pcb_data_t *data, rnd_coord_t drill
 	tshp.shape = shape;
 	proto.tr.alloced = proto.tr.used = 1; /* has the canonical form only */
 	proto.tr.array = &tshp;
+	proto.htop = bb_top;
+	proto.hbottom = bb_bottom;
 
 	if (plated || hole_clearance_hack) {
 		tshp.len = 3 + (mask > 0 ? 2 : 0);
@@ -205,7 +207,12 @@ rnd_cardinal_t pcb_pstk_new_compat_via_proto(pcb_data_t *data, rnd_coord_t drill
 	return pid;
 }
 
-static pcb_pstk_t *pcb_pstk_new_compat_via_(pcb_data_t *data, long int id, rnd_coord_t x, rnd_coord_t y, rnd_coord_t drill_dia, rnd_coord_t pad_dia, rnd_coord_t clearance, rnd_coord_t mask, pcb_pstk_compshape_t cshape, rnd_bool plated, rnd_bool hole_clearance_hack)
+rnd_cardinal_t pcb_pstk_new_compat_via_proto(pcb_data_t *data, rnd_coord_t drill_dia, rnd_coord_t pad_dia, rnd_coord_t mask, pcb_pstk_compshape_t cshape, rnd_bool plated, rnd_bool hole_clearance_hack)
+{
+	return pcb_pstk_new_compat_via_proto_(data, drill_dia, pad_dia, mask, cshape, plated, hole_clearance_hack, 0, 0);
+}
+
+static pcb_pstk_t *pcb_pstk_new_compat_via_(pcb_data_t *data, long int id, rnd_coord_t x, rnd_coord_t y, rnd_coord_t drill_dia, rnd_coord_t pad_dia, rnd_coord_t clearance, rnd_coord_t mask, pcb_pstk_compshape_t cshape, rnd_bool plated, rnd_bool hole_clearance_hack, int bb_top, int bb_bottom)
 {
 	rnd_cardinal_t pid;
 
@@ -223,7 +230,7 @@ static pcb_pstk_t *pcb_pstk_new_compat_via_(pcb_data_t *data, long int id, rnd_c
 	if (plated && !hole_clearance_hack)
 		assert(pad_dia > drill_dia);
 
-	pid = pcb_pstk_new_compat_via_proto(data, drill_dia, pad_dia, mask, cshape, plated, hole_clearance_hack);
+	pid = pcb_pstk_new_compat_via_proto_(data, drill_dia, pad_dia, mask, cshape, plated, hole_clearance_hack, bb_top, bb_bottom);
 	if (pid == -1)
 		return NULL;
 	return pcb_pstk_new(data, -1, pid, x, y, clearance, pcb_flag_make(PCB_FLAG_CLEARLINE));
@@ -232,9 +239,13 @@ static pcb_pstk_t *pcb_pstk_new_compat_via_(pcb_data_t *data, long int id, rnd_c
 
 pcb_pstk_t *pcb_pstk_new_compat_via(pcb_data_t *data, long int id, rnd_coord_t x, rnd_coord_t y, rnd_coord_t drill_dia, rnd_coord_t pad_dia, rnd_coord_t clearance, rnd_coord_t mask, pcb_pstk_compshape_t cshape, rnd_bool plated)
 {
-	return pcb_pstk_new_compat_via_(data, id, x, y, drill_dia, pad_dia, clearance, mask, cshape, plated, 0);
+	return pcb_pstk_new_compat_via_(data, id, x, y, drill_dia, pad_dia, clearance, mask, cshape, plated, 0, 0, 0);
 }
 
+pcb_pstk_t *pcb_pstk_new_compat_bbvia(pcb_data_t *data, long int id, rnd_coord_t x, rnd_coord_t y, rnd_coord_t drill_dia, rnd_coord_t pad_dia, rnd_coord_t clearance, rnd_coord_t mask, pcb_pstk_compshape_t cshape, rnd_bool plated, int bb_top, int bb_bottom)
+{
+	return pcb_pstk_new_compat_via_(data, id, x, y, drill_dia, pad_dia, clearance, mask, cshape, plated, 0, bb_top, bb_bottom);
+}
 
 static pcb_pstk_compshape_t get_old_shape_square(rnd_coord_t *dia, const pcb_pstk_shape_t *shp)
 {
@@ -571,6 +582,46 @@ pcb_pstk_t *pcb_pstk_new_compat_pad(pcb_data_t *data, long int id, rnd_coord_t x
 	return pcb_pstk_new(data, id, pid, cx, cy, clearance/2, pcb_flag_make(PCB_FLAG_CLEARLINE));
 }
 
+rnd_bool pcb_pstk_shape2rect(const pcb_pstk_shape_t *shape, double *w_out, double *h_out, double *cx_out, double *cy_out, double *rot_out, double *vx01_out, double *vy01_out, double *vx03_out, double *vy03_out)
+{
+	double x0, y0, x1, y1, x2, y2, x3, y3, w, h, cx, cy;
+
+	if (shape->shape != PCB_PSSH_POLY)
+		return rnd_false;
+
+	if (shape->data.poly.len != 4)
+		return rnd_false;
+
+	x0 = shape->data.poly.x[0]; y0 = shape->data.poly.y[0];
+	x1 = shape->data.poly.x[1]; y1 = shape->data.poly.y[1];
+	x2 = shape->data.poly.x[2]; y2 = shape->data.poly.y[2];
+	x3 = shape->data.poly.x[3]; y3 = shape->data.poly.y[3];
+	w = rnd_distance(x0, y0, x1, y1);
+	h = rnd_distance(x0, y0, x3, y3);
+
+	if ((cx_out != NULL) || (cy_out != NULL) || (rot_out != NULL)) {
+		cx = (x0+x1+x2+x3)/4.0;
+		cy = (y0+y1+y2+y3)/4.0;
+	}
+
+	if (cx_out != NULL) *cx_out = cx;
+	if (cy_out != NULL) *cy_out = cy;
+	if (w_out != NULL) *w_out = w;
+	if (h_out != NULL) *h_out = h;
+	if (vx01_out != NULL) *vx01_out = (x1 - x0) / w;
+	if (vy01_out != NULL) *vy01_out = (y1 - y0) / w;
+	if (vx03_out != NULL) *vx03_out = (x3 - x0) / h;
+	if (vy03_out != NULL) *vy03_out = (y3 - y0) / h;
+
+	if (rot_out != NULL) {
+		double mx = (x0 + x3) / 2;
+		double my = (y0 + y3) / 2;
+		*rot_out = atan2(my - cy, mx - cx);
+	}
+
+	return rnd_true;
+}
+
 
 rnd_bool pcb_pstk_export_compat_pad(pcb_pstk_t *ps, rnd_coord_t *x1, rnd_coord_t *y1, rnd_coord_t *x2, rnd_coord_t *y2, rnd_coord_t *thickness, rnd_coord_t *clearance, rnd_coord_t *mask, rnd_bool *square, rnd_bool *nopaste)
 {
@@ -630,28 +681,14 @@ rnd_bool pcb_pstk_export_compat_pad(pcb_pstk_t *ps, rnd_coord_t *x1, rnd_coord_t
 	/* if the shape is poly, convert to line to make the rest of the code simpler */
 	if (tshp->shape[0].shape == PCB_PSSH_POLY) {
 		for(n = 0; n < tshp->len; n++) {
-			double x0, y0, x1, y1, x2, y2, x3, y3, w, h, vx01, vy01, vx03, vy03, cx, cy;
+			double w, h, cx, cy, vx01, vy01, vx03, vy03;
 
 			if (tshp->shape[n].shape != PCB_PSSH_POLY)
 				continue;
 
-			if (tshp->shape[n].data.poly.len != 4)
+			if (!pcb_pstk_shape2rect(&tshp->shape[n], &w, &h, &cx, &cy, NULL, &vx01, &vy01, &vx03, &vy03))
 				return rnd_false;
 
-			x0 = tshp->shape[n].data.poly.x[0]; y0 = tshp->shape[n].data.poly.y[0];
-			x1 = tshp->shape[n].data.poly.x[1]; y1 = tshp->shape[n].data.poly.y[1];
-			x2 = tshp->shape[n].data.poly.x[2]; y2 = tshp->shape[n].data.poly.y[2];
-			x3 = tshp->shape[n].data.poly.x[3]; y3 = tshp->shape[n].data.poly.y[3];
-			w = rnd_distance(x0, y0, x1, y1);
-			h = rnd_distance(x0, y0, x3, y3);
-			vx01 = (x1 - x0) / w;
-			vy01 = (y1 - y0) / w;
-			vx03 = (x3 - x0) / h;
-			vy03 = (y3 - y0) / h;
-
-			cx = (x0+x1+x2+x3)/4.0;
-			cy = (y0+y1+y2+y3)/4.0;
-
 			if (w <= h) {
 				lt[n] = rnd_round(w);
 				lx1[n] = rnd_round(cx + h/2.0 * vx03 - w/2.0 * vx03);
@@ -813,7 +850,7 @@ pcb_pstk_t *pcb_old_via_new(pcb_data_t *data, long int id, rnd_coord_t X, rnd_co
 	else
 		shp = PCB_PSTK_COMPAT_ROUND;
 
-	p = pcb_pstk_new_compat_via_(data, id, X, Y, DrillingHole, Thickness, Clearance/2, Mask, shp, !(Flags.f & PCB_FLAG_HOLE), 1);
+	p = pcb_pstk_new_compat_via_(data, id, X, Y, DrillingHole, Thickness, Clearance/2, Mask, shp, !(Flags.f & PCB_FLAG_HOLE), 1, 0, 0);
 	p->Flags.f |= Flags.f & PCB_PSTK_VIA_COMPAT_FLAGS;
 	for(n = 0; n < sizeof(Flags.t) / sizeof(Flags.t[0]); n++) {
 		int nt = PCB_THERMAL_ON, t = ((Flags.t[n/2] >> (4 * (n % 2))) & 0xf);
