@@ -35,16 +35,21 @@
 #include <librnd/core/hid_dad.h>
 #include <librnd/core/hid_dad_tree.h>
 #include <librnd/core/conf_hid.h>
+#include <librnd/core/hid_inlines.h>
 #include "netlist.h"
+#include "event.h"
 
 #include "props.h"
 #include "propsel.h"
 
+extern const char *pcb_propedit_cookie;
+
 typedef struct{
 	RND_DAD_DECL_NOINIT(dlg)
 	pcb_propedit_t pe;
-	int wtree, wfilter, wtype, wvals, wscope;
+	int wtree, wfilter, wtype, wvals, wscope, wprev, whelptxt;
 	int wabs[PCB_PROPT_max], wedit[PCB_PROPT_max];
+	unsigned lock:1; /* do not refresh while editing */
 	gdl_elem_t link;
 } propdlg_t;
 
@@ -210,9 +215,61 @@ static void prop_pcb2dlg(propdlg_t *ctx)
 	}
 }
 
+static void (*help_expose)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e) = NULL;
+
+static void help_trace_thickness(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+#	include "help/thickness.c"
+}
+
+static void help_trace_clearance(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+#	include "help/clearance.c"
+}
+
+static void help_text_scale(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+#	include "help/text_scale.c"
+}
+
+static void help_text_scale_x(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+#	include "help/text_scale_x.c"
+}
+
+static void help_text_scale_y(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+#	include "help/text_scale_y.c"
+}
+
+static void help_text_thickness(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+#	include "help/text_thickness.c"
+}
+
+static void help_text_rotation(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+#	include "help/text_rot.c"
+}
+
+static void help_arc_angles(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+#	include "help/arc_angles.c"
+}
+
+static void help_arc_r(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+#	include "help/arc_r.c"
+}
+
+static void prop_nil_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+{
+}
+
 static void prop_prv_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
 {
-	
+	if (help_expose != NULL)
+		help_expose(attrib, prv, gc, e);
 }
 
 
@@ -310,10 +367,67 @@ static void prop_select_node_cb(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_
 	rnd_hid_tree_t *tree = attrib->wdata;
 	propdlg_t *ctx = tree->user_ctx;
 	pcb_props_t *p = NULL;
+	void (*last_help)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e) = NULL;
+	const char *helptxt = NULL;
 
-	if (row != NULL)
+	last_help = help_expose;
+	help_expose = NULL;
+
+	if (row != NULL) {
 		p = pcb_props_get(&ctx->pe, row->user_data);
 
+		/* update the help preview */
+		if (strcmp(row->path, "p/trace/thickness") == 0)               help_expose = help_trace_thickness;
+		else if (strcmp(row->path, "p/trace/clearance") == 0)          help_expose = help_trace_clearance;
+		else if (strcmp(row->path, "p/padstack/clearance") == 0)       help_expose = help_trace_clearance;
+		else if (strcmp(row->path, "p/text/scale") == 0)               help_expose = help_text_scale;
+		else if (strcmp(row->path, "p/text/scale_x") == 0)             help_expose = help_text_scale_x;
+		else if (strcmp(row->path, "p/text/scale_y") == 0)             help_expose = help_text_scale_y;
+		else if (strcmp(row->path, "p/text/rotation") == 0)            help_expose = help_text_rotation;
+		else if (strcmp(row->path, "p/text/thickness") == 0)           help_expose = help_text_thickness;
+		else if (strcmp(row->path, "p/arc/angle/start") == 0)          help_expose = help_arc_angles;
+		else if (strcmp(row->path, "p/arc/angle/delta") == 0)          help_expose = help_arc_angles;
+		else if (strcmp(row->path, "p/arc/height") == 0)               help_expose = help_arc_r;
+		else if (strcmp(row->path, "p/arc/width") == 0)                help_expose = help_arc_r;
+
+		else if (strcmp(row->path, "p/flags/clearline") == 0)          helptxt = "When set, object tries\nto clear into\npolygons (the\npolygon needs to\nhave the clearpoly\nflag set)";
+		else if (strcmp(row->path, "p/flags/clearpoly") == 0)          helptxt = "When set, objects can\nclear into the\npolygon (the object\nneeds to have the\nclearline flag set)";
+		else if (strcmp(row->path, "p/flags/clearpolypoly") == 0)      helptxt = "When set, polygons can\nclear into the\npolygon (the polygon\nneeds to have the\nclearline flag set\nand clearpolypoly flag\nunset)";
+		else if (strcmp(row->path, "p/flags/dyntext") == 0)            helptxt = "When set, %var%\ntemplates in text object\nstrings are substituted";
+		else if (strcmp(row->path, "p/flags/floater") == 0)            helptxt = "When set, object\ncan be moved freely\neven if it is part\nof a subcircuit";
+		else if (strcmp(row->path, "p/flags/onsolder") == 0)           helptxt = "Object is \"on the\nother side\";\nin practice: mirror";
+		else if (strcmp(row->path, "p/trace/enforce_clearance") == 0)  helptxt = "Clearances within this\npolygon will be at least\nthis large even if\nthe clearing object would\nuse a smaller clearance\n(Only for clearing\nobjects)";
+		else if (strcmp(row->path, "p/padstack/hbottom") == 0)         helptxt = "In case of blind/burried\nvia, the address of the bottom\ncopper layer the hole\nis spanning to";
+		else if (strcmp(row->path, "p/padstack/htop") == 0)            helptxt = "In case of blind/burried\nvia, the address of the top\ncopper layer the hole\nis spanning to";
+		else if (strcmp(row->path, "p/padstack/hole") == 0)            helptxt = "Hole diameter.\nIf 0, no hole.";
+		else if (strcmp(row->path, "p/padstack/plated") == 0)          helptxt = "When set, the hole\nor slot of the padstack\nis copper plated.";
+		else if (strcmp(row->path, "p/padstack/proto") == 0)           helptxt = "Padstack prototype ID\nto use. Determines padstack\ngeometry per layer.";
+		else if (strcmp(row->path, "p/padstack/smirror") == 0)         helptxt = "Swap layers of the\npadstack prototype so\nit is rendered upside down\n(layerstack mirror)";
+		else if (strcmp(row->path, "p/padstack/xmirror") == 0)         helptxt = "Mirror geometry over\nthe X axis.";
+
+		else if (strcmp(row->path, "p/text/clearance") == 0)           helptxt = "Text clearance\nis experimental.\n\nDO NOT USE!";
+	}
+
+	if (last_help != help_expose) {
+		rnd_hid_attr_val_t hv;
+		hv.str = NULL;
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wprev, &hv);
+	}
+
+	if (helptxt != NULL) {
+		rnd_hid_attr_val_t hv;
+
+		rnd_gui->attr_dlg_widget_hide(ctx->dlg_hid_ctx, ctx->wprev, 1);
+		rnd_gui->attr_dlg_widget_hide(ctx->dlg_hid_ctx, ctx->whelptxt, 0);
+
+		hv.str = helptxt;
+		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->whelptxt, &hv);
+	}
+	else {
+		rnd_gui->attr_dlg_widget_hide(ctx->dlg_hid_ctx, ctx->whelptxt, 1);
+		rnd_gui->attr_dlg_widget_hide(ctx->dlg_hid_ctx, ctx->wprev, 0);
+	}
+
 	prop_vals_update(ctx, p);
 }
 
@@ -372,9 +486,11 @@ static void prop_data_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 	}
 
 	if (force_update || ctx->dlg[ctx->wabs[p->type]].val.lng) {
+		ctx->lock = 1;
 		pcb_propsel_set(&ctx->pe, r->user_data, &sctx);
 		prop_refresh(ctx);
 		rnd_gui->invalidate_all(rnd_gui);
+		ctx->lock = 0;
 	}
 }
 
@@ -417,9 +533,11 @@ static void prop_add_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *a
 
 	if ((failed == 0) && (*key != '\0')) {
 		char *path = rnd_strdup_printf("a/%s", key);
+		ctx->lock = 1;
 		pcb_propsel_set_str(&ctx->pe, path, dlg[wval].val.str);
 		free(path);
 		prop_refresh(ctx);
+		ctx->lock = 0;
 	}
 	RND_DAD_FREE(dlg);
 }
@@ -436,11 +554,15 @@ static void prop_del_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *a
 		rnd_message(RND_MSG_ERROR, "Only atributes (a/ subtree) can be deleted.\n");
 		return;
 	}
+
+	ctx->lock = 1;
 	if (pcb_propsel_del(&ctx->pe, r->path) < 1) {
+		ctx->lock = 0;
 		rnd_message(RND_MSG_ERROR, "Failed to remove the attribute from any object.\n");
 		return;
 	}
 	prop_refresh(ctx);
+	ctx->lock = 0;
 }
 
 static void prop_preset_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -647,8 +769,12 @@ static void pcb_dlg_propdlg(propdlg_t *ctx)
 			/* right: preview and per type edit */
 			RND_DAD_BEGIN_VBOX(ctx->dlg);
 				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-				RND_DAD_BEGIN_VBOX(ctx->dlg);
-					RND_DAD_PREVIEW(ctx->dlg, prop_prv_expose_cb, prop_prv_mouse_cb, NULL, NULL, &prvbb, 100, 100, ctx);
+				RND_DAD_BEGIN_HBOX(ctx->dlg);
+					RND_DAD_PREVIEW(ctx->dlg, prop_prv_expose_cb, prop_prv_mouse_cb, NULL, NULL, &prvbb, 150, 150, ctx);
+						ctx->wprev = RND_DAD_CURRENT(ctx->dlg);
+					RND_DAD_LABEL(ctx->dlg, "help");
+						ctx->whelptxt = RND_DAD_CURRENT(ctx->dlg);
+					RND_DAD_PREVIEW(ctx->dlg, prop_nil_expose_cb, NULL, NULL, NULL, &prvbb, 1, 150, ctx); /* placeholder */
 				RND_DAD_END(ctx->dlg);
 				RND_DAD_LABEL(ctx->dlg, "<scope>");
 					ctx->wscope = RND_DAD_CURRENT(ctx->dlg);
@@ -715,6 +841,14 @@ static void propdlg_unit_change(rnd_conf_native_t *cfg, int arr_idx)
 	}
 }
 
+static void propedit_brd_chg(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+{
+	propdlg_t *pd;
+	for(pd = gdl_first(&propdlgs); pd != NULL; pd = gdl_next(&propdlgs, pd))
+		if ((pd->pe.selection || (pd->pe.objs.lst.length != 0)) && !pd->lock)
+			prop_refresh(pd);
+}
+
 static rnd_conf_hid_id_t propdlg_conf_id;
 static const char *propdlg_cookie = "propdlg";
 void pcb_propdlg_init(void)
@@ -727,6 +861,8 @@ void pcb_propdlg_init(void)
 		cbs.val_change_post = propdlg_unit_change;
 		rnd_conf_hid_set_cb(n, propdlg_conf_id, &cbs);
 	}
+
+	rnd_event_bind(PCB_EVENT_BOARD_EDITED, propedit_brd_chg, NULL, pcb_propedit_cookie);
 }
 
 void pcb_propdlg_uninit(void)
