@@ -29,10 +29,12 @@ void pcb_propsel_map_core(pcb_propedit_t *ctx);
 
 typedef struct set_ctx_s {
 	const char *s; /* only for string */
-	pcb_coord_t c; /* also int */
+	rnd_coord_t c; /* also int */
 	double d;
-	pcb_color_t color;
-	pcb_bool c_absolute, d_absolute, c_valid, d_valid, clr_valid;
+	rnd_color_t color;
+	rnd_bool c_absolute, d_absolute, c_valid, d_valid, clr_valid;
+	unsigned toggle:1;        /* when 1, ignore value and attempt to toggle */
+	unsigned toggle_create:1; /* when 1, create non-existing attribute on toggle, with value true */
 
 	/* private */
 	unsigned is_trace:1;
@@ -46,6 +48,7 @@ typedef struct set_ctx_s {
 
 int pcb_propsel_set_str(pcb_propedit_t *ctx, const char *prop, const char *value);
 int pcb_propsel_set(pcb_propedit_t *ctx, const char *prop, pcb_propset_ctx_t *sctx);
+int pcb_propsel_toggle(pcb_propedit_t *ctx, const char *prop, rnd_bool create);
 int pcb_propsel_del(pcb_propedit_t *ctx, const char *attr_name);
 
 /* Allocate new string and print the value using current unit */
