@@ -88,7 +88,7 @@ static fgw_error_t pcb_act_Renumber(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		 * We deal with the case where name already exists in this
 		 * function so the GUI doesn't need to deal with it
 		 */
-		name = rnd_gui->fileselect(rnd_gui, "Save Renumber Annotation File As ...",
+		name = rnd_hid_fileselect(rnd_gui, "Save Renumber Annotation File As ...",
 													 "Choose a file to record the renumbering to.\n"
 														 "This file may be used to back annotate the\n"
 														 "change to the schematics.\n", default_file, ".eco", NULL, "eco", 0, NULL);
@@ -105,16 +105,6 @@ static fgw_error_t pcb_act_Renumber(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		default_file = rnd_strdup(name);
 	}
 
-	if ((out = rnd_fopen(&PCB->hidlib, name, "r"))) {
-		fclose(out);
-		if (rnd_hid_message_box(&PCB->hidlib, "warning", "Renumber: overwrite", "File exists!  Ok to overwrite?", "cancel", 0, "overwrite", 1, NULL) != 1) {
-			if (free_name && name)
-				free((char*)name);
-			RND_ACT_IRES(1);
-			return 0;
-		}
-	}
-
 	if ((out = rnd_fopen_askovr(&PCB->hidlib, name, "w", NULL)) == NULL) {
 		rnd_message(RND_MSG_ERROR, "Could not open %s\n", name);
 		if (free_name && name)
@@ -280,7 +270,7 @@ static fgw_error_t pcb_act_Renumber(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 				pcb_undo_add_obj_to_change_name(PCB_OBJ_SUBC, NULL, NULL, subc_list[i], (char *)or_empty(subc_list[i]->refdes));
 
-				pcb_chg_obj_name(PCB_OBJ_SUBC, subc_list[i], NULL, NULL, tmps);
+				pcb_chg_obj_name(PCB_OBJ_SUBC, subc_list[i], subc_list[i], NULL, tmps);
 				changed = rnd_true;
 
 				/* we don't free tmps in this case because it is used */
