@@ -92,7 +92,7 @@ static void rdialog_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
 	free(ctx);
 }
 
-static void rdialog(const char *name, const char *content)
+static void rdialog_gui(const char *name, const char *content)
 {
 	rdialog_ctx_t *ctx = calloc(sizeof(rdialog_ctx_t), 1);
 	rnd_hid_dad_buttons_t clbtn[] = {{"Close", 0}, {NULL, 0}};
@@ -106,6 +106,21 @@ static void rdialog(const char *name, const char *content)
 }
 
 
+static void rdialog_cli(const char *name, const char *content)
+{
+	printf("*** report '%s' begin ***\n", name);
+	printf("%s\n", content);
+	printf("*** report '%s' end ***\n", name);
+}
+
+static void rdialog(const char *name, const char *content)
+{
+	if (RND_HAVE_GUI_ATTR_DLG)
+		rdialog_gui(name, content);
+	else
+		rdialog_cli(name, content);
+}
+
 static int report_drills(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	pcb_drill_info_t *AllDrills;
@@ -501,9 +516,9 @@ static double xy_to_net_length(pcb_board_t *pcb, rnd_coord_t x, rnd_coord_t y, i
 	}
 
 	if (nl->has_nontrace)
-		rnd_append_printf(err, "\n%Partial result: polygons/texts blocked the search");
+		rnd_append_printf(err, "\nPartial result: polygons/texts blocked the search");
 	else if (nl->has_junction)
-		rnd_append_printf(err, "\n%Partial result: a junction blocked the search");
+		rnd_append_printf(err, "\nPartial result: a junction blocked the search");
 
 	pcb_qry_uninit(&ec);
 
@@ -903,7 +918,7 @@ static fgw_error_t pcb_act_NetLength(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	/* anything below needs the layer */
 
 	if (ly == NULL)
-		ly = pcb_uilayer_alloc("NetLength", "Net length", rnd_color_blue);
+		ly = pcb_uilayer_alloc(PCB_ACT_BOARD, "NetLength", "Net length", rnd_color_blue);
 
 	if (strcmp(cmd, "object") == 0) {
 		int type;
