@@ -14,16 +14,6 @@ int lineno = 0;
 int global_notify = 0;
 rnd_conf_hid_id_t hid_id;
 const char *hid_cookie = "conftest cookie";
-const char *rnd_hidlib_default_embedded_menu = "";
-const char *rnd_menu_file_paths[] = { "./", "~/.pcb-rnd/", PCBSHAREDIR "/", NULL };
-const char *rnd_menu_name_fmt = "pcb-menu-%s.lht";
-const char *rnd_app_package = "pcb-rnd";
-
-#define CONF_USER_DIR "~/" DOT_PCB_RND
-const char *rnd_conf_userdir_path = CONF_USER_DIR;
-const char *rnd_pcphl_conf_user_path = CONF_USER_DIR "/pcb-conf.lht";
-const char *rnd_conf_sysdir_path = PCBSHAREDIR;
-const char *rnd_conf_sys_path = PCBSHAREDIR "/pcb-conf.lht";
 
 const char *pcb_board_get_filename(void)
 {
@@ -35,10 +25,6 @@ const char *pcb_board_get_name(void)
 	return "dummy_brd";
 }
 
-void rnd_hidlib_crosshair_move_to(rnd_hidlib_t *hl, rnd_coord_t abs_x, rnd_coord_t abs_y, int mouse_mot)
-{
-}
-
 
 void watch_pre(rnd_conf_native_t *cfg, int idx)
 {
@@ -66,7 +52,7 @@ rnd_conf_hid_callbacks_t watch_cbs = {watch_pre, watch_post, NULL, NULL};
 rnd_conf_hid_callbacks_t global_cbs = {notify_pre, notify_post, NULL, NULL};
 
 
-extern lht_doc_t *pcb_conf_main_root[];
+extern lht_doc_t *rnd_conf_main_root[];
 void cmd_dump(char *arg)
 {
 	if (arg == NULL) {
@@ -76,7 +62,7 @@ void cmd_dump(char *arg)
 	if (strncmp(arg, "native", 6) == 0) {
 		arg+=7;
 		while(isspace(*arg)) arg++;
-		conf_dump(stdout, "", 1, arg);
+		rnd_diag_conf_dump(stdout, "", 1, arg);
 	}
 	else if (strncmp(arg, "lihata", 6) == 0) {
 		rnd_conf_role_t role;
@@ -87,8 +73,8 @@ void cmd_dump(char *arg)
 			rnd_message(RND_MSG_ERROR, "Invalid role: '%s'", arg);
 			return;
 		}
-		if (pcb_conf_main_root[role] != NULL)
-			lht_dom_export(pcb_conf_main_root[role]->root, stdout, "");
+		if (rnd_conf_main_root[role] != NULL)
+			lht_dom_export(rnd_conf_main_root[role]->root, stdout, "");
 		else
 			printf("<empty>\n");
 	}
