@@ -4,15 +4,12 @@ ROOT=../..
 SRC=$ROOT/src
 CFG="-c rc/library_search_paths=dummy_lib -c rc/quiet=1"
 
-#TODO: remove this once librnd separation id finished
-export LD_LIBRARY_PATH=`pwd`/$ROOT/src_3rd/librnd-local/src
-
 # call:
 # insert.lht 'MenuPatch(load, test, "insert.lht");'
 
 rm d0.lht d1.lht >/dev/null 2>&1
 
-cp pcb-menu-base.lht $1 $SRC
+cp menu-base.lht $1 $SRC
 (
 cd $SRC
 mkdir dummy_lib
@@ -27,7 +24,7 @@ rmdir dummy_lib
 
 mv $SRC/d0.lht .
 mv $SRC/d1.lht .
-rm $SRC/pcb-menu-base.lht $SRC/$1
+rm $SRC/menu-base.lht $SRC/$1
 
 diff -U1 d0.lht d1.lht | grep "^[ +-][^+-]"
 
