@@ -2,6 +2,8 @@
 
 ROOT="../.."
 SRC="$ROOT/src"
+TDIR="../tests/vendordrill"
+GFLT="../pupfilter.sh"
 PCBRND="./pcb-rnd"
 GLOBARGS="-c rc/library_search_paths=../tests/RTT/lib -c rc/quiet=1"
 
@@ -30,9 +32,8 @@ message(*** POST ***)
 Report(DrillReport)
 ') | (
 	cd $SRC
-	export LD_LIBRARY_PATH=../src_3rd/librnd-local/src
-	./pcb-rnd $GLOBARGS --gui batch $brd
-) | awk '
+	$PCBRND $GLOBARGS --gui batch $brd
+) | $GFLT | awk '
 # remove full path filenames
 /Loaded.*from/ {
 	line=$0
